pub enum Color {
}Variants
A98Rgb(A98Rgb)
DisplayP3(DisplayP3)
Hsv(Hsv)
Hsl(Hsl)
Hex(Hex)
Hwb(Hwb)
Lab(Lab)
Lch(Lch)
LinearRgb(LinearRgb)
Named(Named)
Oklab(Oklab)
Oklch(Oklch)
ProphotoRgb(ProphotoRgb)
Rec2020(Rec2020)
Srgb(Srgb)
XyzD50(XyzD50)
XyzD65(XyzD65)
Implementations
Sourceimpl Color
impl Color
Sourcepub fn color_space(&self) -> Option<ColorSpace>
pub fn color_space(&self) -> Option<ColorSpace>
Returns the ColorSpace of this colour, if it maps to a bounded RGB gamut.
Perceptual and CIE spaces (Lab, Lch, Oklab, Oklch, XyzD50, XyzD65) return None — they can represent
colours outside any single RGB gamut.
Sourcepub fn in_gamut_of(&self, space: ColorSpace) -> bool
pub fn in_gamut_of(&self, space: ColorSpace) -> bool
Returns true if this colour can be represented in space without clamping.
If the colour’s own space is a subset of space and the colour is in gamut of its own space, this returns true
without conversion. Otherwise the colour is converted to the target space (via XyzD65) and the RGB channels are
checked against [0,1].