mix_channels

Function mix_channels 

pub fn mix_channels(
    first: [Channel; 4],
    second: [Channel; 4],
    percentage: f64,
    hue_index: Option<usize>,
    hue_interpolation: HueInterpolation,
) -> [Channel; 4]
Mixes two colours channel-by-channel, honouring none channels by adopting the analogous channel from the other colour. When both are missing the result resolves to 0.

Non-hue colour components and alpha use premultiplied alpha interpolation. Polar colours use hue_index to select which (if any) component is a hue: that channel uses hue interpolation with the given direction.