Channel

Type Alias Channel 

pub type Channel = Option<f64>;
A generic single color channel value, which may be None

none channels in color-mix adopt the analogous channel’s value from the other color in the interpolation space (see crate::mix_channels).

Aliased Type

pub enum Channel {
    None,
    Some(f64),
}

Variants

1.0.0

None

No value.

1.0.0

Some(f64)

Some value of type T.