pub enum TouchActionStyleValue {
Auto(Ident),
None(Ident),
PanXPanY {
pan_x: Option<Ident>,
pan_y: Option<Ident>,
pinch_zoom: Option<Ident>,
},
PanXPanUp {
pan_x: Option<Ident>,
pan_up: Option<Ident>,
pinch_zoom: Option<Ident>,
},
PanXPanDown {
pan_x: Option<Ident>,
pan_down: Option<Ident>,
pinch_zoom: Option<Ident>,
},
PanLeftPanY {
pan_left: Option<Ident>,
pan_y: Option<Ident>,
pinch_zoom: Option<Ident>,
},
PanLeftPanUp {
pan_left: Option<Ident>,
pan_up: Option<Ident>,
pinch_zoom: Option<Ident>,
},
PanLeftPanDown {
pan_left: Option<Ident>,
pan_down: Option<Ident>,
pinch_zoom: Option<Ident>,
},
PanRightPanY {
pan_right: Option<Ident>,
pan_y: Option<Ident>,
pinch_zoom: Option<Ident>,
},
PanRightPanUp {
pan_right: Option<Ident>,
pan_up: Option<Ident>,
pinch_zoom: Option<Ident>,
},
PanRightPanDown {
pan_right: Option<Ident>,
pan_down: Option<Ident>,
pinch_zoom: Option<Ident>,
},
Manipulation(Ident),
}Expand description
Represents the style value for touch-action as defined in Pointer Events.
The touch-action CSS property sets whether an element on a touch screen can be panned or pinched to zoom.
The grammar is defined as:
auto | none | [ [ pan-x | pan-left | pan-right ] || [ pan-y | pan-up | pan-down ] || pinch-zoom ] | manipulationhttps://w3c.github.io/pointerevents/#touch-action
Variants
Auto(Ident)
None(Ident)
PanXPanY
PanXPanUp
PanXPanDown
PanLeftPanY
PanLeftPanUp
PanLeftPanDown
PanRightPanY
PanRightPanUp
PanRightPanDown
Manipulation(Ident)