pub struct BlurFunction {
pub name: Function,
pub radius: Option<NonNegative<Length>>,
pub close: RightParen,
}Expand description
blur( <length [0,∞]>? )
Fields
name: Functionradius: Option<NonNegative<Length>>close: RightParenTrait Implementations
Sourceimpl Clone for BlurFunction
impl Clone for BlurFunction
Sourcefn clone(&self) -> BlurFunction
fn clone(&self) -> BlurFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlurFunction
impl Debug for BlurFunction
Sourceimpl Hash for BlurFunction
impl Hash for BlurFunction
Sourceimpl NodeWithMetadata<CssMetadata> for BlurFunction
impl NodeWithMetadata<CssMetadata> for BlurFunction
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for BlurFunction
impl Ord for BlurFunction
Sourcefn cmp(&self, other: &BlurFunction) -> Ordering
fn cmp(&self, other: &BlurFunction) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for BlurFunction
impl<'a> Parse<'a> for BlurFunction
Sourceimpl PartialEq for BlurFunction
impl PartialEq for BlurFunction
Sourceimpl PartialOrd for BlurFunction
impl PartialOrd for BlurFunction
Sourceimpl<'a> Peek<'a> for BlurFunction
impl<'a> Peek<'a> for BlurFunction
Sourceimpl QueryableNode for BlurFunction
impl QueryableNode for BlurFunction
Sourceimpl SemanticEq for BlurFunction
impl SemanticEq for BlurFunction
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for BlurFunction
impl Serialize for BlurFunction
Sourceimpl ToCursors for BlurFunction
impl ToCursors for BlurFunction
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for BlurFunction
impl VisitableMut for BlurFunction
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Eq for BlurFunction
impl StructuralPartialEq for BlurFunction