pub struct BrightnessFunction {
pub name: Function,
pub value: Option<NumberOrPercentage>,
pub close: RightParen,
}Expand description
brightness( <number [0,∞]> | <percentage [0,∞]> )
Fields
name: Functionvalue: Option<NumberOrPercentage>close: RightParenTrait Implementations
Sourceimpl Clone for BrightnessFunction
impl Clone for BrightnessFunction
Sourcefn clone(&self) -> BrightnessFunction
fn clone(&self) -> BrightnessFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrightnessFunction
impl Debug for BrightnessFunction
Sourceimpl Hash for BrightnessFunction
impl Hash for BrightnessFunction
Sourceimpl NodeWithMetadata<CssMetadata> for BrightnessFunction
impl NodeWithMetadata<CssMetadata> for BrightnessFunction
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for BrightnessFunction
impl Ord for BrightnessFunction
Sourcefn cmp(&self, other: &BrightnessFunction) -> Ordering
fn cmp(&self, other: &BrightnessFunction) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for BrightnessFunction
impl<'a> Parse<'a> for BrightnessFunction
Sourceimpl PartialEq for BrightnessFunction
impl PartialEq for BrightnessFunction
Sourceimpl PartialOrd for BrightnessFunction
impl PartialOrd for BrightnessFunction
Sourceimpl<'a> Peek<'a> for BrightnessFunction
impl<'a> Peek<'a> for BrightnessFunction
Sourceimpl QueryableNode for BrightnessFunction
impl QueryableNode for BrightnessFunction
Sourceconst NODE_ID: NodeId = crate::NodeId::BrightnessFunction
const NODE_ID: NodeId = crate::NodeId::BrightnessFunction
Unique identifier for this node type.
fn node_id(&self) -> NodeId
Sourcefn get_property(&self, _kind: PropertyKind) -> Option<Cursor>
fn get_property(&self, _kind: PropertyKind) -> Option<Cursor>
Returns a cursor for the given property kind, if the node has that property.
Used by attribute selectors to extract values from nodes. Read more
Sourceimpl SemanticEq for BrightnessFunction
impl SemanticEq for BrightnessFunction
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for BrightnessFunction
impl Serialize for BrightnessFunction
Sourceimpl ToCursors for BrightnessFunction
impl ToCursors for BrightnessFunction
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for BrightnessFunction
impl VisitableMut for BrightnessFunction
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Eq for BrightnessFunction
impl StructuralPartialEq for BrightnessFunction