pub struct ColorProfileSrcValue(/* private fields */);Trait Implementations
Sourceimpl Clone for ColorProfileSrcValue
impl Clone for ColorProfileSrcValue
Sourcefn clone(&self) -> ColorProfileSrcValue
fn clone(&self) -> ColorProfileSrcValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColorProfileSrcValue
impl Debug for ColorProfileSrcValue
Sourceimpl Hash for ColorProfileSrcValue
impl Hash for ColorProfileSrcValue
Sourceimpl NodeWithMetadata<CssMetadata> for ColorProfileSrcValue
impl NodeWithMetadata<CssMetadata> for ColorProfileSrcValue
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for ColorProfileSrcValue
impl Ord for ColorProfileSrcValue
Sourcefn cmp(&self, other: &ColorProfileSrcValue) -> Ordering
fn cmp(&self, other: &ColorProfileSrcValue) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for ColorProfileSrcValue
impl<'a> Parse<'a> for ColorProfileSrcValue
Sourceimpl PartialEq for ColorProfileSrcValue
impl PartialEq for ColorProfileSrcValue
Sourcefn eq(&self, other: &ColorProfileSrcValue) -> bool
fn eq(&self, other: &ColorProfileSrcValue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ColorProfileSrcValue
impl PartialOrd for ColorProfileSrcValue
Sourceimpl<'a> Peek<'a> for ColorProfileSrcValue
impl<'a> Peek<'a> for ColorProfileSrcValue
Sourceimpl SemanticEq for ColorProfileSrcValue
impl SemanticEq for ColorProfileSrcValue
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for ColorProfileSrcValue
impl Serialize for ColorProfileSrcValue
Sourceimpl ToCursors for ColorProfileSrcValue
impl ToCursors for ColorProfileSrcValue
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl TypeLayout for ColorProfileSrcValue
impl TypeLayout for ColorProfileSrcValue
const TYPE_LAYOUT: TypeLayoutInfo
Sourceimpl Visitable for ColorProfileSrcValue
impl Visitable for ColorProfileSrcValue
Sourceimpl VisitableMut for ColorProfileSrcValue
impl VisitableMut for ColorProfileSrcValue
fn accept_mut<__V: VisitMut>(&mut self, v: &mut __V)
impl Eq for ColorProfileSrcValue
impl StructuralPartialEq for ColorProfileSrcValue