pub struct ContainIntrinsicSizeStyleValue(pub SingleContainIntrinsicSizeStyleValue, pub Option<SingleContainIntrinsicSizeStyleValue>);Expand description
Represents the style value for contain-intrinsic-size as defined in css-sizing-4.
The contain-intrinsic-size CSS property sets the intrinsic size of an element. When using size containment, the browser will lay out the element as if it had a single child of this size.
The grammar is defined as:
[ auto? [ none | <length [0,∞]> ] ]{1,2}https://drafts.csswg.org/css-sizing-4/#contain-intrinsic-size
Tuple Fields
0: SingleContainIntrinsicSizeStyleValue1: Option<SingleContainIntrinsicSizeStyleValue>Trait Implementations
Sourceimpl Clone for ContainIntrinsicSizeStyleValue
impl Clone for ContainIntrinsicSizeStyleValue
Sourcefn clone(&self) -> ContainIntrinsicSizeStyleValue
fn clone(&self) -> ContainIntrinsicSizeStyleValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DeclarationMetadata for ContainIntrinsicSizeStyleValue
impl DeclarationMetadata for ContainIntrinsicSizeStyleValue
Sourcefn applies_to() -> AppliesTo
fn applies_to() -> AppliesTo
Determines what types of frames this rule applies to
Sourcefn animation_type() -> AnimationType
fn animation_type() -> AnimationType
Returns how this style value animates
Sourcefn percentages() -> Percentages
fn percentages() -> Percentages
Determines how this style value resolves percentages, if they are allowed as values
Sourcefn longhands() -> Option<&'static [CssAtomSet]>
fn longhands() -> Option<&'static [CssAtomSet]>
Returns all transitive longhands for a shorthand property.
For nested shorthands (e.g.,
border-width), this recursively expands to include
all nested longhands (e.g., border-top-width, border-left-width, etc.).Sourcefn is_shorthand() -> bool
fn is_shorthand() -> bool
Determines if this style value is a “shorthand” value, meaning it is comprised of other “longhand” style values.
Sourcefn property_group() -> PropertyGroup
fn property_group() -> PropertyGroup
Returns which CSS specification(s) this property belongs to.
This allows tracking which CSS modules are used in a stylesheet.
Sourcefn computed_value_type() -> ComputedValueType
fn computed_value_type() -> ComputedValueType
Returns how the computed value is calculated from the specified value.
Sourcefn canonical_order() -> Option<&'static str>
fn canonical_order() -> Option<&'static str>
Returns the canonical order for serialization (e.g., “per grammar”, “unique”).
Returns None if not specified or not applicable.
Sourcefn is_longhand() -> bool
fn is_longhand() -> bool
Determines if this style value is a “longhand” value, meaning a “shorthand” style value exists that could also
express this.
Sourcefn shorthand_group() -> CssAtomSet
fn shorthand_group() -> CssAtomSet
Returns the declaration ID of the shorthand that this property is part of.
If this is not a longhand then it will be
CssAtomSet::_None.Sourcefn logical_property_group() -> Option<CssAtomSet>
fn logical_property_group() -> Option<CssAtomSet>
Returns the logical property group this property belongs to (e.g., “Margin”, “Border”).
This groups related logical/physical properties together.
Returns None if this is not part of a logical property group.
Sourcefn box_side() -> BoxSide
fn box_side() -> BoxSide
Returns which side(s) of the box this property applies to.
For example,
margin-top returns BoxSide::Top, while margin returns all sides.
Returns BoxSide::none() if the property doesn’t apply to a specific side.Sourcefn box_portion() -> BoxPortion
fn box_portion() -> BoxPortion
Returns which portion(s) of the box model this property affects.
For example,
margin-top returns BoxPortion::Margin, border-width returns BoxPortion::Border.
Returns BoxPortion::none() if the property doesn’t affect the box model.Sourcefn unitless_zero_resolves() -> UnitlessZeroResolves
fn unitless_zero_resolves() -> UnitlessZeroResolves
Returns how unitless zero resolves for this property. Read more
Sourceimpl NodeWithMetadata<CssMetadata> for ContainIntrinsicSizeStyleValue
impl NodeWithMetadata<CssMetadata> for ContainIntrinsicSizeStyleValue
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for ContainIntrinsicSizeStyleValue
impl Ord for ContainIntrinsicSizeStyleValue
Sourcefn cmp(&self, other: &ContainIntrinsicSizeStyleValue) -> Ordering
fn cmp(&self, other: &ContainIntrinsicSizeStyleValue) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for ContainIntrinsicSizeStyleValue
impl<'a> Parse<'a> for ContainIntrinsicSizeStyleValue
Sourceimpl PartialEq for ContainIntrinsicSizeStyleValue
impl PartialEq for ContainIntrinsicSizeStyleValue
Sourcefn eq(&self, other: &ContainIntrinsicSizeStyleValue) -> bool
fn eq(&self, other: &ContainIntrinsicSizeStyleValue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ContainIntrinsicSizeStyleValue
impl PartialOrd for ContainIntrinsicSizeStyleValue
Sourceimpl<'a> Peek<'a> for ContainIntrinsicSizeStyleValue
impl<'a> Peek<'a> for ContainIntrinsicSizeStyleValue
Sourceimpl QueryableNode for ContainIntrinsicSizeStyleValue
impl QueryableNode for ContainIntrinsicSizeStyleValue
Sourceconst NODE_ID: NodeId = crate::NodeId::ContainIntrinsicSizeStyleValue
const NODE_ID: NodeId = crate::NodeId::ContainIntrinsicSizeStyleValue
Unique identifier for this node type.
fn node_id(&self) -> NodeId
Sourcefn get_property(&self, _kind: PropertyKind) -> Option<Cursor>
fn get_property(&self, _kind: PropertyKind) -> Option<Cursor>
Returns a cursor for the given property kind, if the node has that property.
Used by attribute selectors to extract values from nodes. Read more
Sourceimpl SemanticEq for ContainIntrinsicSizeStyleValue
impl SemanticEq for ContainIntrinsicSizeStyleValue
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl ToCursors for ContainIntrinsicSizeStyleValue
impl ToCursors for ContainIntrinsicSizeStyleValue
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for ContainIntrinsicSizeStyleValue
impl VisitableMut for ContainIntrinsicSizeStyleValue
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Eq for ContainIntrinsicSizeStyleValue
impl StructuralPartialEq for ContainIntrinsicSizeStyleValue