#[repr(C)]pub struct ElementFunction {
pub name: Function,
pub id: Id,
pub close: RightParen,
}Expand description
https://drafts.csswg.org/css-images-4/#funcdef-element
<element()> = element( <id-selector> )Fields
name: Functionid: Idclose: RightParenTrait Implementations
Sourceimpl Clone for ElementFunction
impl Clone for ElementFunction
Sourcefn clone(&self) -> ElementFunction
fn clone(&self) -> ElementFunction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ElementFunction
impl Debug for ElementFunction
Sourceimpl Hash for ElementFunction
impl Hash for ElementFunction
Sourceimpl NodeWithMetadata<CssMetadata> for ElementFunction
impl NodeWithMetadata<CssMetadata> for ElementFunction
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for ElementFunction
impl Ord for ElementFunction
Sourcefn cmp(&self, other: &ElementFunction) -> Ordering
fn cmp(&self, other: &ElementFunction) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for ElementFunction
impl<'a> Parse<'a> for ElementFunction
Sourceimpl PartialEq for ElementFunction
impl PartialEq for ElementFunction
Sourcefn eq(&self, other: &ElementFunction) -> bool
fn eq(&self, other: &ElementFunction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ElementFunction
impl PartialOrd for ElementFunction
Sourceimpl<'a> Peek<'a> for ElementFunction
impl<'a> Peek<'a> for ElementFunction
Sourceimpl SemanticEq for ElementFunction
impl SemanticEq for ElementFunction
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for ElementFunction
impl Serialize for ElementFunction
Sourceimpl ToCursors for ElementFunction
impl ToCursors for ElementFunction
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl TypeLayout for ElementFunction
impl TypeLayout for ElementFunction
const TYPE_LAYOUT: TypeLayoutInfo
Sourceimpl Visitable for ElementFunction
impl Visitable for ElementFunction
Sourceimpl VisitableMut for ElementFunction
impl VisitableMut for ElementFunction
fn accept_mut<__V: VisitMut>(&mut self, v: &mut __V)
impl Eq for ElementFunction
impl StructuralPartialEq for ElementFunction