pub struct GenericVoice {
pub age: Option<VoiceAge>,
pub gender: VoiceGender,
pub variant: Option<Number>,
}Expand description
https://drafts.csswg.org/css-speech-1/#typedef-generic-voice
<generic-voice> = <age>? <gender> <integer>?Fields
age: Option<VoiceAge>gender: VoiceGendervariant: Option<Number>Trait Implementations
Sourceimpl Clone for GenericVoice
impl Clone for GenericVoice
Sourcefn clone(&self) -> GenericVoice
fn clone(&self) -> GenericVoice
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenericVoice
impl Debug for GenericVoice
Sourceimpl Hash for GenericVoice
impl Hash for GenericVoice
Sourceimpl NodeWithMetadata<CssMetadata> for GenericVoice
impl NodeWithMetadata<CssMetadata> for GenericVoice
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for GenericVoice
impl Ord for GenericVoice
Sourcefn cmp(&self, other: &GenericVoice) -> Ordering
fn cmp(&self, other: &GenericVoice) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for GenericVoice
impl<'a> Parse<'a> for GenericVoice
Sourceimpl PartialEq for GenericVoice
impl PartialEq for GenericVoice
Sourceimpl PartialOrd for GenericVoice
impl PartialOrd for GenericVoice
Sourceimpl<'a> Peek<'a> for GenericVoice
impl<'a> Peek<'a> for GenericVoice
Sourceimpl QueryableNode for GenericVoice
impl QueryableNode for GenericVoice
Sourceimpl SemanticEq for GenericVoice
impl SemanticEq for GenericVoice
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for GenericVoice
impl Serialize for GenericVoice
Sourceimpl ToCursors for GenericVoice
impl ToCursors for GenericVoice
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for GenericVoice
impl VisitableMut for GenericVoice
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Copy for GenericVoice
impl Eq for GenericVoice
impl StructuralPartialEq for GenericVoice