pub struct GrayscaleFunction {
pub name: Function,
pub value: Option<NumberOrPercentage>,
pub close: RightParen,
}Expand description
grayscale( <number [0,1]> | <percentage [0,100]> )
Fields
name: Functionvalue: Option<NumberOrPercentage>close: RightParenTrait Implementations
Sourceimpl Clone for GrayscaleFunction
impl Clone for GrayscaleFunction
Sourcefn clone(&self) -> GrayscaleFunction
fn clone(&self) -> GrayscaleFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GrayscaleFunction
impl Debug for GrayscaleFunction
Sourceimpl Hash for GrayscaleFunction
impl Hash for GrayscaleFunction
Sourceimpl NodeWithMetadata<CssMetadata> for GrayscaleFunction
impl NodeWithMetadata<CssMetadata> for GrayscaleFunction
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for GrayscaleFunction
impl Ord for GrayscaleFunction
Sourcefn cmp(&self, other: &GrayscaleFunction) -> Ordering
fn cmp(&self, other: &GrayscaleFunction) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for GrayscaleFunction
impl<'a> Parse<'a> for GrayscaleFunction
Sourceimpl PartialEq for GrayscaleFunction
impl PartialEq for GrayscaleFunction
Sourceimpl PartialOrd for GrayscaleFunction
impl PartialOrd for GrayscaleFunction
Sourceimpl<'a> Peek<'a> for GrayscaleFunction
impl<'a> Peek<'a> for GrayscaleFunction
Sourceimpl QueryableNode for GrayscaleFunction
impl QueryableNode for GrayscaleFunction
Sourceconst NODE_ID: NodeId = crate::NodeId::GrayscaleFunction
const NODE_ID: NodeId = crate::NodeId::GrayscaleFunction
Unique identifier for this node type.
fn node_id(&self) -> NodeId
Sourcefn get_property(&self, _kind: PropertyKind) -> Option<Cursor>
fn get_property(&self, _kind: PropertyKind) -> Option<Cursor>
Returns a cursor for the given property kind, if the node has that property.
Used by attribute selectors to extract values from nodes. Read more
Sourceimpl SemanticEq for GrayscaleFunction
impl SemanticEq for GrayscaleFunction
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for GrayscaleFunction
impl Serialize for GrayscaleFunction
Sourceimpl ToCursors for GrayscaleFunction
impl ToCursors for GrayscaleFunction
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for GrayscaleFunction
impl VisitableMut for GrayscaleFunction
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Eq for GrayscaleFunction
impl StructuralPartialEq for GrayscaleFunction