pub struct HueInterpolationMethod {
pub direction: HueInterpolationDirection,
pub hue_keyword: Ident,
}Expand description
https://drafts.csswg.org/css-color-4/#typedef-hue-interpolation-method
<hue-interpolation-method> = [ shorter | longer | increasing | decreasing ] hueFields
direction: HueInterpolationDirectionhue_keyword: IdentTrait Implementations
Sourceimpl Clone for HueInterpolationMethod
impl Clone for HueInterpolationMethod
Sourcefn clone(&self) -> HueInterpolationMethod
fn clone(&self) -> HueInterpolationMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HueInterpolationMethod
impl Debug for HueInterpolationMethod
Sourceimpl Hash for HueInterpolationMethod
impl Hash for HueInterpolationMethod
Sourceimpl NodeWithMetadata<CssMetadata> for HueInterpolationMethod
impl NodeWithMetadata<CssMetadata> for HueInterpolationMethod
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for HueInterpolationMethod
impl Ord for HueInterpolationMethod
Sourcefn cmp(&self, other: &HueInterpolationMethod) -> Ordering
fn cmp(&self, other: &HueInterpolationMethod) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for HueInterpolationMethod
impl<'a> Parse<'a> for HueInterpolationMethod
Sourceimpl PartialEq for HueInterpolationMethod
impl PartialEq for HueInterpolationMethod
Sourceimpl PartialOrd for HueInterpolationMethod
impl PartialOrd for HueInterpolationMethod
Sourceimpl<'a> Peek<'a> for HueInterpolationMethod
impl<'a> Peek<'a> for HueInterpolationMethod
Sourceimpl QueryableNode for HueInterpolationMethod
impl QueryableNode for HueInterpolationMethod
Sourceconst NODE_ID: NodeId = crate::NodeId::HueInterpolationMethod
const NODE_ID: NodeId = crate::NodeId::HueInterpolationMethod
Unique identifier for this node type.
fn node_id(&self) -> NodeId
Sourcefn get_property(&self, _kind: PropertyKind) -> Option<Cursor>
fn get_property(&self, _kind: PropertyKind) -> Option<Cursor>
Returns a cursor for the given property kind, if the node has that property.
Used by attribute selectors to extract values from nodes. Read more
Sourceimpl SemanticEq for HueInterpolationMethod
impl SemanticEq for HueInterpolationMethod
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for HueInterpolationMethod
impl Serialize for HueInterpolationMethod
Sourceimpl ToCursors for HueInterpolationMethod
impl ToCursors for HueInterpolationMethod
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for HueInterpolationMethod
impl VisitableMut for HueInterpolationMethod
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Copy for HueInterpolationMethod
impl Eq for HueInterpolationMethod
impl StructuralPartialEq for HueInterpolationMethod