pub struct InvertFunction {
pub name: Function,
pub value: Option<NumberOrPercentage>,
pub close: RightParen,
}Expand description
invert( <number [0,1]> | <percentage [0,100]> )
Fields
name: Functionvalue: Option<NumberOrPercentage>close: RightParenTrait Implementations
Sourceimpl Clone for InvertFunction
impl Clone for InvertFunction
Sourcefn clone(&self) -> InvertFunction
fn clone(&self) -> InvertFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvertFunction
impl Debug for InvertFunction
Sourceimpl Hash for InvertFunction
impl Hash for InvertFunction
Sourceimpl NodeWithMetadata<CssMetadata> for InvertFunction
impl NodeWithMetadata<CssMetadata> for InvertFunction
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for InvertFunction
impl Ord for InvertFunction
Sourcefn cmp(&self, other: &InvertFunction) -> Ordering
fn cmp(&self, other: &InvertFunction) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for InvertFunction
impl<'a> Parse<'a> for InvertFunction
Sourceimpl PartialEq for InvertFunction
impl PartialEq for InvertFunction
Sourceimpl PartialOrd for InvertFunction
impl PartialOrd for InvertFunction
Sourceimpl<'a> Peek<'a> for InvertFunction
impl<'a> Peek<'a> for InvertFunction
Sourceimpl QueryableNode for InvertFunction
impl QueryableNode for InvertFunction
Sourceimpl SemanticEq for InvertFunction
impl SemanticEq for InvertFunction
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for InvertFunction
impl Serialize for InvertFunction
Sourceimpl ToCursors for InvertFunction
impl ToCursors for InvertFunction
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for InvertFunction
impl VisitableMut for InvertFunction
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Eq for InvertFunction
impl StructuralPartialEq for InvertFunction