pub struct OpacityFunction {
pub name: Function,
pub value: Option<NumberOrPercentage>,
pub close: RightParen,
}Expand description
opacity( <number [0,1]> | <percentage [0,100]> )
Fields
name: Functionvalue: Option<NumberOrPercentage>close: RightParenTrait Implementations
Sourceimpl Clone for OpacityFunction
impl Clone for OpacityFunction
Sourcefn clone(&self) -> OpacityFunction
fn clone(&self) -> OpacityFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpacityFunction
impl Debug for OpacityFunction
Sourceimpl Hash for OpacityFunction
impl Hash for OpacityFunction
Sourceimpl NodeWithMetadata<CssMetadata> for OpacityFunction
impl NodeWithMetadata<CssMetadata> for OpacityFunction
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for OpacityFunction
impl Ord for OpacityFunction
Sourcefn cmp(&self, other: &OpacityFunction) -> Ordering
fn cmp(&self, other: &OpacityFunction) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for OpacityFunction
impl<'a> Parse<'a> for OpacityFunction
Sourceimpl PartialEq for OpacityFunction
impl PartialEq for OpacityFunction
Sourceimpl PartialOrd for OpacityFunction
impl PartialOrd for OpacityFunction
Sourceimpl<'a> Peek<'a> for OpacityFunction
impl<'a> Peek<'a> for OpacityFunction
Sourceimpl QueryableNode for OpacityFunction
impl QueryableNode for OpacityFunction
Sourceimpl SemanticEq for OpacityFunction
impl SemanticEq for OpacityFunction
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for OpacityFunction
impl Serialize for OpacityFunction
Sourceimpl ToCursors for OpacityFunction
impl ToCursors for OpacityFunction
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for OpacityFunction
impl VisitableMut for OpacityFunction
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Eq for OpacityFunction
impl StructuralPartialEq for OpacityFunction