pub struct RectFunction {
pub name: Function,
pub top: AutoOr<Length>,
pub comma1: Option<Comma>,
pub right: AutoOr<Length>,
pub comma2: Option<Comma>,
pub bottom: AutoOr<Length>,
pub comma3: Option<Comma>,
pub left: AutoOr<Length>,
pub close: RightParen,
}Expand description
https://drafts.csswg.org/css-masking-1/#funcdef-rect
rect() = rect( <top>, <right>, <bottom>, <left> )
<top>, <right>, <bottom>, <left> = <length> | autoFields
name: Functiontop: AutoOr<Length>comma1: Option<Comma>right: AutoOr<Length>comma2: Option<Comma>bottom: AutoOr<Length>comma3: Option<Comma>left: AutoOr<Length>close: RightParenTrait Implementations
Sourceimpl Clone for RectFunction
impl Clone for RectFunction
Sourcefn clone(&self) -> RectFunction
fn clone(&self) -> RectFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RectFunction
impl Debug for RectFunction
Sourceimpl Hash for RectFunction
impl Hash for RectFunction
Sourceimpl NodeWithMetadata<CssMetadata> for RectFunction
impl NodeWithMetadata<CssMetadata> for RectFunction
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for RectFunction
impl Ord for RectFunction
Sourcefn cmp(&self, other: &RectFunction) -> Ordering
fn cmp(&self, other: &RectFunction) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for RectFunction
impl<'a> Parse<'a> for RectFunction
Sourceimpl PartialEq for RectFunction
impl PartialEq for RectFunction
Sourceimpl PartialOrd for RectFunction
impl PartialOrd for RectFunction
Sourceimpl<'a> Peek<'a> for RectFunction
impl<'a> Peek<'a> for RectFunction
Sourceimpl QueryableNode for RectFunction
impl QueryableNode for RectFunction
Sourceimpl SemanticEq for RectFunction
impl SemanticEq for RectFunction
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for RectFunction
impl Serialize for RectFunction
Sourceimpl ToCursors for RectFunction
impl ToCursors for RectFunction
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for RectFunction
impl VisitableMut for RectFunction
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Eq for RectFunction
impl StructuralPartialEq for RectFunction