#[repr(C)]pub struct StrokeLayer<'a> {
pub image: Option<Paint<'a>>,
pub position: Option<Box<'a, PositionAndSize<'a>>>,
pub repeat: Option<RepeatStyle>,
pub origin: Option<FillOrigin>,
pub color: Option<Color<'a>>,
}Expand description
Represents a single layer of the stroke shorthand.
The stroke property is a shorthand for stroke-image, stroke-position,
stroke-size, stroke-repeat, stroke-origin, and stroke-color,
modelled on background’s <bg-layer># grammar the same way fill is
(see FillLayer). The color field is only meaningful on the final
layer, but we parse it permissively on every layer, matching BgLayer’s
approach.
Fields
image: Option<Paint<'a>>position: Option<Box<'a, PositionAndSize<'a>>>repeat: Option<RepeatStyle>origin: Option<FillOrigin>color: Option<Color<'a>>Trait Implementations
Sourceimpl<'a> Clone for StrokeLayer<'a>
impl<'a> Clone for StrokeLayer<'a>
Sourcefn clone(&self) -> StrokeLayer<'a>
fn clone(&self) -> StrokeLayer<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for StrokeLayer<'a>
impl<'a> Debug for StrokeLayer<'a>
Sourceimpl<'a> Hash for StrokeLayer<'a>
impl<'a> Hash for StrokeLayer<'a>
Sourceimpl<'a> NodeWithMetadata<CssMetadata> for StrokeLayer<'a>
impl<'a> NodeWithMetadata<CssMetadata> for StrokeLayer<'a>
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl<'a> Ord for StrokeLayer<'a>
impl<'a> Ord for StrokeLayer<'a>
Sourcefn cmp(&self, other: &StrokeLayer<'a>) -> Ordering
fn cmp(&self, other: &StrokeLayer<'a>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for StrokeLayer<'a>
impl<'a> Parse<'a> for StrokeLayer<'a>
Sourceimpl<'a> PartialEq for StrokeLayer<'a>
impl<'a> PartialEq for StrokeLayer<'a>
Sourcefn eq(&self, other: &StrokeLayer<'a>) -> bool
fn eq(&self, other: &StrokeLayer<'a>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'a> PartialOrd for StrokeLayer<'a>
impl<'a> PartialOrd for StrokeLayer<'a>
Sourceimpl<'a> Peek<'a> for StrokeLayer<'a>
impl<'a> Peek<'a> for StrokeLayer<'a>
Sourceimpl<'a> SemanticEq for StrokeLayer<'a>
impl<'a> SemanticEq for StrokeLayer<'a>
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl<'a> Serialize for StrokeLayer<'a>
impl<'a> Serialize for StrokeLayer<'a>
Sourceimpl<'a> ToCursors for StrokeLayer<'a>
impl<'a> ToCursors for StrokeLayer<'a>
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl<'a> TypeLayout for StrokeLayer<'a>
impl<'a> TypeLayout for StrokeLayer<'a>
const TYPE_LAYOUT: TypeLayoutInfo
Sourceimpl<'a> Visitable for StrokeLayer<'a>
impl<'a> Visitable for StrokeLayer<'a>
Sourceimpl<'a> VisitableMut for StrokeLayer<'a>
impl<'a> VisitableMut for StrokeLayer<'a>
fn accept_mut<__V: VisitMut>(&mut self, v: &mut __V)
impl<'a> Eq for StrokeLayer<'a>
impl<'a> StructuralPartialEq for StrokeLayer<'a>