pub struct TargetName(/* private fields */);Expand description
https://www.w3.org/TR/css3-hyperlinks/#target-name
<target-name> = <string>Trait Implementations
Sourceimpl Clone for TargetName
impl Clone for TargetName
Sourcefn clone(&self) -> TargetName
fn clone(&self) -> TargetName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetName
impl Debug for TargetName
Sourceimpl Default for TargetName
impl Default for TargetName
Sourcefn default() -> TargetName
fn default() -> TargetName
Returns the “default value” for a type. Read more
Sourceimpl From<TargetName> for Cursor
impl From<TargetName> for Cursor
Sourcefn from(value: TargetName) -> Cursor
fn from(value: TargetName) -> Cursor
Converts to this type from the input type.
Sourceimpl From<TargetName> for Token
impl From<TargetName> for Token
Sourcefn from(value: TargetName) -> Token
fn from(value: TargetName) -> Token
Converts to this type from the input type.
Sourceimpl Hash for TargetName
impl Hash for TargetName
Sourceimpl NodeWithMetadata<CssMetadata> for TargetName
impl NodeWithMetadata<CssMetadata> for TargetName
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for TargetName
impl Ord for TargetName
Sourcefn cmp(&self, other: &TargetName) -> Ordering
fn cmp(&self, other: &TargetName) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for TargetName
impl<'a> Parse<'a> for TargetName
Sourceimpl PartialEq for TargetName
impl PartialEq for TargetName
Sourcefn eq(&self, other: &TargetName) -> bool
fn eq(&self, other: &TargetName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TargetName
impl PartialOrd for TargetName
Sourceimpl<'a> Peek<'a> for TargetName
impl<'a> Peek<'a> for TargetName
Sourceimpl SemanticEq for TargetName
impl SemanticEq for TargetName
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for TargetName
impl Serialize for TargetName
Sourceimpl ToCursors for TargetName
impl ToCursors for TargetName
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl TypeLayout for TargetName
impl TypeLayout for TargetName
const TYPE_LAYOUT: TypeLayoutInfo
Sourceimpl VisitableMut for TargetName
impl VisitableMut for TargetName
fn accept_mut<__V: VisitMut>(&mut self, v: &mut __V)
impl Copy for TargetName
impl Eq for TargetName
impl StructuralPartialEq for TargetName