pub struct VariationTagValue(pub OpentypeTag, pub Number);Expand description
Value for font-variation-settings: <opentype-tag> <number>
<opentype-tag> <number>Tuple Fields
0: OpentypeTag1: NumberTrait Implementations
Sourceimpl Clone for VariationTagValue
impl Clone for VariationTagValue
Sourcefn clone(&self) -> VariationTagValue
fn clone(&self) -> VariationTagValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VariationTagValue
impl Debug for VariationTagValue
Sourceimpl Hash for VariationTagValue
impl Hash for VariationTagValue
Sourceimpl NodeWithMetadata<CssMetadata> for VariationTagValue
impl NodeWithMetadata<CssMetadata> for VariationTagValue
Sourcefn self_metadata(&self) -> CssMetadata
fn self_metadata(&self) -> CssMetadata
Returns the metadata contributed by this node itself, not including children.
Most nodes don’t contribute metadata, so can simply return
M::default().
Nodes like StyleRule or AtRules should return their own node kind flags here.Sourcefn metadata(&self) -> CssMetadata
fn metadata(&self) -> CssMetadata
Returns the complete aggregated metadata for this node (self + children).
Default implementation merges children’s metadata with self_metadata().
Sourceimpl Ord for VariationTagValue
impl Ord for VariationTagValue
Sourcefn cmp(&self, other: &VariationTagValue) -> Ordering
fn cmp(&self, other: &VariationTagValue) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a> Parse<'a> for VariationTagValue
impl<'a> Parse<'a> for VariationTagValue
Sourceimpl PartialEq for VariationTagValue
impl PartialEq for VariationTagValue
Sourceimpl PartialOrd for VariationTagValue
impl PartialOrd for VariationTagValue
Sourceimpl<'a> Peek<'a> for VariationTagValue
impl<'a> Peek<'a> for VariationTagValue
Sourceimpl SemanticEq for VariationTagValue
impl SemanticEq for VariationTagValue
Sourcefn semantic_eq(&self, other: &Self) -> bool
fn semantic_eq(&self, other: &Self) -> bool
Returns
true if self and other are semantically equal.Sourceimpl Serialize for VariationTagValue
impl Serialize for VariationTagValue
Sourceimpl ToCursors for VariationTagValue
impl ToCursors for VariationTagValue
fn to_cursors(&self, s: &mut impl CursorSink)
Sourceimpl VisitableMut for VariationTagValue
impl VisitableMut for VariationTagValue
fn accept_mut<V: VisitMut>(&mut self, v: &mut V)
impl Eq for VariationTagValue
impl StructuralPartialEq for VariationTagValue