pub enum NodeId {
Show 983 variants
RowRuleInsetCapStartStyleValue = 0,
BorderStyleStyleValue = 1,
RowRuleInsetJunctionEndStyleValue = 2,
BoxShadowStyleValue = 3,
GapStyleValue = 4,
StrokePositionStyleValue = 5,
VerticalAlignStyleValue = 6,
TextDecorationSkipBoxStyleValue = 7,
ScrollStateQuery = 8,
TextTransformStyleValue = 9,
PartPseudoElement = 10,
ContentDistribution = 11,
OverflowClipMarginBlockStartStyleValue = 12,
TabSizeStyleValue = 13,
OPseudoElement = 14,
BorderStartStartRadiusStyleValue = 15,
GlyphOrientationVerticalStyleValue = 16,
SepiaFunction = 17,
VoiceDurationStyleValue = 18,
FlowIntoStyleValue = 19,
BorderRightStyleStyleValue = 20,
ContainerNameStyleValue = 21,
ContainIntrinsicHeightStyleValue = 22,
Keyframe = 23,
ColorInterpolationMethod = 24,
TextJustifyStyleValue = 25,
Percentage = 26,
ImageAnimationStyleValue = 27,
CaretAnimationStyleValue = 28,
HueInterpolationMethod = 29,
ContainerQuery = 30,
StrokeAlignStyleValue = 31,
MarginRule = 32,
ListStylePositionStyleValue = 33,
ScrollSnapTypeStyleValue = 34,
MozOsVersionMediaFeature = 35,
KeyframesRule = 36,
CornerBottomLeftShapeStyleValue = 37,
PaddingRightStyleValue = 38,
SyntaxValue = 39,
MsViewStateMediaFeature = 40,
BorderCollapseStyleValue = 41,
FlexStyleValue = 42,
TextFitStyleValue = 43,
BorderBottomWidthStyleValue = 44,
MsImeAlignMediaFeature = 45,
InitialLetterStyleValue = 46,
WebkitDevicePixelRatioMediaFeature = 47,
BoxShadowSpreadStyleValue = 48,
OutlineStyleValue = 49,
RotatexFunction = 50,
ScrollBehaviorStyleValue = 51,
FontFamilyName = 52,
VisibilityStyleValue = 53,
BorderTopStyleStyleValue = 54,
AnchorScopeStyleValue = 55,
CornerLeftShapeStyleValue = 56,
FontWeightAbsolute = 57,
RuleVisibilityItemsStyleValue = 58,
RgbaFunction = 59,
BorderSpacingStyleValue = 60,
MediaRule = 61,
EventTriggerNameStyleValue = 62,
BlurFunction = 63,
InsetStyleValue = 64,
LeftStyleValue = 65,
ShapePaddingStyleValue = 66,
IsolationMode = 67,
SingleAnimationPlayState = 68,
ColumnFillStyleValue = 69,
HyphenateLimitLinesStyleValue = 70,
ViewTransitionScopeStyleValue = 71,
TransitionDelayStyleValue = 72,
RowRuleInsetJunctionStyleValue = 73,
BackgroundRepeatStyleValue = 74,
ShapeImageThresholdStyleValue = 75,
BorderInlineStartColorStyleValue = 76,
ContainerRule = 77,
GridLine = 78,
BorderInlineEndClipStyleValue = 79,
TextBoxEdgeStyleValue = 80,
MediaPreCondition = 81,
MinIntrinsicSizingStyleValue = 82,
TimelineScopeStyleValue = 83,
MixBlendModeStyleValue = 84,
VerticalViewportSegmentsMediaFeature = 85,
ContentListItem = 86,
DocumentRule = 87,
AutoLineWidthList = 88,
NthColPseudoFunction = 89,
GridAutoFlowStyleValue = 90,
BorderInlineColorStyleValue = 91,
FontSynthesisStyleStyleValue = 92,
LineWidth = 93,
DynamicRangeMediaFeature = 94,
LchFunctionParams = 95,
ViewTimelineInsetStyleValue = 96,
FlowToleranceStyleValue = 97,
WebkitVideoPlayableInlineMediaFeature = 98,
Flex = 99,
BackgroundRepeatInlineStyleValue = 100,
WebkitPseudoClass = 101,
EventTriggerEvent = 102,
MediaType = 103,
BlockStepInsertStyleValue = 104,
ScrollPaddingInlineEndStyleValue = 105,
HeadingPseudoFunction = 106,
TransitionPropertyStyleValue = 107,
PrefersContrastMediaFeature = 108,
ColumnRuleWidthStyleValue = 109,
NamespaceRule = 110,
ScanMediaFeature = 111,
CounterSetStyleValue = 112,
RectangularColorSpace = 113,
HighlightPseudoElement = 114,
CounterIncrementStyleValue = 115,
TimelineTriggerActivationRangeStartStyleValue = 116,
BorderRightWidthStyleValue = 117,
FontSynthesisWeightStyleValue = 118,
CueBeforeStyleValue = 119,
ColumnRuleInsetCapStyleValue = 120,
MaskPositionStyleValue = 121,
WrapAfterStyleValue = 122,
PositionAnchorStyleValue = 123,
PrefersColorSchemeMediaFeature = 124,
WebkitAnimationDurationStyleValue = 125,
ClearStyleValue = 126,
HostPseudoFunction = 127,
RowRuleInsetEndStyleValue = 128,
Length = 129,
StringFunction = 130,
BorderInlineStyleStyleValue = 131,
SlottedPseudoElement = 132,
BorderInlineStartClipStyleValue = 133,
ViewTransitionNewPseudoElement = 134,
WebkitBackfaceVisibilityStyleValue = 135,
Color = 136,
WebkitTransformStyleValue = 137,
ColumnRuleInsetJunctionStartStyleValue = 138,
HostContextPseudoFunction = 139,
RowRuleVisibilityItemsStyleValue = 140,
BreakAfterStyleValue = 141,
ColumnHeightStyleValue = 142,
ReadingOrderStyleValue = 143,
TransitionBehaviorStyleValue = 144,
AnchorNameStyleValue = 145,
LabFunction = 146,
TextDecorationSkipInkStyleValue = 147,
RepeatStyle = 148,
ImageRenderingStyleValue = 149,
PaddingTopStyleValue = 150,
BorderLeftColorStyleValue = 151,
Gradient = 152,
StrokeDashJustifyStyleValue = 153,
DynamicRangeLimitMixFunction = 154,
NavControlsMediaFeature = 155,
WrapThroughStyleValue = 156,
ScrollPaddingBottomStyleValue = 157,
InlineSizingStyleValue = 158,
BreakBeforeStyleValue = 159,
LayerName = 160,
RubyOverhangStyleValue = 161,
BorderBlockStyleValue = 162,
OverflowAnchorStyleValue = 163,
InlineSizeStyleValue = 164,
AllStyleValue = 165,
MaskClipStyleValue = 166,
PageSelector = 167,
TextDecorationThicknessStyleValue = 168,
LineSnapStyleValue = 169,
RelativeSize = 170,
BlockStepRoundStyleValue = 171,
MsPseudoElement = 172,
TextDecorationSkipStyleValue = 173,
AttrFunction = 174,
SingleAnimationTimeline = 175,
MarginStyleValue = 176,
WebkitTransitionDurationStyleValue = 177,
MaskBorderOutsetStyleValue = 178,
SelectorList = 179,
OverflowPosition = 180,
SystemStyleValue = 181,
VoiceBalanceStyleValue = 182,
HoverMediaFeature = 183,
KeypressFunction = 184,
WherePseudoFunction = 185,
JustifyItemsStyleValue = 186,
TranslateStyleValue = 187,
RowRuleBreakStyleValue = 188,
CornerTopLeftShapeStyleValue = 189,
HslFunction = 190,
TranslatezFunction = 191,
MaskBorderModeStyleValue = 192,
TextDecorationStyleStyleValue = 193,
CustomIdent = 194,
WebkitTransform2dMediaFeature = 195,
InheritsValue = 196,
OpacityStyleValue = 197,
FontVariantPositionStyleValue = 198,
TimelineTriggerActivationRangeEndStyleValue = 199,
BackgroundOriginStyleValue = 200,
StripesFunction = 201,
BackgroundImageStyleValue = 202,
ScrollPaddingInlineStartStyleValue = 203,
UnicodeBidiStyleValue = 204,
BoxShadowOffsetStyleValue = 205,
RowRuleStyleStyleValue = 206,
MarginInlineStyleValue = 207,
ViewTransitionGroupStyleValue = 208,
FillOpacityStyleValue = 209,
RuleBreakStyleValue = 210,
GridRowStyleValue = 211,
FieldSizingStyleValue = 212,
ColorMixFunction = 213,
InterestDelayEndStyleValue = 214,
PerspectiveOriginStyleValue = 215,
PaddingInlineStyleValue = 216,
BackfaceVisibilityStyleValue = 217,
BorderRightStyleValue = 218,
FlexGrowStyleValue = 219,
OffsetDistanceStyleValue = 220,
BorderClipStyleValue = 221,
ScrollMarginBlockStyleValue = 222,
FontFaceRule = 223,
SingleTransitionProperty = 224,
TextGroupAlignStyleValue = 225,
ScrollMarginInlineStartStyleValue = 226,
ZoomStyleValue = 227,
ViewTransitionNameStyleValue = 228,
ImportLayer = 229,
TransformBoxStyleValue = 230,
TimelineTriggerSourceStyleValue = 231,
Repetition = 232,
AspectRatioStyleValue = 233,
ColumnRuleStyleValue = 234,
CounterStyleRule = 235,
FillOriginStyleValue = 236,
TextAutospaceStyleValue = 237,
PointerTimelineStyleValue = 238,
TextCombineUprightStyleValue = 239,
NthOfTypePseudoFunction = 240,
ColumnRuleInsetStyleValue = 241,
RgbFunctionParams = 242,
DisplayStyleValue = 243,
TextAlignAllStyleValue = 244,
FontSizeStyleValue = 245,
ColorFunctionColor = 246,
TransformStyleStyleValue = 247,
BorderLeftRadiusStyleValue = 248,
LightingColorStyleValue = 249,
TextBoxTrimStyleValue = 250,
GrayscaleFunction = 251,
SkewFunction = 252,
ColorStyleValue = 253,
Translate3dFunction = 254,
ImageOrientationStyleValue = 255,
RuleInsetStyleValue = 256,
AccentColorStyleValue = 257,
LineStyle = 258,
TransitionTimingFunctionStyleValue = 259,
LineHeightStepStyleValue = 260,
BorderBoundaryStyleValue = 261,
WrapBeforeStyleValue = 262,
InterpolationColorSpace = 263,
RegionFragmentStyleValue = 264,
TextDecorationLineStyleValue = 265,
EmptyCellsStyleValue = 266,
ColorGamutMediaFeature = 267,
BlockStepSizeStyleValue = 268,
ScaleFunction = 269,
BorderBlockClipStyleValue = 270,
CharsetRule = 271,
RowRuleInsetCapEndStyleValue = 272,
SpeakStyleValue = 273,
FilterFunction = 274,
BorderInlineWidthStyleValue = 275,
GridMediaFeature = 276,
PaddingBlockStartStyleValue = 277,
VideoDynamicRangeMediaFeature = 278,
BaselinePosition = 279,
OverflowClipMarginLeftStyleValue = 280,
BlockEllipsisStyleValue = 281,
OverflowInlineStyleValue = 282,
CounterName = 283,
WebkitTransitionStyleValue = 284,
BackgroundBlendModeStyleValue = 285,
FloatOffsetStyleValue = 286,
BorderImageRepeatStyleValue = 287,
InterestDelayStyleValue = 288,
ScrollPaddingBlockStartStyleValue = 289,
ContentVisibilityStyleValue = 290,
StrokeSizeStyleValue = 291,
TimelineTriggerActiveRangeStartStyleValue = 292,
ColumnRuleInsetStartStyleValue = 293,
RepeatFunction = 294,
StrokeOriginStyleValue = 295,
NamedColor = 296,
HeightStyleValue = 297,
RuleStyleStyleValue = 298,
UrlOrString = 299,
SymbolsFunctionParams = 300,
WidthStyleValue = 301,
ScrollMarkerGroupStyleValue = 302,
NthLastChildPseudoFunction = 303,
DashedIdent = 304,
FontStyleStyleValue = 305,
RowGapStyleValue = 306,
TranslateyFunction = 307,
CornerTopShapeStyleValue = 308,
StrokeLinejoinStyleValue = 309,
RubyAlignStyleValue = 310,
BorderInlineEndStyleStyleValue = 311,
WebkitPseudoElement = 312,
AnimationDirectionStyleValue = 313,
WebkitOrderStyleValue = 314,
GridAutoColumnsStyleValue = 315,
BorderLeftStyleStyleValue = 316,
ContentPosition = 317,
RestStyleValue = 318,
CursorImage = 319,
BorderLeftClipStyleValue = 320,
FontLanguageOverrideStyleValue = 321,
RowRuleInsetJunctionStartStyleValue = 322,
OverscrollBehaviorYStyleValue = 323,
EventTriggerSourceStyleValue = 324,
SupportsCondition = 325,
PseudoClass = 326,
StrokeDashCornerStyleValue = 327,
RotatezFunction = 328,
NegativeStyleValue = 329,
MathmlTag = 330,
MozPseudoElement = 331,
PaddingInlineEndStyleValue = 332,
Ratio = 333,
Image1d = 334,
OverflowClipMarginInlineEndStyleValue = 335,
MsColumnCountMediaFeature = 336,
RuleInsetCapStyleValue = 337,
ScrollInitialTargetStyleValue = 338,
BorderBlockWidthStyleValue = 339,
ContainerTypeStyleValue = 340,
ContainIntrinsicInlineSizeStyleValue = 341,
NthChildPseudoFunction = 342,
ContainIntrinsicBlockSizeStyleValue = 343,
AttributeModifier = 344,
HangingPunctuationStyleValue = 345,
GapRuleOrRepeat = 346,
ClipRuleStyleValue = 347,
BorderInlineEndRadiusStyleValue = 348,
GridRowEndStyleValue = 349,
PaddingBlockStyleValue = 350,
WebkitAppearanceStyleValue = 351,
StrokeDasharrayStyleValue = 352,
LineWidthOrRepeat = 353,
MarginInlineStartStyleValue = 354,
BorderBlockStartStyleStyleValue = 355,
PickerPseudoElement = 356,
BorderWidthStyleValue = 357,
TranslateFunction = 358,
LabFunctionParams = 359,
MarginLeftStyleValue = 360,
StrokeLinecapStyleValue = 361,
PauseBeforeStyleValue = 362,
TextBoxStyleValue = 363,
PaddingBlockEndStyleValue = 364,
SymbolsFunction = 365,
VoiceStressStyleValue = 366,
WebkitTapHighlightColorStyleValue = 367,
FillSizeStyleValue = 368,
MaxBlockSizeStyleValue = 369,
EventTriggerStyleValue = 370,
RowRuleInsetStartStyleValue = 371,
MarginBlockStartStyleValue = 372,
HorizontalViewportSegmentsMediaFeature = 373,
AttributeOperator = 374,
ScrollPaddingBlockStyleValue = 375,
ColumnSpanStyleValue = 376,
TimelineTriggerStyleValue = 377,
PaddingBottomStyleValue = 378,
BorderBlockEndStyleValue = 379,
CornerStartStartShapeStyleValue = 380,
FlexDirectionStyleValue = 381,
VoiceRateStyleValue = 382,
OverscrollBehaviorBlockStyleValue = 383,
TextEmphasisPositionStyleValue = 384,
TextSpacingTrimStyleValue = 385,
OverflowYStyleValue = 386,
BorderRightClipStyleValue = 387,
AnimationAction = 388,
TransitionDurationStyleValue = 389,
MaxWidthStyleValue = 390,
StyleValue = 391,
RowRuleStyleValue = 392,
EnvironmentBlendingMediaFeature = 393,
StrokeDashoffsetStyleValue = 394,
InteractivityStyleValue = 395,
BgClip = 396,
RadialGradientFunction = 397,
PropertyPrelude = 398,
ColorMediaFeature = 399,
AnimationTimelineStyleValue = 400,
PolarColorSpace = 401,
OverflowClipMarginTopStyleValue = 402,
WebkitFilterStyleValue = 403,
OverflowInlineMediaFeature = 404,
NumberPercentage = 405,
TextShadowStyleValue = 406,
AnimationTriggerStyleValue = 407,
ScrollPaddingInlineStyleValue = 408,
HslFunctionParams = 409,
TransformStyleValue = 410,
FloatStyleValue = 411,
CornerInlineEndShapeStyleValue = 412,
ImageSetFunction = 413,
RgbFunction = 414,
PlaceItemsStyleValue = 415,
LineWidthList = 416,
BorderBlockEndRadiusStyleValue = 417,
RuleWidthStyleValue = 418,
MarginTopStyleValue = 419,
SingleAnimationDirection = 420,
ContainIntrinsicWidthStyleValue = 421,
AnimationNameStyleValue = 422,
OutlineColorStyleValue = 423,
SingleTransition = 424,
CubicBezierFunction = 425,
AspectRatioContainerFeature = 426,
VideoColorGamutMediaFeature = 427,
BorderBlockStartStyleValue = 428,
RunningStyleValue = 429,
FontFamilyStyleValue = 430,
OrientationContainerFeature = 431,
CounterFunction = 432,
TriggerScopeStyleValue = 433,
DisplayModeMediaFeature = 434,
TopStyleValue = 435,
TransitionStyleValue = 436,
ImportRule = 437,
Namespace = 438,
HyphenateCharacterStyleValue = 439,
TransformList = 440,
PointerEventsStyleValue = 441,
PadStyleValue = 442,
BorderBlockEndClipStyleValue = 443,
MozDocumentRule = 444,
OverflowClipMarginInlineStartStyleValue = 445,
ScrollPaddingLeftStyleValue = 446,
Image = 447,
FrameSizingStyleValue = 448,
ContainerStyleValue = 449,
RuleStyleValue = 450,
MinHeightStyleValue = 451,
CountersFunction = 452,
CueAfterStyleValue = 453,
ColorSpace = 454,
PerspectiveStyleValue = 455,
FontSynthesisSmallCapsStyleValue = 456,
PositionTryOrderStyleValue = 457,
BorderEndStartRadiusStyleValue = 458,
NthLastColPseudoFunction = 459,
RestBeforeStyleValue = 460,
AbsoluteSize = 461,
ScrollTimelineAxisStyleValue = 462,
TextDecorationSkipSelfStyleValue = 463,
PseudoElement = 464,
AnchorName = 465,
HueRotateFunction = 466,
BorderTopClipStyleValue = 467,
ScaleyFunction = 468,
ParamFunction = 469,
FillBreakStyleValue = 470,
BorderTopColorStyleValue = 471,
WordWrapStyleValue = 472,
MozMaemoClassicMediaFeature = 473,
ScrollPaddingBlockEndStyleValue = 474,
SpatialNavigationFunctionStyleValue = 475,
TransformFunction = 476,
SingleAnimationIterationCount = 477,
AnimationDurationStyleValue = 478,
OverflowClipMarginInlineStyleValue = 479,
ScrollSnapStopStyleValue = 480,
ColumnRuleStyleStyleValue = 481,
ColumnsStyleValue = 482,
ContentFunction = 483,
BorderTopLeftRadiusStyleValue = 484,
ScalezFunction = 485,
SingleAnimationTriggerBehavior = 486,
MsPseudoClass = 487,
PrefersReducedMotionMediaFeature = 488,
Attribute = 489,
OverflowWrapStyleValue = 490,
TimelineRangeName = 491,
KeyframesName = 492,
ListStyleTypeStyleValue = 493,
BorderLeftWidthStyleValue = 494,
WhiteSpaceTrimStyleValue = 495,
Combinator = 496,
PrefixStyleValue = 497,
MozFunctionalPseudoElement = 498,
TrySize = 499,
HslaFunction = 500,
LchFunction = 501,
TextAlignStyleValue = 502,
ScrollMarginRightStyleValue = 503,
SystemColor = 504,
MozDeviceOrientationMediaFeature = 505,
BreakInsideStyleValue = 506,
MatrixFunction = 507,
ScrollTimelineNameStyleValue = 508,
PageRule = 509,
FloatDeferStyleValue = 510,
TargetCounterFunction = 511,
ForcedColorsMediaFeature = 512,
FontVariantCapsStyleValue = 513,
WebkitDistrubutedFunctionalPseudoElement = 514,
OPseudoClass = 515,
SymbolsStyleValue = 516,
RuleInsetJunctionStyleValue = 517,
WidowsStyleValue = 518,
WebkitFlexStyleValue = 519,
InsetBlockEndStyleValue = 520,
RestAfterStyleValue = 521,
TextUnderlineOffsetStyleValue = 522,
InsetBlockStyleValue = 523,
JustifySelfStyleValue = 524,
RowRuleColorStyleValue = 525,
StyleRule = 526,
HtmlTag = 527,
BlockSizeStyleValue = 528,
ScrollMarginInlineEndStyleValue = 529,
TimelineTriggerActiveRangeEndStyleValue = 530,
RotateyFunction = 531,
SvgTag = 532,
SupportsFeature = 533,
WebkitAnimationIterationCountStyleValue = 534,
ResizeStyleValue = 535,
HueInterpolationDirection = 536,
RightStyleValue = 537,
FillRepeatStyleValue = 538,
TextDecorationSkipSpacesStyleValue = 539,
DominantBaselineStyleValue = 540,
BorderBlockStyleStyleValue = 541,
CaptionSideStyleValue = 542,
AnimationPlayStateStyleValue = 543,
LegacyPseudoElement = 544,
AnimationTimingFunctionStyleValue = 545,
ListStyleStyleValue = 546,
WrapInsideStyleValue = 547,
AnimationRangeStyleValue = 548,
PropertyRuleStyleValue = 549,
ScriptingMediaFeature = 550,
ImportSupportsFunction = 551,
BorderBottomClipStyleValue = 552,
TextWrapModeStyleValue = 553,
MarginRightStyleValue = 554,
FootnotePolicyStyleValue = 555,
BorderInlineEndColorStyleValue = 556,
ScrollTimelineStyleValue = 557,
InitialLetterWrapStyleValue = 558,
BorderStyleValue = 559,
OutlineStyleStyleValue = 560,
CounterStyleRuleStyleValue = 561,
ColumnRuleInsetCapEndStyleValue = 562,
StatePseudoFunction = 563,
ViewTimelineNameStyleValue = 564,
InsetInlineStyleValue = 565,
UnknownTag = 566,
ColumnRuleColorStyleValue = 567,
TimelineTriggerNameStyleValue = 568,
GridAutoRowsStyleValue = 569,
DocumentMatcher = 570,
AdditiveSymbolsStyleValue = 571,
BorderLimitStyleValue = 572,
MarginInlineEndStyleValue = 573,
MinWidthStyleValue = 574,
MsDevicePixelRatioMediaFeature = 575,
BackgroundClipStyleValue = 576,
BorderImageOutsetStyleValue = 577,
PositionVisibilityStyleValue = 578,
ScrollPaddingRightStyleValue = 579,
BlockSizeContainerFeature = 580,
WebkitKeyframesRule = 581,
ScrollMarginBottomStyleValue = 582,
AnimationRangeStartStyleValue = 583,
PauseStyleValue = 584,
RubyMergeStyleValue = 585,
ScrollStateFeature = 586,
FlexLineCountStyleValue = 587,
TableLayoutStyleValue = 588,
MaskSizeStyleValue = 589,
WebkitAnimationFillModeStyleValue = 590,
FontFeatureSettingsStyleValue = 591,
MozDevicePixelRatioMediaFeature = 592,
GridAreaStyleValue = 593,
ColumnGapStyleValue = 594,
DirectionStyleValue = 595,
HyphenateLimitZoneStyleValue = 596,
BorderRightColorStyleValue = 597,
FlowFromStyleValue = 598,
MaxInlineSizeStyleValue = 599,
BorderBottomRightRadiusStyleValue = 600,
WidthContainerFeature = 601,
BorderRightRadiusStyleValue = 602,
FontSynthesisPositionStyleValue = 603,
FlexWrapStyleValue = 604,
BaselineMetric = 605,
StrokeWidthStyleValue = 606,
LetterSpacingStyleValue = 607,
SuffixStyleValue = 608,
CalcSizeFunction = 609,
MarginBlockEndStyleValue = 610,
ScrollMarginLeftStyleValue = 611,
ShapeMarginStyleValue = 612,
OklabFunction = 613,
PaddingLeftStyleValue = 614,
MonochromeMediaFeature = 615,
BoxShadowBlurStyleValue = 616,
FitContentFunction = 617,
PerspectiveFunction = 618,
KeyframesRuleBlock = 619,
TargetCountersFunction = 620,
RepeatingLinearGradientFunction = 621,
LinkParametersStyleValue = 622,
CursorStyleValue = 623,
CueStyleValue = 624,
MarginBlockStyleValue = 625,
OverflowStyleValue = 626,
WordSpaceTransformStyleValue = 627,
AlignmentBaselineStyleValue = 628,
FunctionalPseudoElement = 629,
HtmlNonStandardTag = 630,
MaxLinesStyleValue = 631,
BorderBottomRadiusStyleValue = 632,
AnimationCompositionStyleValue = 633,
BoxDecorationBreakStyleValue = 634,
ScrollbarGutterStyleValue = 635,
MaskBorderSourceStyleValue = 636,
QuotesStyleValue = 637,
Id = 638,
JustifyContentStyleValue = 639,
PrefersReducedTransparencyMediaFeature = 640,
TextUnderlinePositionStyleValue = 641,
PrefersReducedDataMediaFeature = 642,
ColumnWidthStyleValue = 643,
DirPseudoFunction = 644,
BorderLeftStyleValue = 645,
StartingStyleRule = 646,
LinePaddingStyleValue = 647,
MozTouchEnabledMediaFeature = 648,
FlexBasisStyleValue = 649,
ColumnRuleInsetJunctionStyleValue = 650,
MaxHeightStyleValue = 651,
LengthPercentage = 652,
StyleQuery = 653,
OverflowClipMarginRightStyleValue = 654,
ColorInterpolationFiltersStyleValue = 655,
OrderStyleValue = 656,
HyphenateLimitLastStyleValue = 657,
SpatialNavigationContainStyleValue = 658,
StrokeMiterlimitStyleValue = 659,
FilterStyleValue = 660,
OverscrollBehaviorStyleValue = 661,
Time = 662,
ScrollMarginTopStyleValue = 663,
BorderInlineStartRadiusStyleValue = 664,
GridColumnStartStyleValue = 665,
TextIndentStyleValue = 666,
FloodColorStyleValue = 667,
RubyPositionStyleValue = 668,
WebkitLineClampStyleValue = 669,
ListStyleImageStyleValue = 670,
OverflowBlockMediaFeature = 671,
OpacityFunction = 672,
ScrollSnapAlignStyleValue = 673,
BorderInlineEndWidthStyleValue = 674,
SkewxFunction = 675,
OrientationMediaFeature = 676,
PlaceSelfStyleValue = 677,
FillRuleStyleValue = 678,
BorderTopRightRadiusStyleValue = 679,
AnimationIterationCountStyleValue = 680,
IsPseudoFunction = 681,
ColumnWrapStyleValue = 682,
MaskBorderRepeatStyleValue = 683,
FontOpticalSizingStyleValue = 684,
MozImagesInMenusMediaFeature = 685,
BorderBlockStartColorStyleValue = 686,
Quote = 687,
BorderInlineStartStyleStyleValue = 688,
FillPositionStyleValue = 689,
FontVariationSettingsStyleValue = 690,
PointerMediaFeature = 691,
ContainIntrinsicSizeStyleValue = 692,
WebkitAnimationNameStyleValue = 693,
CornerEndEndShapeStyleValue = 694,
HyphenateLimitCharsStyleValue = 695,
PlaceContentStyleValue = 696,
ContainerFeature = 697,
PrintColorAdjustStyleValue = 698,
ContrastFunction = 699,
TextEmphasisSkipStyleValue = 700,
BlockStepAlignStyleValue = 701,
CornerBottomRightShapeStyleValue = 702,
InsetInlineEndStyleValue = 703,
AnyPointerMediaFeature = 704,
MozLocaleDirFunctionalPseudoClass = 705,
PaddingInlineStartStyleValue = 706,
OverscrollBehaviorInlineStyleValue = 707,
CaretColorStyleValue = 708,
AppearanceStyleValue = 709,
BorderEndEndRadiusStyleValue = 710,
ObjectViewBoxStyleValue = 711,
TextDecorationStyleValue = 712,
WebkitFunctionalPseudoElement = 713,
Nth = 714,
TextWrapStyleStyleValue = 715,
HeightContainerFeature = 716,
ScrollPaddingStyleValue = 717,
TargetTextFunction = 718,
CornerShapeValue = 719,
StepsFunction = 720,
TimelineTriggerActivationRangeStyleValue = 721,
OutlineOffsetStyleValue = 722,
BoxSnapStyleValue = 723,
SuperellipseFunction = 724,
ScrollMarginStyleValue = 725,
MsHighContrastMediaFeature = 726,
NthLastOfTypePseudoFunction = 727,
BackdropFilterStyleValue = 728,
SnapInlineFunction = 729,
PositionArea = 730,
InterpolateSizeStyleValue = 731,
StyleSheet = 732,
WordBreakStyleValue = 733,
WebkitTextSizeAdjustStyleValue = 734,
LineBreakStyleValue = 735,
ColumnRuleInsetCapStartStyleValue = 736,
TranslatexFunction = 737,
BorderTopStyleValue = 738,
MaskOriginStyleValue = 739,
StrokeBreakStyleValue = 740,
MarkerSideStyleValue = 741,
HwbFunctionParams = 742,
BlendMode = 743,
CornerInlineStartShapeStyleValue = 744,
TextSizeAdjustStyleValue = 745,
OverflowClipMarginBlockEndStyleValue = 746,
ObjectPositionStyleValue = 747,
Decibel = 748,
FontKerningStyleValue = 749,
SelfPosition = 750,
BoxShadowColorStyleValue = 751,
BackgroundRepeatYStyleValue = 752,
FloatReferenceStyleValue = 753,
BoxShadowPositionStyleValue = 754,
MozMacGraphiteThemeMediaFeature = 755,
BorderBottomLeftRadiusStyleValue = 756,
BrightnessFunction = 757,
BackgroundSizeStyleValue = 758,
Target = 759,
PropertyRule = 760,
WhiteSpaceCollapseStyleValue = 761,
ODevicePixelRatioMediaFeature = 762,
FontWeightStyleValue = 763,
OverflowBlockStyleValue = 764,
ScrollbarWidthStyleValue = 765,
Shadow = 766,
GenericFontFamily = 767,
BgSize = 768,
AlignItemsStyleValue = 769,
TextAlignLastStyleValue = 770,
EasingFunction = 771,
ReadingFlowStyleValue = 772,
AlignContentStyleValue = 773,
RuleOverlapStyleValue = 774,
OverlayStyleValue = 775,
FilterValueList = 776,
CornerBlockStartShapeStyleValue = 777,
SupportsRule = 778,
RotateFunction = 779,
TimelineTriggerActiveRangeStyleValue = 780,
SingleAnimationComposition = 781,
HyphensStyleValue = 782,
RuleColorStyleValue = 783,
PointerTimelineNameStyleValue = 784,
BackgroundRepeatXStyleValue = 785,
StrokeOpacityStyleValue = 786,
CornerShapeStyleValue = 787,
FloodOpacityStyleValue = 788,
BorderBlockColorStyleValue = 789,
CornerEndStartShapeStyleValue = 790,
AnyHoverMediaFeature = 791,
PtNameAndClassSelector = 792,
Matrix3dFunction = 793,
RuleInsetStartStyleValue = 794,
Class = 795,
Scale3dFunction = 796,
LinearFunction = 797,
StrokeColorStyleValue = 798,
BoxSizingStyleValue = 799,
Position = 800,
FlexFlowStyleValue = 801,
BorderTopWidthStyleValue = 802,
LineFitEdgeStyleValue = 803,
InputSecurityStyleValue = 804,
BorderBottomStyleValue = 805,
ScrollTargetGroupStyleValue = 806,
CornerStartEndShapeStyleValue = 807,
BackgroundRepeatBlockStyleValue = 808,
MozFunctionalPseudoClass = 809,
PointerTimelineAxisStyleValue = 810,
WebkitFontSmoothingStyleValue = 811,
CaretStyleValue = 812,
BorderBottomStyleStyleValue = 813,
RuleInsetEndStyleValue = 814,
BottomStyleValue = 815,
OklchFunction = 816,
BackgroundColorStyleValue = 817,
GridColumnEndStyleValue = 818,
BookmarkLevelStyleValue = 819,
OverscrollBehaviorXStyleValue = 820,
InlineSizeContainerFeature = 821,
BorderStartEndRadiusStyleValue = 822,
StrokeRepeatStyleValue = 823,
ColumnCountStyleValue = 824,
WordSpacingStyleValue = 825,
WritingModeStyleValue = 826,
MinInlineSizeStyleValue = 827,
FootnoteDisplayStyleValue = 828,
Angle = 829,
HtmlNonConformingTag = 830,
ContinueStyleValue = 831,
RowRuleWidthStyleValue = 832,
GridColumnStyleValue = 833,
BlockStepStyleValue = 834,
WebkitTransitionMediaFeature = 835,
TextWrapStyleValue = 836,
FillColorStyleValue = 837,
Wildcard = 838,
GapRepeatRule = 839,
OutlineWidthStyleValue = 840,
SnapBlockFunction = 841,
ViewTimelineAxisStyleValue = 842,
BorderBlockEndStyleStyleValue = 843,
FontFaceRuleStyleValue = 844,
ScrollbarColorStyleValue = 845,
UnknownQualifiedRule = 846,
DropShadowFunction = 847,
OffsetPositionStyleValue = 848,
RowRuleInsetCapStyleValue = 849,
InvertFunction = 850,
LineHeightStyleValue = 851,
TextDecorationColorStyleValue = 852,
ScaleStyleValue = 853,
RowRuleInsetStyleValue = 854,
LangPseudoFunction = 855,
BorderInlineStartWidthStyleValue = 856,
DynamicRangeLimitStyleValue = 857,
AnimationDelayStyleValue = 858,
ColumnRuleBreakStyleValue = 859,
LeaderFunction = 860,
MarginTrimStyleValue = 861,
MinBlockSizeStyleValue = 862,
BaselineSourceStyleValue = 863,
CommaOrSlash = 864,
BorderInlineClipStyleValue = 865,
BookmarkLabelStyleValue = 866,
SpeakAsStyleValue = 867,
UnknownAtRule = 868,
ColorFunctionColorParams = 869,
BorderBlockStartRadiusStyleValue = 870,
UserSelectStyleValue = 871,
PositionAreaStyleValue = 872,
BorderRadiusStyleValue = 873,
AttributeValue = 874,
FontSizeAdjustStyleValue = 875,
StyleFeature = 876,
CustomElementTag = 877,
ColumnRuleInsetJunctionEndStyleValue = 878,
OpacityValue = 879,
WebkitTransform3dMediaFeature = 880,
WrapFlowStyleValue = 881,
ScrollMarginInlineStyleValue = 882,
FontVariantEmojiStyleValue = 883,
BorderBlockStartClipStyleValue = 884,
ScalexFunction = 885,
CornerRightShapeStyleValue = 886,
NotPseudoFunction = 887,
AnimationFillModeStyleValue = 888,
BorderBlockEndWidthStyleValue = 889,
WebkitAnyFunctionalPseudoClass = 890,
GridRowStartStyleValue = 891,
MarginBreakStyleValue = 892,
BorderBottomColorStyleValue = 893,
FallbackStyleValue = 894,
CornerBottomShapeStyleValue = 895,
ViewTransitionClassStyleValue = 896,
OffsetRotateStyleValue = 897,
AlignSelfStyleValue = 898,
InvertedColorsMediaFeature = 899,
ColumnRuleInsetEndStyleValue = 900,
ColorIndexMediaFeature = 901,
ColumnRuleVisibilityItemsStyleValue = 902,
InterestDelayStartStyleValue = 903,
ScrollMarginBlockEndStyleValue = 904,
ColorFunction = 905,
MaskTypeStyleValue = 906,
CompoundSelector = 907,
TextEmphasisColorStyleValue = 908,
ObjectFitStyleValue = 909,
Rotate3dFunction = 910,
AnimateableFeature = 911,
ForcedColorAdjustStyleValue = 912,
OffsetAnchorStyleValue = 913,
PositionStyleValue = 914,
OverflowClipMarginBottomStyleValue = 915,
SkewyFunction = 916,
TextDecorationInsetStyleValue = 917,
SpatialNavigationActionStyleValue = 918,
AnimationRangeEndStyleValue = 919,
ViewTransitionImagePairPseudoElement = 920,
ContainStyleValue = 921,
MozPseudoClass = 922,
WebkitAnimationDelayStyleValue = 923,
BaselineShiftStyleValue = 924,
FilterValue = 925,
WebkitAnimationTimingFunctionStyleValue = 926,
ContentList = 927,
RepeatingRadialGradientFunction = 928,
WillChangeStyleValue = 929,
OverflowClipMarginStyleValue = 930,
Tag = 931,
BorderImageSourceStyleValue = 932,
ScrollPaddingTopStyleValue = 933,
CornerBlockEndShapeStyleValue = 934,
MarginBottomStyleValue = 935,
ViewTransitionOldPseudoElement = 936,
WebkitAnimationMediaFeature = 937,
BorderTopRadiusStyleValue = 938,
KeyframeSelector = 939,
BackgroundAttachmentStyleValue = 940,
SaturateFunction = 941,
OverflowXStyleValue = 942,
InsetBlockStartStyleValue = 943,
SliderOrientationStyleValue = 944,
BorderRadius = 945,
BorderInlineStyleValue = 946,
WebkitTransitionTimingFunctionStyleValue = 947,
ColorAdjustStyleValue = 948,
ImportLayerFunction = 949,
HwbFunction = 950,
PageStyleValue = 951,
CounterStyle = 952,
HasPseudoFunction = 953,
PauseAfterStyleValue = 954,
BorderBlockStartWidthStyleValue = 955,
InsetInlineStartStyleValue = 956,
PaddingStyleValue = 957,
SingleAnimationFillMode = 958,
BookmarkStateStyleValue = 959,
BorderInlineStartStyleValue = 960,
FlexShrinkStyleValue = 961,
MaskRepeatStyleValue = 962,
OverflowClipMarginBlockStyleValue = 963,
NumberLength = 964,
ScrollMarginBlockStartStyleValue = 965,
LayerRule = 966,
CornerTopRightShapeStyleValue = 967,
IsolationStyleValue = 968,
OrphansStyleValue = 969,
Url = 970,
LinearGradientFunction = 971,
BorderInlineEndStyleValue = 972,
ViewTransitionGroupPseudoElement = 973,
GridTemplateAreasStyleValue = 974,
BorderBlockEndColorStyleValue = 975,
LineGridStyleValue = 976,
CaretShapeStyleValue = 977,
TextOrientationStyleValue = 978,
LinearFunctionParams = 979,
GapRuleList = 980,
FontSynthesisStyleValue = 981,
FontWidthStyleValue = 982,
}Expand description
Unique identifier for each AST node type that can be queried.
This enum is automatically generated from types that derive Visitable
and have #[visit], #[visit(self)], or #[visit(all)] attributes.
Each variant has a unique discriminant value assigned at build time.
Variants
RowRuleInsetCapStartStyleValue = 0
BorderStyleStyleValue = 1
RowRuleInsetJunctionEndStyleValue = 2
BoxShadowStyleValue = 3
GapStyleValue = 4
StrokePositionStyleValue = 5
VerticalAlignStyleValue = 6
TextDecorationSkipBoxStyleValue = 7
ScrollStateQuery = 8
TextTransformStyleValue = 9
PartPseudoElement = 10
ContentDistribution = 11
OverflowClipMarginBlockStartStyleValue = 12
TabSizeStyleValue = 13
OPseudoElement = 14
BorderStartStartRadiusStyleValue = 15
GlyphOrientationVerticalStyleValue = 16
SepiaFunction = 17
VoiceDurationStyleValue = 18
FlowIntoStyleValue = 19
BorderRightStyleStyleValue = 20
ContainerNameStyleValue = 21
ContainIntrinsicHeightStyleValue = 22
Keyframe = 23
ColorInterpolationMethod = 24
TextJustifyStyleValue = 25
Percentage = 26
ImageAnimationStyleValue = 27
CaretAnimationStyleValue = 28
HueInterpolationMethod = 29
ContainerQuery = 30
StrokeAlignStyleValue = 31
MarginRule = 32
ListStylePositionStyleValue = 33
ScrollSnapTypeStyleValue = 34
MozOsVersionMediaFeature = 35
KeyframesRule = 36
CornerBottomLeftShapeStyleValue = 37
PaddingRightStyleValue = 38
SyntaxValue = 39
MsViewStateMediaFeature = 40
BorderCollapseStyleValue = 41
FlexStyleValue = 42
TextFitStyleValue = 43
BorderBottomWidthStyleValue = 44
MsImeAlignMediaFeature = 45
InitialLetterStyleValue = 46
WebkitDevicePixelRatioMediaFeature = 47
BoxShadowSpreadStyleValue = 48
OutlineStyleValue = 49
RotatexFunction = 50
ScrollBehaviorStyleValue = 51
FontFamilyName = 52
VisibilityStyleValue = 53
BorderTopStyleStyleValue = 54
AnchorScopeStyleValue = 55
CornerLeftShapeStyleValue = 56
FontWeightAbsolute = 57
RuleVisibilityItemsStyleValue = 58
RgbaFunction = 59
BorderSpacingStyleValue = 60
MediaRule = 61
EventTriggerNameStyleValue = 62
BlurFunction = 63
InsetStyleValue = 64
LeftStyleValue = 65
ShapePaddingStyleValue = 66
IsolationMode = 67
SingleAnimationPlayState = 68
ColumnFillStyleValue = 69
HyphenateLimitLinesStyleValue = 70
ViewTransitionScopeStyleValue = 71
TransitionDelayStyleValue = 72
RowRuleInsetJunctionStyleValue = 73
BackgroundRepeatStyleValue = 74
ShapeImageThresholdStyleValue = 75
BorderInlineStartColorStyleValue = 76
ContainerRule = 77
GridLine = 78
BorderInlineEndClipStyleValue = 79
TextBoxEdgeStyleValue = 80
MediaPreCondition = 81
MinIntrinsicSizingStyleValue = 82
TimelineScopeStyleValue = 83
MixBlendModeStyleValue = 84
VerticalViewportSegmentsMediaFeature = 85
ContentListItem = 86
DocumentRule = 87
AutoLineWidthList = 88
NthColPseudoFunction = 89
GridAutoFlowStyleValue = 90
BorderInlineColorStyleValue = 91
FontSynthesisStyleStyleValue = 92
LineWidth = 93
DynamicRangeMediaFeature = 94
LchFunctionParams = 95
ViewTimelineInsetStyleValue = 96
FlowToleranceStyleValue = 97
WebkitVideoPlayableInlineMediaFeature = 98
Flex = 99
BackgroundRepeatInlineStyleValue = 100
WebkitPseudoClass = 101
EventTriggerEvent = 102
MediaType = 103
BlockStepInsertStyleValue = 104
ScrollPaddingInlineEndStyleValue = 105
HeadingPseudoFunction = 106
TransitionPropertyStyleValue = 107
PrefersContrastMediaFeature = 108
ColumnRuleWidthStyleValue = 109
NamespaceRule = 110
ScanMediaFeature = 111
CounterSetStyleValue = 112
RectangularColorSpace = 113
HighlightPseudoElement = 114
CounterIncrementStyleValue = 115
TimelineTriggerActivationRangeStartStyleValue = 116
BorderRightWidthStyleValue = 117
FontSynthesisWeightStyleValue = 118
CueBeforeStyleValue = 119
ColumnRuleInsetCapStyleValue = 120
MaskPositionStyleValue = 121
WrapAfterStyleValue = 122
PositionAnchorStyleValue = 123
PrefersColorSchemeMediaFeature = 124
WebkitAnimationDurationStyleValue = 125
ClearStyleValue = 126
HostPseudoFunction = 127
RowRuleInsetEndStyleValue = 128
Length = 129
StringFunction = 130
BorderInlineStyleStyleValue = 131
SlottedPseudoElement = 132
BorderInlineStartClipStyleValue = 133
ViewTransitionNewPseudoElement = 134
WebkitBackfaceVisibilityStyleValue = 135
Color = 136
WebkitTransformStyleValue = 137
ColumnRuleInsetJunctionStartStyleValue = 138
HostContextPseudoFunction = 139
RowRuleVisibilityItemsStyleValue = 140
BreakAfterStyleValue = 141
ColumnHeightStyleValue = 142
ReadingOrderStyleValue = 143
TransitionBehaviorStyleValue = 144
AnchorNameStyleValue = 145
LabFunction = 146
TextDecorationSkipInkStyleValue = 147
RepeatStyle = 148
ImageRenderingStyleValue = 149
PaddingTopStyleValue = 150
BorderLeftColorStyleValue = 151
Gradient = 152
StrokeDashJustifyStyleValue = 153
DynamicRangeLimitMixFunction = 154
WrapThroughStyleValue = 156
ScrollPaddingBottomStyleValue = 157
InlineSizingStyleValue = 158
BreakBeforeStyleValue = 159
LayerName = 160
RubyOverhangStyleValue = 161
BorderBlockStyleValue = 162
OverflowAnchorStyleValue = 163
InlineSizeStyleValue = 164
AllStyleValue = 165
MaskClipStyleValue = 166
PageSelector = 167
TextDecorationThicknessStyleValue = 168
LineSnapStyleValue = 169
RelativeSize = 170
BlockStepRoundStyleValue = 171
MsPseudoElement = 172
TextDecorationSkipStyleValue = 173
AttrFunction = 174
SingleAnimationTimeline = 175
MarginStyleValue = 176
WebkitTransitionDurationStyleValue = 177
MaskBorderOutsetStyleValue = 178
SelectorList = 179
OverflowPosition = 180
SystemStyleValue = 181
VoiceBalanceStyleValue = 182
HoverMediaFeature = 183
KeypressFunction = 184
WherePseudoFunction = 185
JustifyItemsStyleValue = 186
TranslateStyleValue = 187
RowRuleBreakStyleValue = 188
CornerTopLeftShapeStyleValue = 189
HslFunction = 190
TranslatezFunction = 191
MaskBorderModeStyleValue = 192
TextDecorationStyleStyleValue = 193
CustomIdent = 194
WebkitTransform2dMediaFeature = 195
InheritsValue = 196
OpacityStyleValue = 197
FontVariantPositionStyleValue = 198
TimelineTriggerActivationRangeEndStyleValue = 199
BackgroundOriginStyleValue = 200
StripesFunction = 201
BackgroundImageStyleValue = 202
ScrollPaddingInlineStartStyleValue = 203
UnicodeBidiStyleValue = 204
BoxShadowOffsetStyleValue = 205
RowRuleStyleStyleValue = 206
MarginInlineStyleValue = 207
ViewTransitionGroupStyleValue = 208
FillOpacityStyleValue = 209
RuleBreakStyleValue = 210
GridRowStyleValue = 211
FieldSizingStyleValue = 212
ColorMixFunction = 213
InterestDelayEndStyleValue = 214
PerspectiveOriginStyleValue = 215
PaddingInlineStyleValue = 216
BackfaceVisibilityStyleValue = 217
BorderRightStyleValue = 218
FlexGrowStyleValue = 219
OffsetDistanceStyleValue = 220
BorderClipStyleValue = 221
ScrollMarginBlockStyleValue = 222
FontFaceRule = 223
SingleTransitionProperty = 224
TextGroupAlignStyleValue = 225
ScrollMarginInlineStartStyleValue = 226
ZoomStyleValue = 227
ViewTransitionNameStyleValue = 228
ImportLayer = 229
TransformBoxStyleValue = 230
TimelineTriggerSourceStyleValue = 231
Repetition = 232
AspectRatioStyleValue = 233
ColumnRuleStyleValue = 234
CounterStyleRule = 235
FillOriginStyleValue = 236
TextAutospaceStyleValue = 237
PointerTimelineStyleValue = 238
TextCombineUprightStyleValue = 239
NthOfTypePseudoFunction = 240
ColumnRuleInsetStyleValue = 241
RgbFunctionParams = 242
DisplayStyleValue = 243
TextAlignAllStyleValue = 244
FontSizeStyleValue = 245
ColorFunctionColor = 246
TransformStyleStyleValue = 247
BorderLeftRadiusStyleValue = 248
LightingColorStyleValue = 249
TextBoxTrimStyleValue = 250
GrayscaleFunction = 251
SkewFunction = 252
ColorStyleValue = 253
Translate3dFunction = 254
ImageOrientationStyleValue = 255
RuleInsetStyleValue = 256
AccentColorStyleValue = 257
LineStyle = 258
TransitionTimingFunctionStyleValue = 259
LineHeightStepStyleValue = 260
BorderBoundaryStyleValue = 261
WrapBeforeStyleValue = 262
InterpolationColorSpace = 263
RegionFragmentStyleValue = 264
TextDecorationLineStyleValue = 265
EmptyCellsStyleValue = 266
ColorGamutMediaFeature = 267
BlockStepSizeStyleValue = 268
ScaleFunction = 269
BorderBlockClipStyleValue = 270
CharsetRule = 271
RowRuleInsetCapEndStyleValue = 272
SpeakStyleValue = 273
FilterFunction = 274
BorderInlineWidthStyleValue = 275
GridMediaFeature = 276
PaddingBlockStartStyleValue = 277
VideoDynamicRangeMediaFeature = 278
BaselinePosition = 279
OverflowClipMarginLeftStyleValue = 280
BlockEllipsisStyleValue = 281
OverflowInlineStyleValue = 282
CounterName = 283
WebkitTransitionStyleValue = 284
BackgroundBlendModeStyleValue = 285
FloatOffsetStyleValue = 286
BorderImageRepeatStyleValue = 287
InterestDelayStyleValue = 288
ScrollPaddingBlockStartStyleValue = 289
ContentVisibilityStyleValue = 290
StrokeSizeStyleValue = 291
TimelineTriggerActiveRangeStartStyleValue = 292
ColumnRuleInsetStartStyleValue = 293
RepeatFunction = 294
StrokeOriginStyleValue = 295
NamedColor = 296
HeightStyleValue = 297
RuleStyleStyleValue = 298
UrlOrString = 299
SymbolsFunctionParams = 300
WidthStyleValue = 301
ScrollMarkerGroupStyleValue = 302
NthLastChildPseudoFunction = 303
DashedIdent = 304
FontStyleStyleValue = 305
RowGapStyleValue = 306
TranslateyFunction = 307
CornerTopShapeStyleValue = 308
StrokeLinejoinStyleValue = 309
RubyAlignStyleValue = 310
BorderInlineEndStyleStyleValue = 311
WebkitPseudoElement = 312
AnimationDirectionStyleValue = 313
WebkitOrderStyleValue = 314
GridAutoColumnsStyleValue = 315
BorderLeftStyleStyleValue = 316
ContentPosition = 317
RestStyleValue = 318
CursorImage = 319
BorderLeftClipStyleValue = 320
FontLanguageOverrideStyleValue = 321
RowRuleInsetJunctionStartStyleValue = 322
OverscrollBehaviorYStyleValue = 323
EventTriggerSourceStyleValue = 324
SupportsCondition = 325
PseudoClass = 326
StrokeDashCornerStyleValue = 327
RotatezFunction = 328
NegativeStyleValue = 329
MathmlTag = 330
MozPseudoElement = 331
PaddingInlineEndStyleValue = 332
Ratio = 333
Image1d = 334
OverflowClipMarginInlineEndStyleValue = 335
MsColumnCountMediaFeature = 336
RuleInsetCapStyleValue = 337
ScrollInitialTargetStyleValue = 338
BorderBlockWidthStyleValue = 339
ContainerTypeStyleValue = 340
ContainIntrinsicInlineSizeStyleValue = 341
NthChildPseudoFunction = 342
ContainIntrinsicBlockSizeStyleValue = 343
AttributeModifier = 344
HangingPunctuationStyleValue = 345
GapRuleOrRepeat = 346
ClipRuleStyleValue = 347
BorderInlineEndRadiusStyleValue = 348
GridRowEndStyleValue = 349
PaddingBlockStyleValue = 350
WebkitAppearanceStyleValue = 351
StrokeDasharrayStyleValue = 352
LineWidthOrRepeat = 353
MarginInlineStartStyleValue = 354
BorderBlockStartStyleStyleValue = 355
PickerPseudoElement = 356
BorderWidthStyleValue = 357
TranslateFunction = 358
LabFunctionParams = 359
MarginLeftStyleValue = 360
StrokeLinecapStyleValue = 361
PauseBeforeStyleValue = 362
TextBoxStyleValue = 363
PaddingBlockEndStyleValue = 364
SymbolsFunction = 365
VoiceStressStyleValue = 366
WebkitTapHighlightColorStyleValue = 367
FillSizeStyleValue = 368
MaxBlockSizeStyleValue = 369
EventTriggerStyleValue = 370
RowRuleInsetStartStyleValue = 371
MarginBlockStartStyleValue = 372
HorizontalViewportSegmentsMediaFeature = 373
AttributeOperator = 374
ScrollPaddingBlockStyleValue = 375
ColumnSpanStyleValue = 376
TimelineTriggerStyleValue = 377
PaddingBottomStyleValue = 378
BorderBlockEndStyleValue = 379
CornerStartStartShapeStyleValue = 380
FlexDirectionStyleValue = 381
VoiceRateStyleValue = 382
OverscrollBehaviorBlockStyleValue = 383
TextEmphasisPositionStyleValue = 384
TextSpacingTrimStyleValue = 385
OverflowYStyleValue = 386
BorderRightClipStyleValue = 387
AnimationAction = 388
TransitionDurationStyleValue = 389
MaxWidthStyleValue = 390
StyleValue = 391
RowRuleStyleValue = 392
EnvironmentBlendingMediaFeature = 393
StrokeDashoffsetStyleValue = 394
InteractivityStyleValue = 395
BgClip = 396
RadialGradientFunction = 397
PropertyPrelude = 398
ColorMediaFeature = 399
AnimationTimelineStyleValue = 400
PolarColorSpace = 401
OverflowClipMarginTopStyleValue = 402
WebkitFilterStyleValue = 403
OverflowInlineMediaFeature = 404
NumberPercentage = 405
TextShadowStyleValue = 406
AnimationTriggerStyleValue = 407
ScrollPaddingInlineStyleValue = 408
HslFunctionParams = 409
TransformStyleValue = 410
FloatStyleValue = 411
CornerInlineEndShapeStyleValue = 412
ImageSetFunction = 413
RgbFunction = 414
PlaceItemsStyleValue = 415
LineWidthList = 416
BorderBlockEndRadiusStyleValue = 417
RuleWidthStyleValue = 418
MarginTopStyleValue = 419
SingleAnimationDirection = 420
ContainIntrinsicWidthStyleValue = 421
AnimationNameStyleValue = 422
OutlineColorStyleValue = 423
SingleTransition = 424
CubicBezierFunction = 425
AspectRatioContainerFeature = 426
VideoColorGamutMediaFeature = 427
BorderBlockStartStyleValue = 428
RunningStyleValue = 429
FontFamilyStyleValue = 430
OrientationContainerFeature = 431
CounterFunction = 432
TriggerScopeStyleValue = 433
DisplayModeMediaFeature = 434
TopStyleValue = 435
TransitionStyleValue = 436
ImportRule = 437
Namespace = 438
HyphenateCharacterStyleValue = 439
TransformList = 440
PointerEventsStyleValue = 441
PadStyleValue = 442
BorderBlockEndClipStyleValue = 443
MozDocumentRule = 444
OverflowClipMarginInlineStartStyleValue = 445
ScrollPaddingLeftStyleValue = 446
Image = 447
FrameSizingStyleValue = 448
ContainerStyleValue = 449
RuleStyleValue = 450
MinHeightStyleValue = 451
CountersFunction = 452
CueAfterStyleValue = 453
ColorSpace = 454
PerspectiveStyleValue = 455
FontSynthesisSmallCapsStyleValue = 456
PositionTryOrderStyleValue = 457
BorderEndStartRadiusStyleValue = 458
NthLastColPseudoFunction = 459
RestBeforeStyleValue = 460
AbsoluteSize = 461
ScrollTimelineAxisStyleValue = 462
TextDecorationSkipSelfStyleValue = 463
PseudoElement = 464
AnchorName = 465
HueRotateFunction = 466
BorderTopClipStyleValue = 467
ScaleyFunction = 468
ParamFunction = 469
FillBreakStyleValue = 470
BorderTopColorStyleValue = 471
WordWrapStyleValue = 472
MozMaemoClassicMediaFeature = 473
ScrollPaddingBlockEndStyleValue = 474
TransformFunction = 476
SingleAnimationIterationCount = 477
AnimationDurationStyleValue = 478
OverflowClipMarginInlineStyleValue = 479
ScrollSnapStopStyleValue = 480
ColumnRuleStyleStyleValue = 481
ColumnsStyleValue = 482
ContentFunction = 483
BorderTopLeftRadiusStyleValue = 484
ScalezFunction = 485
SingleAnimationTriggerBehavior = 486
MsPseudoClass = 487
PrefersReducedMotionMediaFeature = 488
Attribute = 489
OverflowWrapStyleValue = 490
TimelineRangeName = 491
KeyframesName = 492
ListStyleTypeStyleValue = 493
BorderLeftWidthStyleValue = 494
WhiteSpaceTrimStyleValue = 495
Combinator = 496
PrefixStyleValue = 497
MozFunctionalPseudoElement = 498
TrySize = 499
HslaFunction = 500
LchFunction = 501
TextAlignStyleValue = 502
ScrollMarginRightStyleValue = 503
SystemColor = 504
MozDeviceOrientationMediaFeature = 505
BreakInsideStyleValue = 506
MatrixFunction = 507
ScrollTimelineNameStyleValue = 508
PageRule = 509
FloatDeferStyleValue = 510
TargetCounterFunction = 511
ForcedColorsMediaFeature = 512
FontVariantCapsStyleValue = 513
WebkitDistrubutedFunctionalPseudoElement = 514
OPseudoClass = 515
SymbolsStyleValue = 516
RuleInsetJunctionStyleValue = 517
WidowsStyleValue = 518
WebkitFlexStyleValue = 519
InsetBlockEndStyleValue = 520
RestAfterStyleValue = 521
TextUnderlineOffsetStyleValue = 522
InsetBlockStyleValue = 523
JustifySelfStyleValue = 524
RowRuleColorStyleValue = 525
StyleRule = 526
HtmlTag = 527
BlockSizeStyleValue = 528
ScrollMarginInlineEndStyleValue = 529
TimelineTriggerActiveRangeEndStyleValue = 530
RotateyFunction = 531
SvgTag = 532
SupportsFeature = 533
WebkitAnimationIterationCountStyleValue = 534
ResizeStyleValue = 535
HueInterpolationDirection = 536
RightStyleValue = 537
FillRepeatStyleValue = 538
TextDecorationSkipSpacesStyleValue = 539
DominantBaselineStyleValue = 540
BorderBlockStyleStyleValue = 541
CaptionSideStyleValue = 542
AnimationPlayStateStyleValue = 543
LegacyPseudoElement = 544
AnimationTimingFunctionStyleValue = 545
ListStyleStyleValue = 546
WrapInsideStyleValue = 547
AnimationRangeStyleValue = 548
PropertyRuleStyleValue = 549
ScriptingMediaFeature = 550
ImportSupportsFunction = 551
BorderBottomClipStyleValue = 552
TextWrapModeStyleValue = 553
MarginRightStyleValue = 554
FootnotePolicyStyleValue = 555
BorderInlineEndColorStyleValue = 556
ScrollTimelineStyleValue = 557
InitialLetterWrapStyleValue = 558
BorderStyleValue = 559
OutlineStyleStyleValue = 560
CounterStyleRuleStyleValue = 561
ColumnRuleInsetCapEndStyleValue = 562
StatePseudoFunction = 563
ViewTimelineNameStyleValue = 564
InsetInlineStyleValue = 565
UnknownTag = 566
ColumnRuleColorStyleValue = 567
TimelineTriggerNameStyleValue = 568
GridAutoRowsStyleValue = 569
DocumentMatcher = 570
AdditiveSymbolsStyleValue = 571
BorderLimitStyleValue = 572
MarginInlineEndStyleValue = 573
MinWidthStyleValue = 574
MsDevicePixelRatioMediaFeature = 575
BackgroundClipStyleValue = 576
BorderImageOutsetStyleValue = 577
PositionVisibilityStyleValue = 578
ScrollPaddingRightStyleValue = 579
BlockSizeContainerFeature = 580
WebkitKeyframesRule = 581
ScrollMarginBottomStyleValue = 582
AnimationRangeStartStyleValue = 583
PauseStyleValue = 584
RubyMergeStyleValue = 585
ScrollStateFeature = 586
FlexLineCountStyleValue = 587
TableLayoutStyleValue = 588
MaskSizeStyleValue = 589
WebkitAnimationFillModeStyleValue = 590
FontFeatureSettingsStyleValue = 591
MozDevicePixelRatioMediaFeature = 592
GridAreaStyleValue = 593
ColumnGapStyleValue = 594
DirectionStyleValue = 595
HyphenateLimitZoneStyleValue = 596
BorderRightColorStyleValue = 597
FlowFromStyleValue = 598
MaxInlineSizeStyleValue = 599
BorderBottomRightRadiusStyleValue = 600
WidthContainerFeature = 601
BorderRightRadiusStyleValue = 602
FontSynthesisPositionStyleValue = 603
FlexWrapStyleValue = 604
BaselineMetric = 605
StrokeWidthStyleValue = 606
LetterSpacingStyleValue = 607
SuffixStyleValue = 608
CalcSizeFunction = 609
MarginBlockEndStyleValue = 610
ScrollMarginLeftStyleValue = 611
ShapeMarginStyleValue = 612
OklabFunction = 613
PaddingLeftStyleValue = 614
MonochromeMediaFeature = 615
BoxShadowBlurStyleValue = 616
FitContentFunction = 617
PerspectiveFunction = 618
KeyframesRuleBlock = 619
TargetCountersFunction = 620
RepeatingLinearGradientFunction = 621
LinkParametersStyleValue = 622
CursorStyleValue = 623
CueStyleValue = 624
MarginBlockStyleValue = 625
OverflowStyleValue = 626
WordSpaceTransformStyleValue = 627
AlignmentBaselineStyleValue = 628
FunctionalPseudoElement = 629
HtmlNonStandardTag = 630
MaxLinesStyleValue = 631
BorderBottomRadiusStyleValue = 632
AnimationCompositionStyleValue = 633
BoxDecorationBreakStyleValue = 634
ScrollbarGutterStyleValue = 635
MaskBorderSourceStyleValue = 636
QuotesStyleValue = 637
Id = 638
JustifyContentStyleValue = 639
PrefersReducedTransparencyMediaFeature = 640
TextUnderlinePositionStyleValue = 641
PrefersReducedDataMediaFeature = 642
ColumnWidthStyleValue = 643
DirPseudoFunction = 644
BorderLeftStyleValue = 645
StartingStyleRule = 646
LinePaddingStyleValue = 647
MozTouchEnabledMediaFeature = 648
FlexBasisStyleValue = 649
ColumnRuleInsetJunctionStyleValue = 650
MaxHeightStyleValue = 651
LengthPercentage = 652
StyleQuery = 653
OverflowClipMarginRightStyleValue = 654
ColorInterpolationFiltersStyleValue = 655
OrderStyleValue = 656
HyphenateLimitLastStyleValue = 657
StrokeMiterlimitStyleValue = 659
FilterStyleValue = 660
OverscrollBehaviorStyleValue = 661
Time = 662
ScrollMarginTopStyleValue = 663
BorderInlineStartRadiusStyleValue = 664
GridColumnStartStyleValue = 665
TextIndentStyleValue = 666
FloodColorStyleValue = 667
RubyPositionStyleValue = 668
WebkitLineClampStyleValue = 669
ListStyleImageStyleValue = 670
OverflowBlockMediaFeature = 671
OpacityFunction = 672
ScrollSnapAlignStyleValue = 673
BorderInlineEndWidthStyleValue = 674
SkewxFunction = 675
OrientationMediaFeature = 676
PlaceSelfStyleValue = 677
FillRuleStyleValue = 678
BorderTopRightRadiusStyleValue = 679
AnimationIterationCountStyleValue = 680
IsPseudoFunction = 681
ColumnWrapStyleValue = 682
MaskBorderRepeatStyleValue = 683
FontOpticalSizingStyleValue = 684
MozImagesInMenusMediaFeature = 685
BorderBlockStartColorStyleValue = 686
Quote = 687
BorderInlineStartStyleStyleValue = 688
FillPositionStyleValue = 689
FontVariationSettingsStyleValue = 690
PointerMediaFeature = 691
ContainIntrinsicSizeStyleValue = 692
WebkitAnimationNameStyleValue = 693
CornerEndEndShapeStyleValue = 694
HyphenateLimitCharsStyleValue = 695
PlaceContentStyleValue = 696
ContainerFeature = 697
PrintColorAdjustStyleValue = 698
ContrastFunction = 699
TextEmphasisSkipStyleValue = 700
BlockStepAlignStyleValue = 701
CornerBottomRightShapeStyleValue = 702
InsetInlineEndStyleValue = 703
AnyPointerMediaFeature = 704
MozLocaleDirFunctionalPseudoClass = 705
PaddingInlineStartStyleValue = 706
OverscrollBehaviorInlineStyleValue = 707
CaretColorStyleValue = 708
AppearanceStyleValue = 709
BorderEndEndRadiusStyleValue = 710
ObjectViewBoxStyleValue = 711
TextDecorationStyleValue = 712
WebkitFunctionalPseudoElement = 713
Nth = 714
TextWrapStyleStyleValue = 715
HeightContainerFeature = 716
ScrollPaddingStyleValue = 717
TargetTextFunction = 718
CornerShapeValue = 719
StepsFunction = 720
TimelineTriggerActivationRangeStyleValue = 721
OutlineOffsetStyleValue = 722
BoxSnapStyleValue = 723
SuperellipseFunction = 724
ScrollMarginStyleValue = 725
MsHighContrastMediaFeature = 726
NthLastOfTypePseudoFunction = 727
BackdropFilterStyleValue = 728
SnapInlineFunction = 729
PositionArea = 730
InterpolateSizeStyleValue = 731
StyleSheet = 732
WordBreakStyleValue = 733
WebkitTextSizeAdjustStyleValue = 734
LineBreakStyleValue = 735
ColumnRuleInsetCapStartStyleValue = 736
TranslatexFunction = 737
BorderTopStyleValue = 738
MaskOriginStyleValue = 739
StrokeBreakStyleValue = 740
MarkerSideStyleValue = 741
HwbFunctionParams = 742
BlendMode = 743
CornerInlineStartShapeStyleValue = 744
TextSizeAdjustStyleValue = 745
OverflowClipMarginBlockEndStyleValue = 746
ObjectPositionStyleValue = 747
Decibel = 748
FontKerningStyleValue = 749
SelfPosition = 750
BoxShadowColorStyleValue = 751
BackgroundRepeatYStyleValue = 752
FloatReferenceStyleValue = 753
BoxShadowPositionStyleValue = 754
MozMacGraphiteThemeMediaFeature = 755
BorderBottomLeftRadiusStyleValue = 756
BrightnessFunction = 757
BackgroundSizeStyleValue = 758
Target = 759
PropertyRule = 760
WhiteSpaceCollapseStyleValue = 761
ODevicePixelRatioMediaFeature = 762
FontWeightStyleValue = 763
OverflowBlockStyleValue = 764
ScrollbarWidthStyleValue = 765
Shadow = 766
GenericFontFamily = 767
BgSize = 768
AlignItemsStyleValue = 769
TextAlignLastStyleValue = 770
EasingFunction = 771
ReadingFlowStyleValue = 772
AlignContentStyleValue = 773
RuleOverlapStyleValue = 774
OverlayStyleValue = 775
FilterValueList = 776
CornerBlockStartShapeStyleValue = 777
SupportsRule = 778
RotateFunction = 779
TimelineTriggerActiveRangeStyleValue = 780
SingleAnimationComposition = 781
HyphensStyleValue = 782
RuleColorStyleValue = 783
PointerTimelineNameStyleValue = 784
BackgroundRepeatXStyleValue = 785
StrokeOpacityStyleValue = 786
CornerShapeStyleValue = 787
FloodOpacityStyleValue = 788
BorderBlockColorStyleValue = 789
CornerEndStartShapeStyleValue = 790
AnyHoverMediaFeature = 791
PtNameAndClassSelector = 792
Matrix3dFunction = 793
RuleInsetStartStyleValue = 794
Class = 795
Scale3dFunction = 796
LinearFunction = 797
StrokeColorStyleValue = 798
BoxSizingStyleValue = 799
Position = 800
FlexFlowStyleValue = 801
BorderTopWidthStyleValue = 802
LineFitEdgeStyleValue = 803
InputSecurityStyleValue = 804
BorderBottomStyleValue = 805
ScrollTargetGroupStyleValue = 806
CornerStartEndShapeStyleValue = 807
BackgroundRepeatBlockStyleValue = 808
MozFunctionalPseudoClass = 809
PointerTimelineAxisStyleValue = 810
WebkitFontSmoothingStyleValue = 811
CaretStyleValue = 812
BorderBottomStyleStyleValue = 813
RuleInsetEndStyleValue = 814
BottomStyleValue = 815
OklchFunction = 816
BackgroundColorStyleValue = 817
GridColumnEndStyleValue = 818
BookmarkLevelStyleValue = 819
OverscrollBehaviorXStyleValue = 820
InlineSizeContainerFeature = 821
BorderStartEndRadiusStyleValue = 822
StrokeRepeatStyleValue = 823
ColumnCountStyleValue = 824
WordSpacingStyleValue = 825
WritingModeStyleValue = 826
MinInlineSizeStyleValue = 827
FootnoteDisplayStyleValue = 828
Angle = 829
HtmlNonConformingTag = 830
ContinueStyleValue = 831
RowRuleWidthStyleValue = 832
GridColumnStyleValue = 833
BlockStepStyleValue = 834
WebkitTransitionMediaFeature = 835
TextWrapStyleValue = 836
FillColorStyleValue = 837
Wildcard = 838
GapRepeatRule = 839
OutlineWidthStyleValue = 840
SnapBlockFunction = 841
ViewTimelineAxisStyleValue = 842
BorderBlockEndStyleStyleValue = 843
FontFaceRuleStyleValue = 844
ScrollbarColorStyleValue = 845
UnknownQualifiedRule = 846
DropShadowFunction = 847
OffsetPositionStyleValue = 848
RowRuleInsetCapStyleValue = 849
InvertFunction = 850
LineHeightStyleValue = 851
TextDecorationColorStyleValue = 852
ScaleStyleValue = 853
RowRuleInsetStyleValue = 854
LangPseudoFunction = 855
BorderInlineStartWidthStyleValue = 856
DynamicRangeLimitStyleValue = 857
AnimationDelayStyleValue = 858
ColumnRuleBreakStyleValue = 859
LeaderFunction = 860
MarginTrimStyleValue = 861
MinBlockSizeStyleValue = 862
BaselineSourceStyleValue = 863
CommaOrSlash = 864
BorderInlineClipStyleValue = 865
BookmarkLabelStyleValue = 866
SpeakAsStyleValue = 867
UnknownAtRule = 868
ColorFunctionColorParams = 869
BorderBlockStartRadiusStyleValue = 870
UserSelectStyleValue = 871
PositionAreaStyleValue = 872
BorderRadiusStyleValue = 873
AttributeValue = 874
FontSizeAdjustStyleValue = 875
StyleFeature = 876
CustomElementTag = 877
ColumnRuleInsetJunctionEndStyleValue = 878
OpacityValue = 879
WebkitTransform3dMediaFeature = 880
WrapFlowStyleValue = 881
ScrollMarginInlineStyleValue = 882
FontVariantEmojiStyleValue = 883
BorderBlockStartClipStyleValue = 884
ScalexFunction = 885
CornerRightShapeStyleValue = 886
NotPseudoFunction = 887
AnimationFillModeStyleValue = 888
BorderBlockEndWidthStyleValue = 889
WebkitAnyFunctionalPseudoClass = 890
GridRowStartStyleValue = 891
MarginBreakStyleValue = 892
BorderBottomColorStyleValue = 893
FallbackStyleValue = 894
CornerBottomShapeStyleValue = 895
ViewTransitionClassStyleValue = 896
OffsetRotateStyleValue = 897
AlignSelfStyleValue = 898
InvertedColorsMediaFeature = 899
ColumnRuleInsetEndStyleValue = 900
ColorIndexMediaFeature = 901
ColumnRuleVisibilityItemsStyleValue = 902
InterestDelayStartStyleValue = 903
ScrollMarginBlockEndStyleValue = 904
ColorFunction = 905
MaskTypeStyleValue = 906
CompoundSelector = 907
TextEmphasisColorStyleValue = 908
ObjectFitStyleValue = 909
Rotate3dFunction = 910
AnimateableFeature = 911
ForcedColorAdjustStyleValue = 912
OffsetAnchorStyleValue = 913
PositionStyleValue = 914
OverflowClipMarginBottomStyleValue = 915
SkewyFunction = 916
TextDecorationInsetStyleValue = 917
AnimationRangeEndStyleValue = 919
ViewTransitionImagePairPseudoElement = 920
ContainStyleValue = 921
MozPseudoClass = 922
WebkitAnimationDelayStyleValue = 923
BaselineShiftStyleValue = 924
FilterValue = 925
WebkitAnimationTimingFunctionStyleValue = 926
ContentList = 927
RepeatingRadialGradientFunction = 928
WillChangeStyleValue = 929
OverflowClipMarginStyleValue = 930
Tag = 931
BorderImageSourceStyleValue = 932
ScrollPaddingTopStyleValue = 933
CornerBlockEndShapeStyleValue = 934
MarginBottomStyleValue = 935
ViewTransitionOldPseudoElement = 936
WebkitAnimationMediaFeature = 937
BorderTopRadiusStyleValue = 938
KeyframeSelector = 939
BackgroundAttachmentStyleValue = 940
SaturateFunction = 941
OverflowXStyleValue = 942
InsetBlockStartStyleValue = 943
SliderOrientationStyleValue = 944
BorderRadius = 945
BorderInlineStyleValue = 946
WebkitTransitionTimingFunctionStyleValue = 947
ColorAdjustStyleValue = 948
ImportLayerFunction = 949
HwbFunction = 950
PageStyleValue = 951
CounterStyle = 952
HasPseudoFunction = 953
PauseAfterStyleValue = 954
BorderBlockStartWidthStyleValue = 955
InsetInlineStartStyleValue = 956
PaddingStyleValue = 957
SingleAnimationFillMode = 958
BookmarkStateStyleValue = 959
BorderInlineStartStyleValue = 960
FlexShrinkStyleValue = 961
MaskRepeatStyleValue = 962
OverflowClipMarginBlockStyleValue = 963
NumberLength = 964
ScrollMarginBlockStartStyleValue = 965
LayerRule = 966
CornerTopRightShapeStyleValue = 967
IsolationStyleValue = 968
OrphansStyleValue = 969
Url = 970
LinearGradientFunction = 971
BorderInlineEndStyleValue = 972
ViewTransitionGroupPseudoElement = 973
GridTemplateAreasStyleValue = 974
BorderBlockEndColorStyleValue = 975
LineGridStyleValue = 976
CaretShapeStyleValue = 977
TextOrientationStyleValue = 978
LinearFunctionParams = 979
GapRuleList = 980
FontSynthesisStyleValue = 981
FontWidthStyleValue = 982
Implementations
Sourceimpl NodeId
impl NodeId
Sourcepub fn to_at_rule_id(self) -> Option<AtRuleId>
pub fn to_at_rule_id(self) -> Option<AtRuleId>
Converts a NodeId to an AtRuleId if the node is an at-rule type.
Returns None for non-at-rule nodes like StyleRule, Declaration, etc.
Sourceimpl NodeId
impl NodeId
Sourcepub const fn tag_name(self) -> &'static str
pub const fn tag_name(self) -> &'static str
Returns the kebab-case tag name for this node type.
This is used in selector matching (e.g., “style-rule”, “declaration”).
Sourcepub fn from_tag_name(name: &str) -> Option<Self>
pub fn from_tag_name(name: &str) -> Option<Self>
Attempts to parse a tag name string into a NodeId.
Returns None if the tag name doesn’t match any known node type.
Sourcepub fn all_variants() -> impl Iterator<Item = Self>
pub fn all_variants() -> impl Iterator<Item = Self>
Returns an iterator over all possible NodeId values.