pub type Cursor = Cursor<Token>;Aliased Type
pub struct Cursor(/* private fields */);Trait Implementations
Sourceimpl PartialEq<AssociatedWhitespaceRules> for Cursor
impl PartialEq<AssociatedWhitespaceRules> for Cursor
Sourcefn eq(&self, other: &AssociatedWhitespaceRules) -> bool
fn eq(&self, other: &AssociatedWhitespaceRules) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<CommentStyle> for &Cursor
impl PartialEq<CommentStyle> for &Cursor
Sourcefn eq(&self, other: &CommentStyle) -> bool
fn eq(&self, other: &CommentStyle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<CommentStyle> for Cursor
impl PartialEq<CommentStyle> for Cursor
Sourcefn eq(&self, other: &CommentStyle) -> bool
fn eq(&self, other: &CommentStyle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<QuoteStyle> for &Cursor
impl PartialEq<QuoteStyle> for &Cursor
Sourcefn eq(&self, other: &QuoteStyle) -> bool
fn eq(&self, other: &QuoteStyle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<QuoteStyle> for Cursor
impl PartialEq<QuoteStyle> for Cursor
Sourcefn eq(&self, other: &QuoteStyle) -> bool
fn eq(&self, other: &QuoteStyle) -> bool
Tests for
self and other values to be equal, and is used by ==.