Kind

Enum Kind 

pub enum Kind {
Show 44 variants Eof = 0, Whitespace = 1, Comment = 2, CdcOrCdo = 3, Number = 4, Dimension = 5, BadString = 28, BadUrl = 29, BadWhitespace = 17, BadComment = 18, BadCdcOrCdo = 19, BadNumber = 20, BadDimension = 21, BadIdent = 24, BadFunction = 25, BadAtKeyword = 26, BadHash = 27, BadDelim = 31, Ident = 8, Function = 9, AtKeyword = 10, Hash = 11, String = 12, Url = 13, UnicodeRange = 14, Delim = 15, Colon = 33, Semicolon = 34, Comma = 35, LeftSquare = 36, RightSquare = 37, LeftParen = 38, RightParen = 39, LeftCurly = 40, RightCurly = 41, BadColon = 49, BadSemicolon = 50, BadComma = 51, BadLeftSquare = 52, BadRightSquare = 53, BadLeftParen = 54, BadRightParen = 55, BadLeftCurly = 56, BadRightCurly = 57,
}
Kind represents the token “Type”, categorised mostly by the token types within the CSS Syntax spec.

Importantly, Kind is represented as u8 and must only use the 5 low bits, because the upper 3 bits get used to house details about each kind, that a token would be interested in learning about.

Maintaining parity with the spec makes it easier to reason about logic around the parser, despite it being possible to group a bunch of these tokens into a single “delimiter” token. These Delim kinds, however, set the upper bit which means they cannot be inserted directly into a token. Instead a token.

Variants



Eof = 0

Represents the <eof-token> defined in CSS. While CSS stipulates that this token is never produced by a tokenizer, this [Lexer][crate::Lexer] will produce <eof-token>s if the underlying source has been fully consumed.



Whitespace = 1

Represents the <whitespace-token> defined in CSS.

<newline>
 │├──╮─ "\n" ───╭──┤│
     ├─ "\r\n" ─┤
     ├─ "\r" ───┤
     ╰─ "\f" ───╯

<whitespace>
 │├──╮─ " " ───────╭──┤│
     ├─ "\t" ──────┤
     ╰─ <newline> ─╯

<whitespace-token>
 │├─╭─ <whitespace> ─╮─┤│
    ╰────────────────╯

While CSS stipulates that this token represents collapsed whitespace, it is possible for [Lexer][crate::Lexer] to produce multiple consecutive Kind::Whitespace tokens if the [Feature::SeparateWhitespace][crate::Feature::SeparateWhitespace] runtime feature is enabled. In this case, <whitespace-token> becomes:

<whitespace-token>
 │├──╮─╭─ " " ───────╮─╭──┤│
     │ ╰─────────────╯ │
     ├─╭─ "\t" ──────╮─┤
     │ ╰─────────────╯ │
     ╰─╭─ <newline> ─╮─╯
       ╰─────────────╯


Comment = 2

Represents the <comment> defined in CSS. While CSS stipulates comment tokens are not produced during tokenization, they are for this [Lexer][crate::Lexer] as they’re needed in order to preserve them.

<comment>
           ╭──────────────────────────────────────────╮
 │├─ "/*" ─╯-╭─ (anything but "*" followed by "/") ─╮─╰─ "*/" ─┤│
             ╰──────────────────────────────────────╯

It is possible for [Lexer][crate::Lexer] to produce Kind::Whitespace tokens that begin // if the [Feature::SingleLineComments][crate::Feature::SingleLineComments] runtime feature is enabled. In this mode, <comment> becomes:

<comment>
              ╭──────────────────────────────────────────╮
 │├──╮─ "/*" ─╯-╭─ (anything but "*" followed by "/") ─╮─╰─ "*/" ─╭─┤│
     │          ╰──────────────────────────────────────╯          │
     │              ╭───────────────────────────╮                 │
     ╰─ "//" ───────╯-╭─ (anything but "\n") ─╮─╰─ "\n" ──────────╯
                      ╰───────────────────────╯


CdcOrCdo = 3

Represents both the <cdc-token> and <cdo-token>s defined in CSS. While CSS separates these tokens, they’re only useful representations at the top-level stylesheet, anywhere else they represent a parse error, and it’s a little pointless to define two tokens types for what amounts to a parse error.

<cdo-token>
 │├─ "<!--" ─┤│

<cdc-token>
 │├─ "-->" ─┤│

<cdc-or-cdo-token> (Not part of the CSS specification)
 │├──╮─ <cdo-token> ─╭──┤│
     ╰─ <crc-token> ─╯


Number = 4

Represents the <number-token>.


<number-token>
    ╭─ "+" ─╮
 │├─├───────┤───╭─ [digit] ─╮─ "." ─╭─ [digit] ─╮──╭───╮──────────────────────────────────╭──┤│
    ╰─ "-" ─╯ │ ╰───────────╯       ╰───────────╯  │   │         ╭─ "+" ─╮                │
              ├───────── ╭─ [digit] ─╮─────────────┤   ├─ "e" ─╭─├───────┤──╭─ [digit] ─╮─╯
              │          ╰───────────╯             │   ╰─ "E" ─╯ ╰─ "-" ─╯  ╰───────────╯
              ╰──── "." ─╭─ [digit] ─╮─────────────╯
                         ╰───────────╯


Dimension = 5

Represents the <dimension-token>.

Here we deviate from the spec slightly, which has both <dimension-token> and <percentage-token>. <percentage-token> represents a dimension with a % symbol, but having this as a separate token results in more work in the parser for little gain in the Lexer. So instead this lexer does not have a <percentage-token> and instead folds the grammar for it inside of <dimension-token>.


<newline>
 │├──╮─ "\n" ───╭──┤│
     ├─ "\r\n" ─┤
     ├─ "\r" ───┤
     ╰─ "\f" ───╯

<whitespace>
 │├──╮─ " " ───────╭──┤│
     ├─ "\t" ──────┤
     ╰─ <newline> ─╯

<hexdigit>
 │├─ [ 0-9, A-F, a-f ] ─┤│


<escape>
 │├─ "\" ─╮───── [not <newline> or <hexdigit>] ───╭─┤│
          ╰─╭── <hexdigit> ─╮──╮────────────────╭─╯
            ╰─ (1-6 times) ─╯  ╰─ <whitespace> ─╯

<ident-token>
    ╭───────────────── "--" ─────────────────────╮  ╭───────────────────────────────────────────╮
 │├─╯─╮───────╭─╮─ [a-z, A-Z, "_", non-ASCII] ─╭─╰──╯─╭─╮─ [a-z, A-Z, 0-9, "_", non-ASCII] ─╭─╮─╰──┤│
      ╰─ "-" ─╯ ╰──────── <escape> ────────────╯      │ ╰──────────── <escape> ─────────────╯ │
                                                      ╰───────────────────────────────────────╯

<number-token>
    ╭─ "+" ─╮
 │├─├───────┤─╮─╭─ [digit] ─╮─ "." ─╭─ [digit] ─╮──╭───╮──────────────────────────────────╭──┤│
    ╰─ "-" ─╯ │ ╰───────────╯       ╰───────────╯  │   │         ╭─ "+" ─╮                │
              ├───────── ╭─ [digit] ─╮─────────────┤   ├─ "e" ─╭─├───────┤──╭─ [digit] ─╮─╯
              │          ╰───────────╯             │   ╰─ "E" ─╯ ╰─ "-" ─╯  ╰───────────╯
              ╰──── "." ─╭─ [digit] ─╮─────────────╯
                         ╰───────────╯

<dimension-token>
 │├─ <number-token> ─ <ident-token> ─┤│

<dimension-token> // Refined for this lexer, not true to the standard.
 │├─ <number-token> ─╮─ <ident-token> ─╭──┤│
                     ╰────── "%" ──────╯


BadString = 28

Represents the <bad-string-token>. This token is a failure to fully lex the <string-token>.



BadUrl = 29

Represents the <bad-url-token>. This token is a failure to fully lex the <url-token>.



BadWhitespace = 17

These kind are non-standard Bad kinds and never emitted by the Lexer, but can be used by Parsers to denote a token that are either:

  • a Token that was unexpected in this position.
  • a Token that was inserted to recover the parser to a known state.


BadComment = 18



BadCdcOrCdo = 19



BadNumber = 20



BadDimension = 21



BadIdent = 24



BadFunction = 25



BadAtKeyword = 26



BadHash = 27



BadDelim = 31



Ident = 8

Represents the <ident-token>.


<newline>
 │├──╮─ "\n" ───╭──┤│
     ├─ "\r\n" ─┤
     ├─ "\r" ───┤
     ╰─ "\f" ───╯

<whitespace>
 │├──╮─ " " ─────╭──┤│
     ├─ "\t" ────┤
     ╰─ newline ─╯

<hexdigit>
 │├─ [ 0-9, A-F, a-f ] ─┤│


<escape>
 │├─ "\" ─╮───── [not <newline> or <hexdigit>] ───╭─┤│
          ╰─╭── <hexdigit> ─╮──╮────────────────╭─╯
            ╰─ (1-6 times) ─╯  ╰─ <whitespace> ─╯

<ident-token>
    ╭───────────────── "--" ─────────────────────╮  ╭───────────────────────────────────────────╮
 │├─╯─╮───────╭─╮─ [a-z, A-Z, "_", non-ASCII] ─╭─╰──╯─╭─╮─ [a-z, A-Z, 0-9, "_", non-ASCII] ─╭─╮─╰──┤│
      ╰─ "-" ─╯ ╰──────── <escape> ────────────╯      │ ╰──────────── <escape> ─────────────╯ │
                                                      ╰───────────────────────────────────────╯


Function = 9

Represents the <function-token>.


<newline>
 │├──╮─ "\n" ───╭──┤│
     ├─ "\r\n" ─┤
     ├─ "\r" ───┤
     ╰─ "\f" ───╯

<whitespace>
 │├──╮─ " " ───────╭──┤│
     ├─ "\t" ──────┤
     ╰─ <newline> ─╯

<hexdigit>
 │├─ [ 0-9, A-F, a-f ] ─┤│


<escape>
 │├─ "\" ─╮───── [not <newline> or <hexdigit>] ───╭─┤│
          ╰─╭── <hexdigit> ─╮──╮────────────────╭─╯
            ╰─ (1-6 times) ─╯  ╰─ <whitespace> ─╯

<ident-token>
    ╭───────────────── "--" ─────────────────────╮  ╭───────────────────────────────────────────╮
 │├─╯─╮───────╭─╮─ [a-z, A-Z, "_", non-ASCII] ─╭─╰──╯─╭─╮─ [a-z, A-Z, 0-9, "_", non-ASCII] ─╭─╮─╰──┤│
      ╰─ "-" ─╯ ╰──────── <escape> ────────────╯      │ ╰──────────── <escape> ─────────────╯ │
                                                      ╰───────────────────────────────────────╯

<function-token>
 │├─ <ident-token> ─ "(" ─┤│


AtKeyword = 10

Represents the <at-keyword-token>.


<newline>
 │├──╮─ "\n" ───╭──┤│
     ├─ "\r\n" ─┤
     ├─ "\r" ───┤
     ╰─ "\f" ───╯

<whitespace>
 │├──╮─ " " ───────╭──┤│
     ├─ "\t" ──────┤
     ╰─ <newline> ─╯

<hexdigit>
 │├─ [ 0-9, A-F, a-f ] ─┤│


<escape>
 │├─ "\" ─╮───── [not <newline> or <hexdigit>] ───╭─┤│
          ╰─╭── <hexdigit> ─╮──╮────────────────╭─╯
            ╰─ (1-6 times) ─╯  ╰─ <whitespace> ─╯

<ident-token>
    ╭───────────────── "--" ─────────────────────╮  ╭───────────────────────────────────────────╮
 │├─╯─╮───────╭─╮─ [a-z, A-Z, "_", non-ASCII] ─╭─╰──╯─╭─╮─ [a-z, A-Z, 0-9, "_", non-ASCII] ─╭─╮─╰──┤│
      ╰─ "-" ─╯ ╰──────── <escape> ────────────╯      │ ╰──────────── <escape> ─────────────╯ │
                                                      ╰───────────────────────────────────────╯

<at-keyword-token>
 │├─ "@" ─ <ident-token> ─┤│


Hash = 11

Represents the <hash-token>.


<newline>
 │├──╮─ "\n" ───╭──┤│
     ├─ "\r\n" ─┤
     ├─ "\r" ───┤
     ╰─ "\f" ───╯

<whitespace>
 │├──╮─ " " ───────╭──┤│
     ├─ "\t" ──────┤
     ╰─ <newline> ─╯

<hexdigit>
 │├─ [ 0-9, A-F, a-f ] ─┤│


<escape>
 │├─ "\" ─╮───── [not <newline> or <hexdigit>] ───╭─┤│
          ╰─╭── <hexdigit> ─╮──╮────────────────╭─╯
            ╰─ (1-6 times) ─╯  ╰─ <whitespace> ─╯

<hash-token>
 │├─ "#" ──╭─╮─ [a-z, A-Z, 0-9, "_", "-", non-ASCII] ─╭─╮─┤│
           │ ╰─────────────── <escape> ───────────────╯ │
           ╰────────────────────────────────────────────╯


String = 12

Represents the <string-token>.


<newline>
 │├──╮─ "\n" ───╭──┤│
     ├─ "\r\n" ─┤
     ├─ "\r" ───┤
     ╰─ "\f" ───╯

<escape>
 │├─ "\" ─╮───── [not <newline> or <hexdigit>] ───╭─┤│
          ╰─╭── <hexdigit> ─╮──╮────────────────╭─╯
            ╰─ (1-6 times) ─╯  ╰─ <whitespace> ─╯

<string-token>
            ╭───────────────────────────────────╮
 │├─╮─ """ ─╯─╭─╮─ [not """, "\", newline] ─╭─╮─╰── """ ─╭─┤│
    │         │ ├──────── <escape> ─────────┤ │          │
    │         │ ╰───── "\" ─ <newline> ─────╯ │          │
    │         ╰───────────────────────────────╯          │
    │       ╭───────────────────────────────────╮        │
    ╰─ "'" ─╯─╭─╮─ [not """, "\", newline] ─╭─╮─╰── "'" ─╯
              │ ├──────── <escape> ─────────┤ │
              │ ╰───── "\" ─ <newline> ─────╯ │
              ╰───────────────────────────────╯


Url = 13

Represents the <url-token>.


<newline>
 │├──╮─ "\n" ───╭──┤│
     ├─ "\r\n" ─┤
     ├─ "\r" ───┤
     ╰─ "\f" ───╯

<whitespace>
 │├──╮─ " " ───────╭──┤│
     ├─ "\t" ──────┤
     ╰─ <newline> ─╯

<whitespace-token>
 │├─╭─ <whitespace> ─╮─┤│
    ╰────────────────╯

<ws*>
    ╭──────────────────────────╮
 │├─╯─╭─ <whitespace-token> ─╮─╰─┤│
      ╰──────────────────────╯

<hexdigit>
 │├─ [ 0-9, A-F, a-f ] ─┤│


<escape>
 │├─ "\" ─╮───── [not <newline> or <hexdigit>] ───╭─┤│
          ╰─╭── <hexdigit> ─╮──╮────────────────╭─╯
            ╰─ (1-6 times) ─╯  ╰─ <whitespace> ─╯

<ident-token>
    ╭───────────────── "--" ─────────────────────╮  ╭───────────────────────────────────────────╮
 │├─╯─╮───────╭─╮─ [a-z, A-Z, "_", non-ASCII] ─╭─╰──╯─╭─╮─ [a-z, A-Z, 0-9, "_", non-ASCII] ─╭─╮─╰──┤│
      ╰─ "-" ─╯ ╰──────── <escape> ────────────╯      │ ╰──────────── <escape> ─────────────╯ │
                                                      ╰───────────────────────────────────────╯

<url-token>
                                        ╭───────────────────────────────────────────────────────────────────╮
 │├─ <ident-token "url"> ─ "(" ─ <ws*> ─╯─╭─╮─ [not """ "'" "(" ")" "\" <whitespace> or non-printable] ─╭─╮─╰─ <ws*> ─ ")" ─┤│
                                          │ ╰──────────────────────── <escape> ─────────────────────────╯ │
                                          ╰───────────────────────────────────────────────────────────────╯


UnicodeRange = 14

Represents the <unicode-range-token>. This token is only produced when the [Feature::UnicodeRange][crate::Feature::UnicodeRange] feature is enabled.


<hexdigit>
 │├─ [ 0-9, A-F, a-f ] ─┤│

<unicode-range-token>
 │├─╮─ 'U' ─╭─ '+' ─╭──────────────────╭── <hexdigit> ─╮──────────────────╭─┤│
    ╰─ 'u' ─╯       │                  ╰─ (1-6 times) ─╯                  │
                    │ ╭───────────────────╮                               │
                    ├─╯─╭── <hexdigit> ─╮─╰─╭───────────── ? ───────────╮─┤
                    │   ╰─ (1-5 times) ─╯   ╰─ (1 to (6 digits) times) ─╯ │
                    │                                                     │
                    ╰────╭── <hexdigit> ─╮── '-' ──╭── <hexdigit> ─╮──────╯
                         ╰─ (1-5 times) ─╯         ╰─ (1-5 times) ─╯


Delim = 15

Represents the <delim-token>. The <delim-token> has a value composed of a single code point.

<delim-token>
 │├─ [codepoint] ─┤│


Colon = 33

Represents the <colon-token>.

<colon-token>
 │├─ ":" ─┤│


Semicolon = 34

Represents the <semicolon-token>.

<semicolon-token>
 │├─ ";" ─┤│


Comma = 35

Represents the <comma-token>.

<comma-token>
 │├─ "," ─┤│


LeftSquare = 36

Represents the <[-token>.

<[-token>
 │├─ "[" ─┤│


RightSquare = 37

Represents the <]-token>.

<]-token>
 │├─ "]" ─┤│


LeftParen = 38

Represents the <(-token>.

<(-token>
 │├─ "(" ─┤│


RightParen = 39

Represents the <)-token>.

<)-token>
 │├─ ")" ─┤│


LeftCurly = 40

Represents the <{-token>.

<{-token>
 │├─ "{" ─┤│


RightCurly = 41

Represents the <}-token>.

<}-token>
 │├─ "}" ─┤│


BadColon = 49

These kind are non-standard Bad kinds and never emitted by the Lexer, but can be used by Parsers to denote a token that are either:

  • a Token that was unexpected in this position.
  • a Token that was inserted to recover the parser to a known state.


BadSemicolon = 50



BadComma = 51



BadLeftSquare = 52



BadRightSquare = 53



BadLeftParen = 54



BadRightParen = 55



BadLeftCurly = 56



BadRightCurly = 57

Implementations



impl Kind

pub const fn is_bad(&self) -> bool