Box

Struct Box 

pub struct Box<'a, T, A: Allocator = &'a Arena> { /* private fields */ }
An arena-allocated box that retains a reference to its allocator, enabling Clone support.

Unlike [bumpalo::boxed::Box], which only stores a mutable reference to the allocated value (and thus cannot implement Clone without the allocator), Box stores both the allocator reference and the value pointer. This allows it to allocate a new copy during Clone::clone.

This type is intended for recursive AST nodes (e.g. color-mix() containing nested <color> values) where indirection is required to break the cycle, but the allocation should still live in the parsing arena.

Implementations

Source

impl<'a, T, A: Allocator> Box<'a, T, A>

pub fn new_in(alloc: A, value: T) -> Self

Allocate value in the given alloc.