pub trait CursorSink {
// Required method
fn append(&mut self, c: Cursor);
}Expand description
This trait provides the generic impl that ToCursors can use. This provides just enough API
surface for nodes to put the cursors they represent into some buffer which can later be read, the details of which
are elided.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".