pub struct CssMinifierFeature { /* private fields */ }Expand description
Runtime feature flags for the CSS minifier, enabling individual transforms.
Implementations
Sourceimpl CssMinifierFeature
impl CssMinifierFeature
Sourcepub const ReduceCharsetRule: CssMinifierFeature
pub const ReduceCharsetRule: CssMinifierFeature
Enables the ReduceCharsetRule transformer.
Sourcepub const ReduceColors: CssMinifierFeature
pub const ReduceColors: CssMinifierFeature
Enables the ReduceColors transformer.
Sourcepub const ReduceLengths: CssMinifierFeature
pub const ReduceLengths: CssMinifierFeature
Enables the ReduceLengths transformer.
Sourcepub const ReduceTimeUnits: CssMinifierFeature
pub const ReduceTimeUnits: CssMinifierFeature
Enables the ReduceTimeUnits transformer.
Sourcepub const ReduceUrls: CssMinifierFeature
pub const ReduceUrls: CssMinifierFeature
Enables the ReduceUrls transformer.
Sourcepub const ReduceShorthandValues: CssMinifierFeature
pub const ReduceShorthandValues: CssMinifierFeature
Enables the ReduceShorthandValues transformer.
Sourcepub const RemoveOverriddenDeclarations: CssMinifierFeature
pub const RemoveOverriddenDeclarations: CssMinifierFeature
Enables the RemoveOverriddenDeclarations transformer.
Sourcepub const RemoveInertNodes: CssMinifierFeature
pub const RemoveInertNodes: CssMinifierFeature
Enables the RemoveInertNodes transformer.
Sourcepub const fn all_bits() -> Self
pub const fn all_bits() -> Self
Returns a bitmask that contains all values.
This will include bits that do not have any flags.
Use ::all_flags() if you only want to use flags.
Sourcepub const fn is_all_bits(&self) -> bool
pub const fn is_all_bits(&self) -> bool
Returns true if the bitmask contains all values.
This will check for bits == !0,
use .is_all_flags() if you only want to check for all flags
Sourcepub const fn is_all_flags(&self) -> bool
pub const fn is_all_flags(&self) -> bool
Returns true if the bitmask contains all flags.
This will fail if any unused bit is set,
consider using .truncate() first.
Sourcepub const fn all() -> Self
👎Deprecated: Please use the ::all_bits() constructor
pub const fn all() -> Self
Please use the ::all_bits() constructor
Returns a bitmask that contains all values.
This will include bits that do not have any flags.
Use ::all_flags() if you only want to use flags.
Sourcepub const fn is_all(&self) -> bool
👎Deprecated: Please use the .is_all_bits() method
pub const fn is_all(&self) -> bool
Please use the .is_all_bits() method
Returns true if the bitmask contains all values.
This will check for bits == !0,
use .is_all_flags() if you only want to check for all flags
Sourcepub const fn full() -> Self
👎Deprecated: Please use the ::all_flags() constructor
pub const fn full() -> Self
Please use the ::all_flags() constructor
Returns a bitmask that contains all flags.
Sourcepub const fn is_full(&self) -> bool
👎Deprecated: Please use the .is_all_flags() method
pub const fn is_full(&self) -> bool
Please use the .is_all_flags() method
Returns true if the bitmask contains all flags.
This will fail if any unused bit is set,
consider using .truncate() first.
Sourcepub const fn truncate(&self) -> Self
pub const fn truncate(&self) -> Self
Returns a bitmask that only has bits corresponding to flags
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if self intersects with any value in other,
or if other does not contain any values.
This is equivalent to (self & other) != 0 || other == 0.