Asyncronous and Pleasant Entity Component System

Modules

Re-export of the anyhow error handling library.
A few flavors of channels to help writing async code
Types used internally for deriving CanFetch and other macros.

Structs

The set of all entities’ components.
Creates and destroys entities.
Associates a discrete group of components within the world.
A component value along with its entity’s id and change tracking information.
Fetches world resources in async systems.
Query type used to denote an optional column.
A composition of resource requirements and systems.
Queries can be used iterate over matching bundles of components.
A prepared and active query.
Immutably borrowed resource that may also be created by default.
Query type used to denote the absence of the wrapped type.
A collection of resources and systems.
A mutably borrowed resource that may be created by default.

Enums

Defines the number of threads to use for inner and outer parallelism.
Whether or not a system should continue execution.

Traits

Types that can be fetched from the World.
Provides runtime type info about bundles and more.
Denotes the shape of a query that can be used to iterate over bundles of components.
Marker trait that denotes a static, nameable type that can be sent between threads.
Optional default creation.

Functions

Get the current system iteration timestamp.
Returns a syncronous system result meaning everything is ok, but the system should not be run again.
Returns a syncronous system result meaning an error occured and the system should not run again.
Returns a syncronous system result meaning everything is ok and the system should run again next frame.

Type Definitions

Type alias for a hashmap using the fx hash algorithm.
Alias for Maybe<&'static mut T> for folks with wrist pain.
Alias for Maybe<&'static T> for folks with wrist pain.
Alias for &'static mut T for folks with wrist pain.
Iterator returned by QueryGuard::iter_mut.
Alias for &'static T for folks with wrist pain.

Derive Macros