pub type Channel = Option<f64>;Expand description
A generic single color channel value, which may be None
none channels in color-mix adopt the analogous channel’s value from the other color in the interpolation space
(see crate::mix_channels).
Aliased Type
pub enum Channel {
None,
Some(f64),
}