pub enum ContainStyleValue {
None(Ident),
Strict(Ident),
Content(Ident),
Size {
size: Option<Ident>,
layout: Option<Ident>,
style: Option<Ident>,
paint: Option<Ident>,
},
InlineSize {
inline_size: Option<Ident>,
layout: Option<Ident>,
style: Option<Ident>,
paint: Option<Ident>,
},
}Expand description
Represents the style value for contain as defined in css-contain-4.
The contain CSS property sets limits to the scope of styles, layout, and paint rendering for speed and efficiency. The none keyword value disables containment, strict is equivalent to contain: size layout style paint, and content is equivalent to contain: layout style paint.
The grammar is defined as:
none | strict | content | [ [size | inline-size] || layout || style || paint ]https://drafts.csswg.org/css-contain-4/#contain
Variants