pub enum NodeId {
Show 873 variants
ColorGamutMediaFeature = 0,
MarginRule = 1,
BorderCollapseStyleValue = 2,
FillPositionStyleValue = 3,
RowRuleInteriorInsetStyleValue = 4,
BreakInsideStyleValue = 5,
TextBoxEdgeStyleValue = 6,
ScrollPaddingInlineStartStyleValue = 7,
RepeatFunction = 8,
BorderInlineStyleStyleValue = 9,
BorderBottomWidthStyleValue = 10,
MarginStyleValue = 11,
GridRowEndStyleValue = 12,
ContinueStyleValue = 13,
StyleSheet = 14,
RightStyleValue = 15,
PrintColorAdjustStyleValue = 16,
HslaFunction = 17,
TextBoxStyleValue = 18,
EasingFunction = 19,
FontFamilyStyleValue = 20,
BorderBlockWidthStyleValue = 21,
TableLayoutStyleValue = 22,
FontLanguageOverrideStyleValue = 23,
TextUnderlineOffsetStyleValue = 24,
MarginInlineStyleValue = 25,
InterpolationColorSpace = 26,
BlockStepAlignStyleValue = 27,
ViewTransitionNameStyleValue = 28,
StartingStyleRule = 29,
BaselineMetric = 30,
BorderBottomLeftRadiusStyleValue = 31,
FontFaceRuleStyleValue = 32,
OverscrollBehaviorBlockStyleValue = 33,
MozFunctionalPseudoElement = 34,
BgClip = 35,
Repetition = 36,
SingleAnimationTimeline = 37,
AnyHoverMediaFeature = 38,
DirectionStyleValue = 39,
BorderInlineStartStyleStyleValue = 40,
BackgroundRepeatXStyleValue = 41,
MarginBlockStyleValue = 42,
DirPseudoFunction = 43,
LayerName = 44,
MarginBlockEndStyleValue = 45,
WrapInsideStyleValue = 46,
NavControlsMediaFeature = 47,
ColumnRuleInteriorInsetEndStyleValue = 48,
BlockEllipsisStyleValue = 49,
Nth = 50,
PropertyRuleStyleValue = 51,
SingleAnimationDirection = 52,
OpacityStyleValue = 53,
LangPseudoFunction = 54,
TriggerScopeStyleValue = 55,
InterpolateSizeStyleValue = 56,
LchFunction = 57,
ContentVisibilityStyleValue = 58,
BackgroundBlendModeStyleValue = 59,
Translate3dFunction = 60,
StrokeDashoffsetStyleValue = 61,
RelativeSize = 62,
BorderBlockEndClipStyleValue = 63,
Matrix3dFunction = 64,
OverscrollBehaviorXStyleValue = 65,
DynamicRangeLimitStyleValue = 66,
MozDocumentRule = 67,
OklchFunction = 68,
ColumnFillStyleValue = 69,
CornerTopRightShapeStyleValue = 70,
GridLine = 71,
RowGapStyleValue = 72,
AnimationFillModeStyleValue = 73,
BorderBottomStyleValue = 74,
TimelineTriggerNameStyleValue = 75,
MsImeAlignMediaFeature = 76,
PauseBeforeStyleValue = 77,
TimelineScopeStyleValue = 78,
PageStyleValue = 79,
UnicodeBidiStyleValue = 80,
TextOrientationStyleValue = 81,
GlyphOrientationVerticalStyleValue = 82,
ClearStyleValue = 83,
TransitionDurationStyleValue = 84,
BorderInlineWidthStyleValue = 85,
SkewxFunction = 86,
RuleEdgeInsetStyleValue = 87,
MaxInlineSizeStyleValue = 88,
RepeatingRadialGradientFunction = 89,
PaddingInlineEndStyleValue = 90,
BackgroundSizeStyleValue = 91,
RowRuleEdgeInsetStartStyleValue = 92,
IsolationMode = 93,
PositionAnchorStyleValue = 94,
BorderInlineEndClipStyleValue = 95,
SystemColor = 96,
FunctionalPseudoElement = 97,
PointerTimelineAxisStyleValue = 98,
RuleInsetEndStyleValue = 99,
CornerInlineEndShapeStyleValue = 100,
TranslatezFunction = 101,
PseudoElement = 102,
ObjectPositionStyleValue = 103,
StrokeOpacityStyleValue = 104,
BackfaceVisibilityStyleValue = 105,
FontStyleStyleValue = 106,
MaskPositionStyleValue = 107,
VisibilityStyleValue = 108,
BaselineShiftStyleValue = 109,
ColumnRuleStyleStyleValue = 110,
ColumnRuleInsetStyleValue = 111,
RgbFunctionParams = 112,
BackgroundRepeatStyleValue = 113,
CornerInlineStartShapeStyleValue = 114,
TranslatexFunction = 115,
MsColumnCountMediaFeature = 116,
ViewTransitionNewPseudoElement = 117,
CaretAnimationStyleValue = 118,
LeaderFunction = 119,
PositionAreaStyleValue = 120,
TransformBoxStyleValue = 121,
OverflowXStyleValue = 122,
MozTouchEnabledMediaFeature = 123,
AnchorNameStyleValue = 124,
CalcSizeFunction = 125,
CornerEndStartShapeStyleValue = 126,
HwbFunction = 127,
TextShadowStyleValue = 128,
GridAutoColumnsStyleValue = 129,
ScrollMarginLeftStyleValue = 130,
LineWidthList = 131,
BorderBlockStartWidthStyleValue = 132,
RestStyleValue = 133,
RowRuleEdgeInsetStyleValue = 134,
RuleInsetStyleValue = 135,
CornerTopLeftShapeStyleValue = 136,
CaptionSideStyleValue = 137,
WebkitPseudoClass = 138,
BreakBeforeStyleValue = 139,
DominantBaselineStyleValue = 140,
IsPseudoFunction = 141,
SpatialNavigationActionStyleValue = 142,
OverflowClipMarginStyleValue = 143,
BorderClipStyleValue = 144,
PartPseudoElement = 145,
SymbolsFunctionParams = 146,
PtNameAndClassSelector = 147,
FontVariantPositionStyleValue = 148,
BackgroundRepeatYStyleValue = 149,
StyleQuery = 150,
PrefersReducedMotionMediaFeature = 151,
BoxDecorationBreakStyleValue = 152,
FamilyName = 153,
UrlOrString = 154,
ScrollSnapStopStyleValue = 155,
VerticalViewportSegmentsMediaFeature = 156,
HyphenateLimitLinesStyleValue = 157,
VoiceDurationStyleValue = 158,
StrokeAlignStyleValue = 159,
LchFunctionParams = 160,
RowRuleStyleValue = 161,
ParamFunction = 162,
TextAlignStyleValue = 163,
CueAfterStyleValue = 164,
NthLastOfTypePseudoFunction = 165,
TransformStyleValue = 166,
HasPseudoFunction = 167,
FontSynthesisPositionStyleValue = 168,
Length = 169,
RuleOverlapStyleValue = 170,
WidowsStyleValue = 171,
SingleAnimationIterationCount = 172,
SpatialNavigationFunctionStyleValue = 173,
PointerEventsStyleValue = 174,
CornerBottomShapeStyleValue = 175,
AspectRatioContainerFeature = 176,
HtmlNonStandardTag = 177,
UnknownQualifiedRule = 178,
StrokeSizeStyleValue = 179,
MaskBorderRepeatStyleValue = 180,
PrefersColorSchemeMediaFeature = 181,
CornerStartEndShapeStyleValue = 182,
MaskOriginStyleValue = 183,
AbsoluteSize = 184,
MozPseudoElement = 185,
NthOfTypePseudoFunction = 186,
InteractivityStyleValue = 187,
EventTriggerEvent = 188,
AnimationDurationStyleValue = 189,
LineHeightStyleValue = 190,
BlendMode = 191,
ColumnRuleInsetEndStyleValue = 192,
ShapeMarginStyleValue = 193,
Attribute = 194,
LineBreakStyleValue = 195,
FillOpacityStyleValue = 196,
ScrollStateFeature = 197,
RuleVisibilityItemsStyleValue = 198,
OverflowPosition = 199,
AnimationTimingFunctionStyleValue = 200,
NamespaceRule = 201,
FloatDeferStyleValue = 202,
SingleAnimationTriggerBehavior = 203,
RowRuleInsetEndStyleValue = 204,
PrefersReducedTransparencyMediaFeature = 205,
ListStylePositionStyleValue = 206,
TransitionTimingFunctionStyleValue = 207,
ColorInterpolationFiltersStyleValue = 208,
ContentPosition = 209,
ColorInterpolationMethod = 210,
MozMacGraphiteThemeMediaFeature = 211,
BorderBlockStyleStyleValue = 212,
RotateFunction = 213,
Gradient = 214,
BorderInlineStartStyleValue = 215,
TransformStyleStyleValue = 216,
BorderTopRightRadiusStyleValue = 217,
NthLastChildPseudoFunction = 218,
Namespace = 219,
NamedColor = 220,
PropertyPrelude = 221,
TextDecorationSkipStyleValue = 222,
BorderBlockStartStyleValue = 223,
LineWidthOrRepeat = 224,
OPseudoClass = 225,
MathmlTag = 226,
HyphensStyleValue = 227,
PositionTryOrderStyleValue = 228,
HyphenateLimitLastStyleValue = 229,
OffsetPositionStyleValue = 230,
InlineSizeContainerFeature = 231,
LinearFunction = 232,
RgbaFunction = 233,
FootnoteDisplayStyleValue = 234,
OverflowClipMarginRightStyleValue = 235,
ColumnRuleEdgeInsetStyleValue = 236,
ImportLayerFunction = 237,
MsPseudoClass = 238,
ColorFunctionColor = 239,
MarginBreakStyleValue = 240,
MatrixFunction = 241,
OrientationMediaFeature = 242,
BorderInlineStartClipStyleValue = 243,
HueInterpolationDirection = 244,
ScrollbarColorStyleValue = 245,
Class = 246,
BoxShadowStyleValue = 247,
ColumnSpanStyleValue = 248,
BoxSnapStyleValue = 249,
RuleInteriorInsetStyleValue = 250,
CommaOrSlash = 251,
BorderTopStyleStyleValue = 252,
ForcedColorAdjustStyleValue = 253,
FontWeightStyleValue = 254,
InvertedColorsMediaFeature = 255,
CornerShapeStyleValue = 256,
CueBeforeStyleValue = 257,
Decibel = 258,
KeypressFunction = 259,
ScrollTimelineAxisStyleValue = 260,
BorderInlineEndColorStyleValue = 261,
OklabFunction = 262,
LengthPercentage = 263,
BgSize = 264,
EventTriggerStyleValue = 265,
PointerTimelineNameStyleValue = 266,
ScrollStateQuery = 267,
SingleAnimationComposition = 268,
MaskTypeStyleValue = 269,
BlockStepRoundStyleValue = 270,
TranslateFunction = 271,
BorderBlockStartColorStyleValue = 272,
ReadingFlowStyleValue = 273,
DynamicRangeLimitMixFunction = 274,
BorderBottomColorStyleValue = 275,
BorderInlineStyleValue = 276,
RubyMergeStyleValue = 277,
Shadow = 278,
WebkitTransform3dMediaFeature = 279,
CornerRightShapeStyleValue = 280,
FlexBasisStyleValue = 281,
BorderBlockStartClipStyleValue = 282,
LineHeightStepStyleValue = 283,
ScrollMarginRightStyleValue = 284,
WebkitDistrubutedFunctionalPseudoElement = 285,
PaddingBlockEndStyleValue = 286,
CueStyleValue = 287,
GridRowStartStyleValue = 288,
LabFunctionParams = 289,
ColumnWidthStyleValue = 290,
OffsetAnchorStyleValue = 291,
MediaType = 292,
KeyframesRule = 293,
HtmlTag = 294,
TextWrapStyleValue = 295,
StyleRule = 296,
FontSizeStyleValue = 297,
ViewTimelineAxisStyleValue = 298,
FloodOpacityStyleValue = 299,
MixBlendModeStyleValue = 300,
ColumnRuleStyleValue = 301,
CursorImage = 302,
BorderLeftColorStyleValue = 303,
TargetCounterFunction = 304,
FallbackStyleValue = 305,
FontOpticalSizingStyleValue = 306,
BorderStyleValue = 307,
TextSpacingTrimStyleValue = 308,
ScrollTargetGroupStyleValue = 309,
ScrollPaddingInlineEndStyleValue = 310,
InlineSizingStyleValue = 311,
StepsFunction = 312,
ScaleFunction = 313,
GenericFamily = 314,
CubicBezierFunction = 315,
Image1d = 316,
WebkitDevicePixelRatioMediaFeature = 317,
ColumnRuleBreakStyleValue = 318,
InlineSizeStyleValue = 319,
HeightStyleValue = 320,
LineGridStyleValue = 321,
OverlayStyleValue = 322,
BorderEndEndRadiusStyleValue = 323,
FontWidthStyleValue = 324,
AnimationRangeEndStyleValue = 325,
AttributeValue = 326,
PointerTimelineStyleValue = 327,
OverscrollBehaviorStyleValue = 328,
BookmarkStateStyleValue = 329,
BorderStartEndRadiusStyleValue = 330,
PageRule = 331,
SpeakAsStyleValue = 332,
MaskBorderModeStyleValue = 333,
TextDecorationThicknessStyleValue = 334,
EmptyCellsStyleValue = 335,
SelectorList = 336,
MarginBottomStyleValue = 337,
Time = 338,
ViewTimelineInsetStyleValue = 339,
PaddingTopStyleValue = 340,
PropertyRule = 341,
WillChangeStyleValue = 342,
LetterSpacingStyleValue = 343,
LinearFunctionParams = 344,
BackgroundRepeatBlockStyleValue = 345,
ColumnRuleInsetStartStyleValue = 346,
DocumentRule = 347,
InterestDelayEndStyleValue = 348,
ScrollPaddingBottomStyleValue = 349,
UnknownAtRule = 350,
SelfPosition = 351,
BorderSpacingStyleValue = 352,
TextAlignAllStyleValue = 353,
InsetStyleValue = 354,
AspectRatioStyleValue = 355,
MinBlockSizeStyleValue = 356,
FlexFlowStyleValue = 357,
ScrollBehaviorStyleValue = 358,
FlexDirectionStyleValue = 359,
TextDecorationSkipInkStyleValue = 360,
ScrollMarginStyleValue = 361,
SystemStyleValue = 362,
FillOriginStyleValue = 363,
CaretStyleValue = 364,
ViewTransitionImagePairPseudoElement = 365,
ScrollbarWidthStyleValue = 366,
FontFaceRule = 367,
OutlineStyleStyleValue = 368,
RubyAlignStyleValue = 369,
BorderBlockEndWidthStyleValue = 370,
ScrollTimelineStyleValue = 371,
HoverMediaFeature = 372,
SupportsCondition = 373,
WebkitAnimationMediaFeature = 374,
AnimationCompositionStyleValue = 375,
TextGroupAlignStyleValue = 376,
PaddingStyleValue = 377,
BorderRightClipStyleValue = 378,
ImportRule = 379,
ColumnHeightStyleValue = 380,
TransitionPropertyStyleValue = 381,
StrokeLinecapStyleValue = 382,
GridTemplateAreasStyleValue = 383,
StyleFeature = 384,
RowRuleInsetStyleValue = 385,
LabFunction = 386,
ColumnRuleWidthStyleValue = 387,
FontKerningStyleValue = 388,
BackgroundOriginStyleValue = 389,
DisplayModeMediaFeature = 390,
WebkitLineClampStyleValue = 391,
KeyframesRuleBlock = 392,
LineWidth = 393,
CaretShapeStyleValue = 394,
AnchorName = 395,
PaddingInlineStartStyleValue = 396,
BackgroundImageStyleValue = 397,
BorderLeftWidthStyleValue = 398,
SlottedPseudoElement = 399,
MarginTopStyleValue = 400,
BorderImageOutsetStyleValue = 401,
ScrollSnapAlignStyleValue = 402,
ContentDistribution = 403,
PointerMediaFeature = 404,
RotatexFunction = 405,
GridAutoRowsStyleValue = 406,
EventTriggerNameStyleValue = 407,
BackgroundRepeatInlineStyleValue = 408,
StrokeOriginStyleValue = 409,
BorderLeftClipStyleValue = 410,
LegacyPseudoElement = 411,
StripesFunction = 412,
MozPseudoClass = 413,
BlockStepSizeStyleValue = 414,
PickerPseudoElement = 415,
ColumnRuleEdgeInsetStartStyleValue = 416,
MaskBorderOutsetStyleValue = 417,
Url = 418,
WebkitFunctionalPseudoElement = 419,
LineStyle = 420,
AttrFunction = 421,
TimelineRangeName = 422,
FontSynthesisWeightStyleValue = 423,
HyphenateLimitZoneStyleValue = 424,
PaddingBlockStartStyleValue = 425,
TopStyleValue = 426,
ViewTransitionOldPseudoElement = 427,
MsHighContrastMediaFeature = 428,
HostPseudoFunction = 429,
ContainerFeature = 430,
AnimationNameStyleValue = 431,
ScrollMarginBlockStyleValue = 432,
BoxShadowBlurStyleValue = 433,
LineSnapStyleValue = 434,
ListStyleImageStyleValue = 435,
DynamicRangeMediaFeature = 436,
SnapInlineFunction = 437,
ContainerQuery = 438,
MozDeviceOrientationMediaFeature = 439,
RotatezFunction = 440,
CounterStyleRule = 441,
OverflowClipMarginBlockEndStyleValue = 442,
SliderOrientationStyleValue = 443,
RectangularColorSpace = 444,
ZoomStyleValue = 445,
ScalexFunction = 446,
ClipRuleStyleValue = 447,
CornerShapeValue = 448,
MaskBorderSourceStyleValue = 449,
FlexStyleValue = 450,
MonochromeMediaFeature = 451,
TextDecorationStyleStyleValue = 452,
BottomStyleValue = 453,
TargetTextFunction = 454,
ColumnCountStyleValue = 455,
PageSelector = 456,
LineFitEdgeStyleValue = 457,
WordBreakStyleValue = 458,
RestAfterStyleValue = 459,
AlignContentStyleValue = 460,
UserSelectStyleValue = 461,
ScrollMarginBlockStartStyleValue = 462,
MsPseudoElement = 463,
AccentColorStyleValue = 464,
ShapeImageThresholdStyleValue = 465,
BorderRightWidthStyleValue = 466,
BorderTopColorStyleValue = 467,
HyphenateCharacterStyleValue = 468,
Ratio = 469,
Keyframe = 470,
Target = 471,
ColorMixFunction = 472,
ViewTransitionGroupPseudoElement = 473,
FillBreakStyleValue = 474,
CornerStartStartShapeStyleValue = 475,
CornerBottomLeftShapeStyleValue = 476,
RepeatingLinearGradientFunction = 477,
FontVariationSettingsStyleValue = 478,
FontSynthesisSmallCapsStyleValue = 479,
RgbFunction = 480,
StatePseudoFunction = 481,
WidthContainerFeature = 482,
MozImagesInMenusMediaFeature = 483,
BorderTopWidthStyleValue = 484,
ScrollTimelineNameStyleValue = 485,
CounterFunction = 486,
MediaPreCondition = 487,
BorderRightStyleValue = 488,
ForcedColorsMediaFeature = 489,
BorderStyleStyleValue = 490,
BorderBlockStyleValue = 491,
TextEmphasisSkipStyleValue = 492,
AnimationTriggerStyleValue = 493,
HeightContainerFeature = 494,
FloodColorStyleValue = 495,
SpeakStyleValue = 496,
StringFunction = 497,
GapRepeatRule = 498,
CornerBottomRightShapeStyleValue = 499,
InsetInlineStyleValue = 500,
SingleTransitionProperty = 501,
DashedIdent = 502,
ScrollPaddingBlockStartStyleValue = 503,
SingleAnimationPlayState = 504,
TransitionStyleValue = 505,
RowRuleStyleStyleValue = 506,
AnimationRangeStartStyleValue = 507,
MarkerSideStyleValue = 508,
NumberLength = 509,
AlignmentBaselineStyleValue = 510,
ReadingOrderStyleValue = 511,
OrphansStyleValue = 512,
TabSizeStyleValue = 513,
TextEmphasisColorStyleValue = 514,
HwbFunctionParams = 515,
TextDecorationInsetStyleValue = 516,
OverscrollBehaviorInlineStyleValue = 517,
ScrollPaddingInlineStyleValue = 518,
CornerTopShapeStyleValue = 519,
ContainerRule = 520,
ScrollMarginInlineEndStyleValue = 521,
AnyPointerMediaFeature = 522,
MaskClipStyleValue = 523,
ContentListItem = 524,
StrokeWidthStyleValue = 525,
BorderInlineEndStyleValue = 526,
HslFunctionParams = 527,
Tag = 528,
AttributeModifier = 529,
VideoColorGamutMediaFeature = 530,
FlexWrapStyleValue = 531,
ScanMediaFeature = 532,
OverflowClipMarginInlineStyleValue = 533,
UnknownTag = 534,
Percentage = 535,
OverflowClipMarginTopStyleValue = 536,
AllStyleValue = 537,
TextWrapStyleStyleValue = 538,
OrientationContainerFeature = 539,
ScrollMarginTopStyleValue = 540,
FontVariantEmojiStyleValue = 541,
BoxSizingStyleValue = 542,
PerspectiveFunction = 543,
PseudoClass = 544,
AttributeOperator = 545,
RuleBreakStyleValue = 546,
BorderBlockColorStyleValue = 547,
ScrollMarkerGroupStyleValue = 548,
CornerBlockEndShapeStyleValue = 549,
BookmarkLevelStyleValue = 550,
MozMaemoClassicMediaFeature = 551,
Scale3dFunction = 552,
WebkitKeyframesRule = 553,
FloatStyleValue = 554,
InsetInlineEndStyleValue = 555,
ColumnRuleVisibilityItemsStyleValue = 556,
RuleColorStyleValue = 557,
DisplayStyleValue = 558,
FillRepeatStyleValue = 559,
TransformList = 560,
BorderInlineEndStyleStyleValue = 561,
MaxHeightStyleValue = 562,
Rotate3dFunction = 563,
SpatialNavigationContainStyleValue = 564,
CounterStyle = 565,
CounterStyleRuleStyleValue = 566,
NthColPseudoFunction = 567,
HtmlNonConformingTag = 568,
SupportsFeature = 569,
MaxBlockSizeStyleValue = 570,
VideoDynamicRangeMediaFeature = 571,
HorizontalViewportSegmentsMediaFeature = 572,
ScriptingMediaFeature = 573,
WebkitTransform2dMediaFeature = 574,
ImageRenderingStyleValue = 575,
BorderWidthStyleValue = 576,
ScrollPaddingBlockStyleValue = 577,
SvgTag = 578,
InsetBlockStartStyleValue = 579,
PrefixStyleValue = 580,
GridMediaFeature = 581,
GapStyleValue = 582,
TrySize = 583,
BorderTopLeftRadiusStyleValue = 584,
RowRuleEdgeInsetEndStyleValue = 585,
LinePaddingStyleValue = 586,
RuleInsetStartStyleValue = 587,
SnapBlockFunction = 588,
ColorFunctionColorParams = 589,
OverflowClipMarginInlineStartStyleValue = 590,
ImportLayer = 591,
RowRuleVisibilityItemsStyleValue = 592,
Flex = 593,
HeadingPseudoFunction = 594,
TargetCountersFunction = 595,
OverflowClipMarginInlineEndStyleValue = 596,
BlockStepStyleValue = 597,
AnimationTimelineStyleValue = 598,
WebkitTransitionMediaFeature = 599,
BorderLeftStyleValue = 600,
InitialLetterWrapStyleValue = 601,
SymbolsStyleValue = 602,
SupportsRule = 603,
StrokeDasharrayStyleValue = 604,
MinWidthStyleValue = 605,
MsDevicePixelRatioMediaFeature = 606,
ContentFunction = 607,
ViewTransitionGroupStyleValue = 608,
BorderInlineEndWidthStyleValue = 609,
BookmarkLabelStyleValue = 610,
ScrollPaddingStyleValue = 611,
Combinator = 612,
TextDecorationSkipBoxStyleValue = 613,
AnimationRangeStyleValue = 614,
HighlightPseudoElement = 615,
BorderTopClipStyleValue = 616,
SkewyFunction = 617,
BreakAfterStyleValue = 618,
PolarColorSpace = 619,
BlockSizeContainerFeature = 620,
MediaRule = 621,
AppearanceStyleValue = 622,
LayerRule = 623,
ColumnRuleColorStyleValue = 624,
TextCombineUprightStyleValue = 625,
MaskSizeStyleValue = 626,
ObjectViewBoxStyleValue = 627,
OffsetDistanceStyleValue = 628,
WrapBeforeStyleValue = 629,
BorderEndStartRadiusStyleValue = 630,
Angle = 631,
MarginInlineEndStyleValue = 632,
TranslateyFunction = 633,
PrefersContrastMediaFeature = 634,
EnvironmentBlendingMediaFeature = 635,
OpacityValue = 636,
NegativeStyleValue = 637,
WebkitAnyFunctionalPseudoClass = 638,
ShapePaddingStyleValue = 639,
FlowFromStyleValue = 640,
RuleStyleValue = 641,
NthLastColPseudoFunction = 642,
RubyOverhangStyleValue = 643,
LeftStyleValue = 644,
PositionStyleValue = 645,
TextDecorationColorStyleValue = 646,
ResizeStyleValue = 647,
BoxShadowColorStyleValue = 648,
HueInterpolationMethod = 649,
CharsetRule = 650,
StrokeDashCornerStyleValue = 651,
ColorSpace = 652,
Position = 653,
GapRuleOrRepeat = 654,
WritingModeStyleValue = 655,
CornerLeftShapeStyleValue = 656,
AnimationAction = 657,
Image = 658,
TransitionDelayStyleValue = 659,
ScrollMarginBlockEndStyleValue = 660,
BorderBottomStyleStyleValue = 661,
OutlineOffsetStyleValue = 662,
LinkParametersStyleValue = 663,
ScrollMarginInlineStyleValue = 664,
Wildcard = 665,
InterestDelayStartStyleValue = 666,
BackgroundColorStyleValue = 667,
ColorAdjustStyleValue = 668,
StrokeMiterlimitStyleValue = 669,
Quote = 670,
TextBoxTrimStyleValue = 671,
RowRuleBreakStyleValue = 672,
RepeatStyle = 673,
WhiteSpaceCollapseStyleValue = 674,
ScrollInitialTargetStyleValue = 675,
HslFunction = 676,
PaddingInlineStyleValue = 677,
MaskRepeatStyleValue = 678,
FillSizeStyleValue = 679,
BorderBoundaryStyleValue = 680,
BorderBottomClipStyleValue = 681,
BorderBlockStartStyleStyleValue = 682,
CustomElementTag = 683,
ColorIndexMediaFeature = 684,
OverflowWrapStyleValue = 685,
MozLocaleDirFunctionalPseudoClass = 686,
SyntaxValue = 687,
IsolationStyleValue = 688,
AnimationPlayStateStyleValue = 689,
PositionArea = 690,
MarginLeftStyleValue = 691,
BorderRightColorStyleValue = 692,
ScalezFunction = 693,
SuffixStyleValue = 694,
BorderTopStyleValue = 695,
PrefersReducedDataMediaFeature = 696,
PerspectiveOriginStyleValue = 697,
BorderBlockClipStyleValue = 698,
VoiceStressStyleValue = 699,
BorderImageRepeatStyleValue = 700,
CornerBlockStartShapeStyleValue = 701,
RunningStyleValue = 702,
ColorMediaFeature = 703,
TextSizeAdjustStyleValue = 704,
MozOsVersionMediaFeature = 705,
ScrollMarginBottomStyleValue = 706,
ScrollPaddingLeftStyleValue = 707,
RegionFragmentStyleValue = 708,
ViewTransitionScopeStyleValue = 709,
MozFunctionalPseudoClass = 710,
RowRuleInteriorInsetEndStyleValue = 711,
OverflowYStyleValue = 712,
OverflowClipMarginBottomStyleValue = 713,
ContentList = 714,
WrapAfterStyleValue = 715,
BorderBlockEndStyleValue = 716,
InheritsValue = 717,
OverflowBlockStyleValue = 718,
ScaleStyleValue = 719,
FieldSizingStyleValue = 720,
GridColumnStartStyleValue = 721,
FontFeatureSettingsStyleValue = 722,
KeyframeSelector = 723,
RowRuleWidthStyleValue = 724,
AdditiveSymbolsStyleValue = 725,
OverflowInlineMediaFeature = 726,
OverflowAnchorStyleValue = 727,
FitContentFunction = 728,
ColumnRuleInteriorInsetStartStyleValue = 729,
ColumnRuleInteriorInsetStyleValue = 730,
ContainerNameStyleValue = 731,
BorderImageSourceStyleValue = 732,
ColumnRuleEdgeInsetEndStyleValue = 733,
AnchorScopeStyleValue = 734,
RowRuleInteriorInsetStartStyleValue = 735,
OverflowStyleValue = 736,
AutoLineWidthList = 737,
MinInlineSizeStyleValue = 738,
StyleValue = 739,
MinHeightStyleValue = 740,
AnimateableFeature = 741,
StrokePositionStyleValue = 742,
CountersFunction = 743,
BoxShadowSpreadStyleValue = 744,
AlignSelfStyleValue = 745,
FontWeightAbsolute = 746,
WebkitPseudoElement = 747,
OrderStyleValue = 748,
CursorStyleValue = 749,
InsetBlockStyleValue = 750,
InsetBlockEndStyleValue = 751,
ColumnWrapStyleValue = 752,
InsetInlineStartStyleValue = 753,
FloatOffsetStyleValue = 754,
LightingColorStyleValue = 755,
BorderRightStyleStyleValue = 756,
BaselinePosition = 757,
AnimationDelayStyleValue = 758,
WordWrapStyleValue = 759,
ColumnGapStyleValue = 760,
MarginRightStyleValue = 761,
MarginInlineStartStyleValue = 762,
MarginBlockStartStyleValue = 763,
ImageAnimationStyleValue = 764,
TransitionBehaviorStyleValue = 765,
SingleTransition = 766,
TextAutospaceStyleValue = 767,
OutlineWidthStyleValue = 768,
ColorFunction = 769,
CornerEndEndShapeStyleValue = 770,
ScrollMarginInlineStartStyleValue = 771,
FlexShrinkStyleValue = 772,
GapRuleList = 773,
PauseStyleValue = 774,
BorderLeftStyleStyleValue = 775,
PaddingRightStyleValue = 776,
KeyframesName = 777,
PaddingBottomStyleValue = 778,
RestBeforeStyleValue = 779,
MaxLinesStyleValue = 780,
OverflowClipMarginBlockStyleValue = 781,
CompoundSelector = 782,
BlockStepInsertStyleValue = 783,
OutlineStyleValue = 784,
InterestDelayStyleValue = 785,
InputSecurityStyleValue = 786,
CaretColorStyleValue = 787,
ScrollPaddingBlockEndStyleValue = 788,
OverflowClipMarginBlockStartStyleValue = 789,
StrokeRepeatStyleValue = 790,
BlockSizeStyleValue = 791,
BackgroundClipStyleValue = 792,
SuperellipseFunction = 793,
BorderBlockEndStyleStyleValue = 794,
BorderInlineColorStyleValue = 795,
FootnotePolicyStyleValue = 796,
OPseudoElement = 797,
ImportSupportsFunction = 798,
NotPseudoFunction = 799,
BorderStartStartRadiusStyleValue = 800,
GridColumnEndStyleValue = 801,
OverflowInlineStyleValue = 802,
MozDevicePixelRatioMediaFeature = 803,
StrokeBreakStyleValue = 804,
BorderRadius = 805,
FillRuleStyleValue = 806,
DocumentMatcher = 807,
OverscrollBehaviorYStyleValue = 808,
ListStyleTypeStyleValue = 809,
Color = 810,
PauseAfterStyleValue = 811,
BorderInlineStartColorStyleValue = 812,
FlowToleranceStyleValue = 813,
FontSynthesisStyleStyleValue = 814,
PerspectiveStyleValue = 815,
StrokeColorStyleValue = 816,
BaselineSourceStyleValue = 817,
EventTriggerSourceStyleValue = 818,
BorderInlineClipStyleValue = 819,
RotateyFunction = 820,
NthChildPseudoFunction = 821,
FlexGrowStyleValue = 822,
ODevicePixelRatioMediaFeature = 823,
ColorStyleValue = 824,
RadialGradientFunction = 825,
ScrollPaddingTopStyleValue = 826,
SingleAnimationFillMode = 827,
BackgroundAttachmentStyleValue = 828,
PadStyleValue = 829,
RuleStyleStyleValue = 830,
VoiceBalanceStyleValue = 831,
HostContextPseudoFunction = 832,
WherePseudoFunction = 833,
BorderBottomRightRadiusStyleValue = 834,
LinearGradientFunction = 835,
OverflowBlockMediaFeature = 836,
OutlineColorStyleValue = 837,
MsViewStateMediaFeature = 838,
FontVariantCapsStyleValue = 839,
SymbolsFunction = 840,
TextWrapModeStyleValue = 841,
WidthStyleValue = 842,
ScrollPaddingRightStyleValue = 843,
FloatReferenceStyleValue = 844,
FillColorStyleValue = 845,
ViewTimelineNameStyleValue = 846,
RowRuleInsetStartStyleValue = 847,
NumberPercentage = 848,
RowRuleColorStyleValue = 849,
BoxShadowPositionStyleValue = 850,
Id = 851,
ScaleyFunction = 852,
PaddingBlockStyleValue = 853,
PaddingLeftStyleValue = 854,
RuleWidthStyleValue = 855,
BorderBlockEndColorStyleValue = 856,
WrapThroughStyleValue = 857,
WordSpacingStyleValue = 858,
ViewTransitionClassStyleValue = 859,
CustomIdent = 860,
WrapFlowStyleValue = 861,
AnimationIterationCountStyleValue = 862,
BorderInlineStartWidthStyleValue = 863,
MaxWidthStyleValue = 864,
ImageSetFunction = 865,
TextAlignLastStyleValue = 866,
OverflowClipMarginLeftStyleValue = 867,
TimelineTriggerSourceStyleValue = 868,
TransformFunction = 869,
AnimationDirectionStyleValue = 870,
SkewFunction = 871,
WebkitVideoPlayableInlineMediaFeature = 872,
}Expand description
Unique identifier for each AST node type that can be queried.
This enum is automatically generated from types that derive Visitable
and have #[visit], #[visit(self)], or #[visit(all)] attributes.
Each variant has a unique discriminant value assigned at build time.
Variants
ColorGamutMediaFeature = 0
MarginRule = 1
BorderCollapseStyleValue = 2
FillPositionStyleValue = 3
RowRuleInteriorInsetStyleValue = 4
BreakInsideStyleValue = 5
TextBoxEdgeStyleValue = 6
ScrollPaddingInlineStartStyleValue = 7
RepeatFunction = 8
BorderInlineStyleStyleValue = 9
BorderBottomWidthStyleValue = 10
MarginStyleValue = 11
GridRowEndStyleValue = 12
ContinueStyleValue = 13
StyleSheet = 14
RightStyleValue = 15
PrintColorAdjustStyleValue = 16
HslaFunction = 17
TextBoxStyleValue = 18
EasingFunction = 19
FontFamilyStyleValue = 20
BorderBlockWidthStyleValue = 21
TableLayoutStyleValue = 22
FontLanguageOverrideStyleValue = 23
TextUnderlineOffsetStyleValue = 24
MarginInlineStyleValue = 25
InterpolationColorSpace = 26
BlockStepAlignStyleValue = 27
ViewTransitionNameStyleValue = 28
StartingStyleRule = 29
BaselineMetric = 30
BorderBottomLeftRadiusStyleValue = 31
FontFaceRuleStyleValue = 32
OverscrollBehaviorBlockStyleValue = 33
MozFunctionalPseudoElement = 34
BgClip = 35
Repetition = 36
SingleAnimationTimeline = 37
AnyHoverMediaFeature = 38
DirectionStyleValue = 39
BorderInlineStartStyleStyleValue = 40
BackgroundRepeatXStyleValue = 41
MarginBlockStyleValue = 42
DirPseudoFunction = 43
LayerName = 44
MarginBlockEndStyleValue = 45
WrapInsideStyleValue = 46
ColumnRuleInteriorInsetEndStyleValue = 48
BlockEllipsisStyleValue = 49
Nth = 50
PropertyRuleStyleValue = 51
SingleAnimationDirection = 52
OpacityStyleValue = 53
LangPseudoFunction = 54
TriggerScopeStyleValue = 55
InterpolateSizeStyleValue = 56
LchFunction = 57
ContentVisibilityStyleValue = 58
BackgroundBlendModeStyleValue = 59
Translate3dFunction = 60
StrokeDashoffsetStyleValue = 61
RelativeSize = 62
BorderBlockEndClipStyleValue = 63
Matrix3dFunction = 64
OverscrollBehaviorXStyleValue = 65
DynamicRangeLimitStyleValue = 66
MozDocumentRule = 67
OklchFunction = 68
ColumnFillStyleValue = 69
CornerTopRightShapeStyleValue = 70
GridLine = 71
RowGapStyleValue = 72
AnimationFillModeStyleValue = 73
BorderBottomStyleValue = 74
TimelineTriggerNameStyleValue = 75
MsImeAlignMediaFeature = 76
PauseBeforeStyleValue = 77
TimelineScopeStyleValue = 78
PageStyleValue = 79
UnicodeBidiStyleValue = 80
TextOrientationStyleValue = 81
GlyphOrientationVerticalStyleValue = 82
ClearStyleValue = 83
TransitionDurationStyleValue = 84
BorderInlineWidthStyleValue = 85
SkewxFunction = 86
RuleEdgeInsetStyleValue = 87
MaxInlineSizeStyleValue = 88
RepeatingRadialGradientFunction = 89
PaddingInlineEndStyleValue = 90
BackgroundSizeStyleValue = 91
RowRuleEdgeInsetStartStyleValue = 92
IsolationMode = 93
PositionAnchorStyleValue = 94
BorderInlineEndClipStyleValue = 95
SystemColor = 96
FunctionalPseudoElement = 97
PointerTimelineAxisStyleValue = 98
RuleInsetEndStyleValue = 99
CornerInlineEndShapeStyleValue = 100
TranslatezFunction = 101
PseudoElement = 102
ObjectPositionStyleValue = 103
StrokeOpacityStyleValue = 104
BackfaceVisibilityStyleValue = 105
FontStyleStyleValue = 106
MaskPositionStyleValue = 107
VisibilityStyleValue = 108
BaselineShiftStyleValue = 109
ColumnRuleStyleStyleValue = 110
ColumnRuleInsetStyleValue = 111
RgbFunctionParams = 112
BackgroundRepeatStyleValue = 113
CornerInlineStartShapeStyleValue = 114
TranslatexFunction = 115
MsColumnCountMediaFeature = 116
ViewTransitionNewPseudoElement = 117
CaretAnimationStyleValue = 118
LeaderFunction = 119
PositionAreaStyleValue = 120
TransformBoxStyleValue = 121
OverflowXStyleValue = 122
MozTouchEnabledMediaFeature = 123
AnchorNameStyleValue = 124
CalcSizeFunction = 125
CornerEndStartShapeStyleValue = 126
HwbFunction = 127
TextShadowStyleValue = 128
GridAutoColumnsStyleValue = 129
ScrollMarginLeftStyleValue = 130
LineWidthList = 131
BorderBlockStartWidthStyleValue = 132
RestStyleValue = 133
RowRuleEdgeInsetStyleValue = 134
RuleInsetStyleValue = 135
CornerTopLeftShapeStyleValue = 136
CaptionSideStyleValue = 137
WebkitPseudoClass = 138
BreakBeforeStyleValue = 139
DominantBaselineStyleValue = 140
IsPseudoFunction = 141
OverflowClipMarginStyleValue = 143
BorderClipStyleValue = 144
PartPseudoElement = 145
SymbolsFunctionParams = 146
PtNameAndClassSelector = 147
FontVariantPositionStyleValue = 148
BackgroundRepeatYStyleValue = 149
StyleQuery = 150
PrefersReducedMotionMediaFeature = 151
BoxDecorationBreakStyleValue = 152
FamilyName = 153
UrlOrString = 154
ScrollSnapStopStyleValue = 155
VerticalViewportSegmentsMediaFeature = 156
HyphenateLimitLinesStyleValue = 157
VoiceDurationStyleValue = 158
StrokeAlignStyleValue = 159
LchFunctionParams = 160
RowRuleStyleValue = 161
ParamFunction = 162
TextAlignStyleValue = 163
CueAfterStyleValue = 164
NthLastOfTypePseudoFunction = 165
TransformStyleValue = 166
HasPseudoFunction = 167
FontSynthesisPositionStyleValue = 168
Length = 169
RuleOverlapStyleValue = 170
WidowsStyleValue = 171
SingleAnimationIterationCount = 172
PointerEventsStyleValue = 174
CornerBottomShapeStyleValue = 175
AspectRatioContainerFeature = 176
HtmlNonStandardTag = 177
UnknownQualifiedRule = 178
StrokeSizeStyleValue = 179
MaskBorderRepeatStyleValue = 180
PrefersColorSchemeMediaFeature = 181
CornerStartEndShapeStyleValue = 182
MaskOriginStyleValue = 183
AbsoluteSize = 184
MozPseudoElement = 185
NthOfTypePseudoFunction = 186
InteractivityStyleValue = 187
EventTriggerEvent = 188
AnimationDurationStyleValue = 189
LineHeightStyleValue = 190
BlendMode = 191
ColumnRuleInsetEndStyleValue = 192
ShapeMarginStyleValue = 193
Attribute = 194
LineBreakStyleValue = 195
FillOpacityStyleValue = 196
ScrollStateFeature = 197
RuleVisibilityItemsStyleValue = 198
OverflowPosition = 199
AnimationTimingFunctionStyleValue = 200
NamespaceRule = 201
FloatDeferStyleValue = 202
SingleAnimationTriggerBehavior = 203
RowRuleInsetEndStyleValue = 204
PrefersReducedTransparencyMediaFeature = 205
ListStylePositionStyleValue = 206
TransitionTimingFunctionStyleValue = 207
ColorInterpolationFiltersStyleValue = 208
ContentPosition = 209
ColorInterpolationMethod = 210
MozMacGraphiteThemeMediaFeature = 211
BorderBlockStyleStyleValue = 212
RotateFunction = 213
Gradient = 214
BorderInlineStartStyleValue = 215
TransformStyleStyleValue = 216
BorderTopRightRadiusStyleValue = 217
NthLastChildPseudoFunction = 218
Namespace = 219
NamedColor = 220
PropertyPrelude = 221
TextDecorationSkipStyleValue = 222
BorderBlockStartStyleValue = 223
LineWidthOrRepeat = 224
OPseudoClass = 225
MathmlTag = 226
HyphensStyleValue = 227
PositionTryOrderStyleValue = 228
HyphenateLimitLastStyleValue = 229
OffsetPositionStyleValue = 230
InlineSizeContainerFeature = 231
LinearFunction = 232
RgbaFunction = 233
FootnoteDisplayStyleValue = 234
OverflowClipMarginRightStyleValue = 235
ColumnRuleEdgeInsetStyleValue = 236
ImportLayerFunction = 237
MsPseudoClass = 238
ColorFunctionColor = 239
MarginBreakStyleValue = 240
MatrixFunction = 241
OrientationMediaFeature = 242
BorderInlineStartClipStyleValue = 243
HueInterpolationDirection = 244
ScrollbarColorStyleValue = 245
Class = 246
BoxShadowStyleValue = 247
ColumnSpanStyleValue = 248
BoxSnapStyleValue = 249
RuleInteriorInsetStyleValue = 250
CommaOrSlash = 251
BorderTopStyleStyleValue = 252
ForcedColorAdjustStyleValue = 253
FontWeightStyleValue = 254
InvertedColorsMediaFeature = 255
CornerShapeStyleValue = 256
CueBeforeStyleValue = 257
Decibel = 258
KeypressFunction = 259
ScrollTimelineAxisStyleValue = 260
BorderInlineEndColorStyleValue = 261
OklabFunction = 262
LengthPercentage = 263
BgSize = 264
EventTriggerStyleValue = 265
PointerTimelineNameStyleValue = 266
ScrollStateQuery = 267
SingleAnimationComposition = 268
MaskTypeStyleValue = 269
BlockStepRoundStyleValue = 270
TranslateFunction = 271
BorderBlockStartColorStyleValue = 272
ReadingFlowStyleValue = 273
DynamicRangeLimitMixFunction = 274
BorderBottomColorStyleValue = 275
BorderInlineStyleValue = 276
RubyMergeStyleValue = 277
Shadow = 278
WebkitTransform3dMediaFeature = 279
CornerRightShapeStyleValue = 280
FlexBasisStyleValue = 281
BorderBlockStartClipStyleValue = 282
LineHeightStepStyleValue = 283
ScrollMarginRightStyleValue = 284
WebkitDistrubutedFunctionalPseudoElement = 285
PaddingBlockEndStyleValue = 286
CueStyleValue = 287
GridRowStartStyleValue = 288
LabFunctionParams = 289
ColumnWidthStyleValue = 290
OffsetAnchorStyleValue = 291
MediaType = 292
KeyframesRule = 293
HtmlTag = 294
TextWrapStyleValue = 295
StyleRule = 296
FontSizeStyleValue = 297
ViewTimelineAxisStyleValue = 298
FloodOpacityStyleValue = 299
MixBlendModeStyleValue = 300
ColumnRuleStyleValue = 301
CursorImage = 302
BorderLeftColorStyleValue = 303
TargetCounterFunction = 304
FallbackStyleValue = 305
FontOpticalSizingStyleValue = 306
BorderStyleValue = 307
TextSpacingTrimStyleValue = 308
ScrollTargetGroupStyleValue = 309
ScrollPaddingInlineEndStyleValue = 310
InlineSizingStyleValue = 311
StepsFunction = 312
ScaleFunction = 313
GenericFamily = 314
CubicBezierFunction = 315
Image1d = 316
WebkitDevicePixelRatioMediaFeature = 317
ColumnRuleBreakStyleValue = 318
InlineSizeStyleValue = 319
HeightStyleValue = 320
LineGridStyleValue = 321
OverlayStyleValue = 322
BorderEndEndRadiusStyleValue = 323
FontWidthStyleValue = 324
AnimationRangeEndStyleValue = 325
AttributeValue = 326
PointerTimelineStyleValue = 327
OverscrollBehaviorStyleValue = 328
BookmarkStateStyleValue = 329
BorderStartEndRadiusStyleValue = 330
PageRule = 331
SpeakAsStyleValue = 332
MaskBorderModeStyleValue = 333
TextDecorationThicknessStyleValue = 334
EmptyCellsStyleValue = 335
SelectorList = 336
MarginBottomStyleValue = 337
Time = 338
ViewTimelineInsetStyleValue = 339
PaddingTopStyleValue = 340
PropertyRule = 341
WillChangeStyleValue = 342
LetterSpacingStyleValue = 343
LinearFunctionParams = 344
BackgroundRepeatBlockStyleValue = 345
ColumnRuleInsetStartStyleValue = 346
DocumentRule = 347
InterestDelayEndStyleValue = 348
ScrollPaddingBottomStyleValue = 349
UnknownAtRule = 350
SelfPosition = 351
BorderSpacingStyleValue = 352
TextAlignAllStyleValue = 353
InsetStyleValue = 354
AspectRatioStyleValue = 355
MinBlockSizeStyleValue = 356
FlexFlowStyleValue = 357
ScrollBehaviorStyleValue = 358
FlexDirectionStyleValue = 359
TextDecorationSkipInkStyleValue = 360
ScrollMarginStyleValue = 361
SystemStyleValue = 362
FillOriginStyleValue = 363
CaretStyleValue = 364
ViewTransitionImagePairPseudoElement = 365
ScrollbarWidthStyleValue = 366
FontFaceRule = 367
OutlineStyleStyleValue = 368
RubyAlignStyleValue = 369
BorderBlockEndWidthStyleValue = 370
ScrollTimelineStyleValue = 371
HoverMediaFeature = 372
SupportsCondition = 373
WebkitAnimationMediaFeature = 374
AnimationCompositionStyleValue = 375
TextGroupAlignStyleValue = 376
PaddingStyleValue = 377
BorderRightClipStyleValue = 378
ImportRule = 379
ColumnHeightStyleValue = 380
TransitionPropertyStyleValue = 381
StrokeLinecapStyleValue = 382
GridTemplateAreasStyleValue = 383
StyleFeature = 384
RowRuleInsetStyleValue = 385
LabFunction = 386
ColumnRuleWidthStyleValue = 387
FontKerningStyleValue = 388
BackgroundOriginStyleValue = 389
DisplayModeMediaFeature = 390
WebkitLineClampStyleValue = 391
KeyframesRuleBlock = 392
LineWidth = 393
CaretShapeStyleValue = 394
AnchorName = 395
PaddingInlineStartStyleValue = 396
BackgroundImageStyleValue = 397
BorderLeftWidthStyleValue = 398
SlottedPseudoElement = 399
MarginTopStyleValue = 400
BorderImageOutsetStyleValue = 401
ScrollSnapAlignStyleValue = 402
ContentDistribution = 403
PointerMediaFeature = 404
RotatexFunction = 405
GridAutoRowsStyleValue = 406
EventTriggerNameStyleValue = 407
BackgroundRepeatInlineStyleValue = 408
StrokeOriginStyleValue = 409
BorderLeftClipStyleValue = 410
LegacyPseudoElement = 411
StripesFunction = 412
MozPseudoClass = 413
BlockStepSizeStyleValue = 414
PickerPseudoElement = 415
ColumnRuleEdgeInsetStartStyleValue = 416
MaskBorderOutsetStyleValue = 417
Url = 418
WebkitFunctionalPseudoElement = 419
LineStyle = 420
AttrFunction = 421
TimelineRangeName = 422
FontSynthesisWeightStyleValue = 423
HyphenateLimitZoneStyleValue = 424
PaddingBlockStartStyleValue = 425
TopStyleValue = 426
ViewTransitionOldPseudoElement = 427
MsHighContrastMediaFeature = 428
HostPseudoFunction = 429
ContainerFeature = 430
AnimationNameStyleValue = 431
ScrollMarginBlockStyleValue = 432
BoxShadowBlurStyleValue = 433
LineSnapStyleValue = 434
ListStyleImageStyleValue = 435
DynamicRangeMediaFeature = 436
SnapInlineFunction = 437
ContainerQuery = 438
MozDeviceOrientationMediaFeature = 439
RotatezFunction = 440
CounterStyleRule = 441
OverflowClipMarginBlockEndStyleValue = 442
SliderOrientationStyleValue = 443
RectangularColorSpace = 444
ZoomStyleValue = 445
ScalexFunction = 446
ClipRuleStyleValue = 447
CornerShapeValue = 448
MaskBorderSourceStyleValue = 449
FlexStyleValue = 450
MonochromeMediaFeature = 451
TextDecorationStyleStyleValue = 452
BottomStyleValue = 453
TargetTextFunction = 454
ColumnCountStyleValue = 455
PageSelector = 456
LineFitEdgeStyleValue = 457
WordBreakStyleValue = 458
RestAfterStyleValue = 459
AlignContentStyleValue = 460
UserSelectStyleValue = 461
ScrollMarginBlockStartStyleValue = 462
MsPseudoElement = 463
AccentColorStyleValue = 464
ShapeImageThresholdStyleValue = 465
BorderRightWidthStyleValue = 466
BorderTopColorStyleValue = 467
HyphenateCharacterStyleValue = 468
Ratio = 469
Keyframe = 470
Target = 471
ColorMixFunction = 472
ViewTransitionGroupPseudoElement = 473
FillBreakStyleValue = 474
CornerStartStartShapeStyleValue = 475
CornerBottomLeftShapeStyleValue = 476
RepeatingLinearGradientFunction = 477
FontVariationSettingsStyleValue = 478
FontSynthesisSmallCapsStyleValue = 479
RgbFunction = 480
StatePseudoFunction = 481
WidthContainerFeature = 482
MozImagesInMenusMediaFeature = 483
BorderTopWidthStyleValue = 484
ScrollTimelineNameStyleValue = 485
CounterFunction = 486
MediaPreCondition = 487
BorderRightStyleValue = 488
ForcedColorsMediaFeature = 489
BorderStyleStyleValue = 490
BorderBlockStyleValue = 491
TextEmphasisSkipStyleValue = 492
AnimationTriggerStyleValue = 493
HeightContainerFeature = 494
FloodColorStyleValue = 495
SpeakStyleValue = 496
StringFunction = 497
GapRepeatRule = 498
CornerBottomRightShapeStyleValue = 499
InsetInlineStyleValue = 500
SingleTransitionProperty = 501
DashedIdent = 502
ScrollPaddingBlockStartStyleValue = 503
SingleAnimationPlayState = 504
TransitionStyleValue = 505
RowRuleStyleStyleValue = 506
AnimationRangeStartStyleValue = 507
MarkerSideStyleValue = 508
NumberLength = 509
AlignmentBaselineStyleValue = 510
ReadingOrderStyleValue = 511
OrphansStyleValue = 512
TabSizeStyleValue = 513
TextEmphasisColorStyleValue = 514
HwbFunctionParams = 515
TextDecorationInsetStyleValue = 516
OverscrollBehaviorInlineStyleValue = 517
ScrollPaddingInlineStyleValue = 518
CornerTopShapeStyleValue = 519
ContainerRule = 520
ScrollMarginInlineEndStyleValue = 521
AnyPointerMediaFeature = 522
MaskClipStyleValue = 523
ContentListItem = 524
StrokeWidthStyleValue = 525
BorderInlineEndStyleValue = 526
HslFunctionParams = 527
Tag = 528
AttributeModifier = 529
VideoColorGamutMediaFeature = 530
FlexWrapStyleValue = 531
ScanMediaFeature = 532
OverflowClipMarginInlineStyleValue = 533
UnknownTag = 534
Percentage = 535
OverflowClipMarginTopStyleValue = 536
AllStyleValue = 537
TextWrapStyleStyleValue = 538
OrientationContainerFeature = 539
ScrollMarginTopStyleValue = 540
FontVariantEmojiStyleValue = 541
BoxSizingStyleValue = 542
PerspectiveFunction = 543
PseudoClass = 544
AttributeOperator = 545
RuleBreakStyleValue = 546
BorderBlockColorStyleValue = 547
ScrollMarkerGroupStyleValue = 548
CornerBlockEndShapeStyleValue = 549
BookmarkLevelStyleValue = 550
MozMaemoClassicMediaFeature = 551
Scale3dFunction = 552
WebkitKeyframesRule = 553
FloatStyleValue = 554
InsetInlineEndStyleValue = 555
ColumnRuleVisibilityItemsStyleValue = 556
RuleColorStyleValue = 557
DisplayStyleValue = 558
FillRepeatStyleValue = 559
TransformList = 560
BorderInlineEndStyleStyleValue = 561
MaxHeightStyleValue = 562
Rotate3dFunction = 563
CounterStyle = 565
CounterStyleRuleStyleValue = 566
NthColPseudoFunction = 567
HtmlNonConformingTag = 568
SupportsFeature = 569
MaxBlockSizeStyleValue = 570
VideoDynamicRangeMediaFeature = 571
HorizontalViewportSegmentsMediaFeature = 572
ScriptingMediaFeature = 573
WebkitTransform2dMediaFeature = 574
ImageRenderingStyleValue = 575
BorderWidthStyleValue = 576
ScrollPaddingBlockStyleValue = 577
SvgTag = 578
InsetBlockStartStyleValue = 579
PrefixStyleValue = 580
GridMediaFeature = 581
GapStyleValue = 582
TrySize = 583
BorderTopLeftRadiusStyleValue = 584
RowRuleEdgeInsetEndStyleValue = 585
LinePaddingStyleValue = 586
RuleInsetStartStyleValue = 587
SnapBlockFunction = 588
ColorFunctionColorParams = 589
OverflowClipMarginInlineStartStyleValue = 590
ImportLayer = 591
RowRuleVisibilityItemsStyleValue = 592
Flex = 593
HeadingPseudoFunction = 594
TargetCountersFunction = 595
OverflowClipMarginInlineEndStyleValue = 596
BlockStepStyleValue = 597
AnimationTimelineStyleValue = 598
WebkitTransitionMediaFeature = 599
BorderLeftStyleValue = 600
InitialLetterWrapStyleValue = 601
SymbolsStyleValue = 602
SupportsRule = 603
StrokeDasharrayStyleValue = 604
MinWidthStyleValue = 605
MsDevicePixelRatioMediaFeature = 606
ContentFunction = 607
ViewTransitionGroupStyleValue = 608
BorderInlineEndWidthStyleValue = 609
BookmarkLabelStyleValue = 610
ScrollPaddingStyleValue = 611
Combinator = 612
TextDecorationSkipBoxStyleValue = 613
AnimationRangeStyleValue = 614
HighlightPseudoElement = 615
BorderTopClipStyleValue = 616
SkewyFunction = 617
BreakAfterStyleValue = 618
PolarColorSpace = 619
BlockSizeContainerFeature = 620
MediaRule = 621
AppearanceStyleValue = 622
LayerRule = 623
ColumnRuleColorStyleValue = 624
TextCombineUprightStyleValue = 625
MaskSizeStyleValue = 626
ObjectViewBoxStyleValue = 627
OffsetDistanceStyleValue = 628
WrapBeforeStyleValue = 629
BorderEndStartRadiusStyleValue = 630
Angle = 631
MarginInlineEndStyleValue = 632
TranslateyFunction = 633
PrefersContrastMediaFeature = 634
EnvironmentBlendingMediaFeature = 635
OpacityValue = 636
NegativeStyleValue = 637
WebkitAnyFunctionalPseudoClass = 638
ShapePaddingStyleValue = 639
FlowFromStyleValue = 640
RuleStyleValue = 641
NthLastColPseudoFunction = 642
RubyOverhangStyleValue = 643
LeftStyleValue = 644
PositionStyleValue = 645
TextDecorationColorStyleValue = 646
ResizeStyleValue = 647
BoxShadowColorStyleValue = 648
HueInterpolationMethod = 649
CharsetRule = 650
StrokeDashCornerStyleValue = 651
ColorSpace = 652
Position = 653
GapRuleOrRepeat = 654
WritingModeStyleValue = 655
CornerLeftShapeStyleValue = 656
AnimationAction = 657
Image = 658
TransitionDelayStyleValue = 659
ScrollMarginBlockEndStyleValue = 660
BorderBottomStyleStyleValue = 661
OutlineOffsetStyleValue = 662
LinkParametersStyleValue = 663
ScrollMarginInlineStyleValue = 664
Wildcard = 665
InterestDelayStartStyleValue = 666
BackgroundColorStyleValue = 667
ColorAdjustStyleValue = 668
StrokeMiterlimitStyleValue = 669
Quote = 670
TextBoxTrimStyleValue = 671
RowRuleBreakStyleValue = 672
RepeatStyle = 673
WhiteSpaceCollapseStyleValue = 674
ScrollInitialTargetStyleValue = 675
HslFunction = 676
PaddingInlineStyleValue = 677
MaskRepeatStyleValue = 678
FillSizeStyleValue = 679
BorderBoundaryStyleValue = 680
BorderBottomClipStyleValue = 681
BorderBlockStartStyleStyleValue = 682
CustomElementTag = 683
ColorIndexMediaFeature = 684
OverflowWrapStyleValue = 685
MozLocaleDirFunctionalPseudoClass = 686
SyntaxValue = 687
IsolationStyleValue = 688
AnimationPlayStateStyleValue = 689
PositionArea = 690
MarginLeftStyleValue = 691
BorderRightColorStyleValue = 692
ScalezFunction = 693
SuffixStyleValue = 694
BorderTopStyleValue = 695
PrefersReducedDataMediaFeature = 696
PerspectiveOriginStyleValue = 697
BorderBlockClipStyleValue = 698
VoiceStressStyleValue = 699
BorderImageRepeatStyleValue = 700
CornerBlockStartShapeStyleValue = 701
RunningStyleValue = 702
ColorMediaFeature = 703
TextSizeAdjustStyleValue = 704
MozOsVersionMediaFeature = 705
ScrollMarginBottomStyleValue = 706
ScrollPaddingLeftStyleValue = 707
RegionFragmentStyleValue = 708
ViewTransitionScopeStyleValue = 709
MozFunctionalPseudoClass = 710
RowRuleInteriorInsetEndStyleValue = 711
OverflowYStyleValue = 712
OverflowClipMarginBottomStyleValue = 713
ContentList = 714
WrapAfterStyleValue = 715
BorderBlockEndStyleValue = 716
InheritsValue = 717
OverflowBlockStyleValue = 718
ScaleStyleValue = 719
FieldSizingStyleValue = 720
GridColumnStartStyleValue = 721
FontFeatureSettingsStyleValue = 722
KeyframeSelector = 723
RowRuleWidthStyleValue = 724
AdditiveSymbolsStyleValue = 725
OverflowInlineMediaFeature = 726
OverflowAnchorStyleValue = 727
FitContentFunction = 728
ColumnRuleInteriorInsetStartStyleValue = 729
ColumnRuleInteriorInsetStyleValue = 730
ContainerNameStyleValue = 731
BorderImageSourceStyleValue = 732
ColumnRuleEdgeInsetEndStyleValue = 733
AnchorScopeStyleValue = 734
RowRuleInteriorInsetStartStyleValue = 735
OverflowStyleValue = 736
AutoLineWidthList = 737
MinInlineSizeStyleValue = 738
StyleValue = 739
MinHeightStyleValue = 740
AnimateableFeature = 741
StrokePositionStyleValue = 742
CountersFunction = 743
BoxShadowSpreadStyleValue = 744
AlignSelfStyleValue = 745
FontWeightAbsolute = 746
WebkitPseudoElement = 747
OrderStyleValue = 748
CursorStyleValue = 749
InsetBlockStyleValue = 750
InsetBlockEndStyleValue = 751
ColumnWrapStyleValue = 752
InsetInlineStartStyleValue = 753
FloatOffsetStyleValue = 754
LightingColorStyleValue = 755
BorderRightStyleStyleValue = 756
BaselinePosition = 757
AnimationDelayStyleValue = 758
WordWrapStyleValue = 759
ColumnGapStyleValue = 760
MarginRightStyleValue = 761
MarginInlineStartStyleValue = 762
MarginBlockStartStyleValue = 763
ImageAnimationStyleValue = 764
TransitionBehaviorStyleValue = 765
SingleTransition = 766
TextAutospaceStyleValue = 767
OutlineWidthStyleValue = 768
ColorFunction = 769
CornerEndEndShapeStyleValue = 770
ScrollMarginInlineStartStyleValue = 771
FlexShrinkStyleValue = 772
GapRuleList = 773
PauseStyleValue = 774
BorderLeftStyleStyleValue = 775
PaddingRightStyleValue = 776
KeyframesName = 777
PaddingBottomStyleValue = 778
RestBeforeStyleValue = 779
MaxLinesStyleValue = 780
OverflowClipMarginBlockStyleValue = 781
CompoundSelector = 782
BlockStepInsertStyleValue = 783
OutlineStyleValue = 784
InterestDelayStyleValue = 785
InputSecurityStyleValue = 786
CaretColorStyleValue = 787
ScrollPaddingBlockEndStyleValue = 788
OverflowClipMarginBlockStartStyleValue = 789
StrokeRepeatStyleValue = 790
BlockSizeStyleValue = 791
BackgroundClipStyleValue = 792
SuperellipseFunction = 793
BorderBlockEndStyleStyleValue = 794
BorderInlineColorStyleValue = 795
FootnotePolicyStyleValue = 796
OPseudoElement = 797
ImportSupportsFunction = 798
NotPseudoFunction = 799
BorderStartStartRadiusStyleValue = 800
GridColumnEndStyleValue = 801
OverflowInlineStyleValue = 802
MozDevicePixelRatioMediaFeature = 803
StrokeBreakStyleValue = 804
BorderRadius = 805
FillRuleStyleValue = 806
DocumentMatcher = 807
OverscrollBehaviorYStyleValue = 808
ListStyleTypeStyleValue = 809
Color = 810
PauseAfterStyleValue = 811
BorderInlineStartColorStyleValue = 812
FlowToleranceStyleValue = 813
FontSynthesisStyleStyleValue = 814
PerspectiveStyleValue = 815
StrokeColorStyleValue = 816
BaselineSourceStyleValue = 817
EventTriggerSourceStyleValue = 818
BorderInlineClipStyleValue = 819
RotateyFunction = 820
NthChildPseudoFunction = 821
FlexGrowStyleValue = 822
ODevicePixelRatioMediaFeature = 823
ColorStyleValue = 824
RadialGradientFunction = 825
ScrollPaddingTopStyleValue = 826
SingleAnimationFillMode = 827
BackgroundAttachmentStyleValue = 828
PadStyleValue = 829
RuleStyleStyleValue = 830
VoiceBalanceStyleValue = 831
HostContextPseudoFunction = 832
WherePseudoFunction = 833
BorderBottomRightRadiusStyleValue = 834
LinearGradientFunction = 835
OverflowBlockMediaFeature = 836
OutlineColorStyleValue = 837
MsViewStateMediaFeature = 838
FontVariantCapsStyleValue = 839
SymbolsFunction = 840
TextWrapModeStyleValue = 841
WidthStyleValue = 842
ScrollPaddingRightStyleValue = 843
FloatReferenceStyleValue = 844
FillColorStyleValue = 845
ViewTimelineNameStyleValue = 846
RowRuleInsetStartStyleValue = 847
NumberPercentage = 848
RowRuleColorStyleValue = 849
BoxShadowPositionStyleValue = 850
Id = 851
ScaleyFunction = 852
PaddingBlockStyleValue = 853
PaddingLeftStyleValue = 854
RuleWidthStyleValue = 855
BorderBlockEndColorStyleValue = 856
WrapThroughStyleValue = 857
WordSpacingStyleValue = 858
ViewTransitionClassStyleValue = 859
CustomIdent = 860
WrapFlowStyleValue = 861
AnimationIterationCountStyleValue = 862
BorderInlineStartWidthStyleValue = 863
MaxWidthStyleValue = 864
ImageSetFunction = 865
TextAlignLastStyleValue = 866
OverflowClipMarginLeftStyleValue = 867
TimelineTriggerSourceStyleValue = 868
TransformFunction = 869
AnimationDirectionStyleValue = 870
SkewFunction = 871
WebkitVideoPlayableInlineMediaFeature = 872
Implementations
Sourceimpl NodeId
impl NodeId
Sourcepub fn to_at_rule_id(self) -> Option<AtRuleId>
pub fn to_at_rule_id(self) -> Option<AtRuleId>
Converts a NodeId to an AtRuleId if the node is an at-rule type.
Returns None for non-at-rule nodes like StyleRule, Declaration, etc.
Sourceimpl NodeId
impl NodeId
Sourcepub const fn tag_name(self) -> &'static str
pub const fn tag_name(self) -> &'static str
Returns the kebab-case tag name for this node type.
This is used in selector matching (e.g., “style-rule”, “declaration”).
Sourcepub fn from_tag_name(name: &str) -> Option<Self>
pub fn from_tag_name(name: &str) -> Option<Self>
Attempts to parse a tag name string into a NodeId.
Returns None if the tag name doesn’t match any known node type.
Sourcepub fn all_variants() -> impl Iterator<Item = Self>
pub fn all_variants() -> impl Iterator<Item = Self>
Returns an iterator over all possible NodeId values.